(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    153968,       3206]
NotebookOptionsPosition[    152403,       3152]
NotebookOutlinePosition[    152830,       3170]
CellTagsIndexPosition[    152787,       3167]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "notebook", " ", "calculates", " ", "the", " ", "magnetic", 
    " ", "fields", " ", "and", " ", "forces", " ", "on", " ", "the", " ", 
    "magnetic", " ", "beads", " ", "from", " ", "the", " ", "magnet", " ", 
    RowBox[{"pair", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Distances", " ", "in", " ", 
    RowBox[{"Meters", ".", " ", "H"}], " ", "in", " ", 
    RowBox[{"A", "/", 
     RowBox[{"m", ".", " ", "B"}]}], " ", "in", " ", "Tesla"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"B", "=", 
    RowBox[{"\[Mu]0", "*", "H"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Mathematica", "'"}], "s", " ", "vector", " ", "Analysis", " ", 
    "Package", " ", "is", " ", "utilized"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Needs", "[", "\"\<VectorAnalysis`\>\"", "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "These", " ", "are", " ", "used", " ", "to", " ", "supppress", " ", 
     "error", " ", "messages", " ", "from", " ", "NIntegrate"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "slwcon"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "ncvb"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"General", "::", "spell1"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "ploss"}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "tmap"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "oidiv"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "infy"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "indet"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Import", " ", "measured", " ", "data", " ", "of", " ", "Lipfert", " ", 
      RowBox[{"et", ".", " ", "al"}], " ", "Biopysical", " ", "journal", " ", 
      "vol", " ", "96", " ", "540"}], "-", 
     RowBox[{"5049", " ", "2009."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"measH", "=", 
     RowBox[{"Import", "[", 
      RowBox[{
       RowBox[{"ToFileName", "[", 
        RowBox[{
         RowBox[{"NotebookDirectory", "[", "]"}], ",", " ", 
         "\"\<MeasV2_Lipfert.txt\>\""}], "]"}], ",", " ", "\"\<Table\>\""}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "magnetic", " ", "permeability", " ", "of", " ", "the", " ", "vacuum"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Mu]0", "=", 
     RowBox[{"4", " ", "\[Pi]", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "7"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]", "=", 
     RowBox[{"1.24", "/", "\[Mu]0"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "magnetic", " ", "surface", " ", "charge", " ", "at", " ", "the", " ", 
      "face", " ", "of", " ", "the", " ", 
      RowBox[{"magnets", ".", " ", "The"}], " ", "manufacturer", " ", 
      "provides", " ", "that", " ", "the", " ", "magnetic", " ", "field", " ",
       "at", " ", "the", " ", "face", " ", "of", " ", "the", " ", "magnets", 
      " ", "is", " ", "14.1"}], "-", 
     RowBox[{"14.5", " ", "kilo"}], "-", 
     RowBox[{"Gauss", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"length", " ", "of", " ", "the", " ", "cubic", " ", "magnets"}], 
     ",", " ", 
     RowBox[{"5", "mm"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"L", "=", 
     RowBox[{"5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "this", " ", "is", " ", "actually", " ", "one", " ", "half", " ", "the", 
      " ", "gap", " ", "size", " ", "between", " ", "the", " ", "magnets"}], 
     ",", " ", 
     RowBox[{
     "so", " ", "for", " ", "a", " ", "2", "mm", " ", "gap", " ", "this", " ",
       "term", " ", "should", " ", "be", " ", "1"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gap", "=", 
     RowBox[{"1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Position", " ", "vector", " ", "of", " ", "the", " ", "bead"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rb", "=", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "position", " ", "vector", " ", "which", " ", "we", " ", "integrate", 
      " ", "over", " ", "the", " ", "surface", " ", "of", " ", "the", " ", 
      "magnet", " ", 
      RowBox[{"faces", ".", " ", "If"}], " ", "instead", " ", "of", " ", 
      "using", " ", "an", " ", "integral", " ", "we", " ", "used", " ", "a", 
      " ", "Riemann", " ", "sum"}], ",", " ", 
     RowBox[{
     "this", " ", "vector", " ", "would", " ", "represent", " ", "the", " ", 
      "position", " ", "of", " ", "the", " ", "small", " ", "square", " ", 
      "of", " ", "magnetic", " ", "charge", " ", "on", " ", "the", " ", 
      "magnet", " ", 
      RowBox[{"face", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ri", "=", 
     RowBox[{"{", 
      RowBox[{"xi", ",", "yi", ",", "zi"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Saturation", " ", "Magnetization", " ", "in", " ", "units", " ", "of", 
     " ", 
     RowBox[{"A", "/", "m"}], " ", "of", " ", "the", " ", "magnetic", " ", 
     "bead", " ", "NOT", " ", "to", " ", "be", " ", "confused", " ", "with", 
     " ", "the", " ", "saturation", " ", "magnetization", " ", "of", " ", 
     "Neodinium"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"msat", "=", 
     RowBox[{"43.3", " ", 
      SuperscriptBox["10", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Characteristic", " ", "Field", " ", "in", " ", "Tesla", " ", "of", " ", 
     "the", " ", "M", " ", 
     RowBox[{"v", ".", " ", "B"}], " ", "curves", " ", "of", " ", "the", " ", 
     "myone", " ", "beads"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B0", "=", 
     RowBox[{"12", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"bead", " ", "radius", " ", "and", " ", "volume"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"radb", "=", 
     RowBox[{"1.05", "*", 
      RowBox[{
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]], "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V", "=", 
     RowBox[{
      FractionBox["4", "3"], " ", "\[Pi]", " ", 
      SuperscriptBox["radb", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "To", " ", "calculate", " ", "the", " ", "force", " ", "we", " ", 
      "calculate", " ", "the", " ", "gradient", " ", "of", " ", 
      RowBox[{"m", ".", "b"}], " ", 
      RowBox[{"numerically", ".", " ", "This"}], " ", "is", " ", "the", " ", 
      "size", " ", "of", " ", "the", " ", "step", " ", "we", " ", "take", " ",
       "in", " ", 
      RowBox[{"meters", ".", " ", "The"}], " ", "numerical", " ", "integral", 
      " ", "can", " ", "be", " ", "sensitive", " ", "to", " ", "this"}], ",", 
     " ", 
     RowBox[{
      RowBox[{
      "if", " ", "you", " ", "make", " ", "it", " ", "to", " ", "small", " ", 
       "you", " ", "get", " ", "bit"}], "-", 
      RowBox[{"sized", " ", "errors", " ", "and", " ", 
       RowBox[{"stuff", ".", " ", "1"}], " ", "micron", " ", 
       RowBox[{"(", 
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ")"}], " ", "seems", " ", "to", " ", "work", 
       " ", "pretty", " ", "well"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "7"}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "set", " ", "up", " ", "cartesian", " ", "coordinates", " ", "so", " ", 
     "we", " ", "can", " ", "use", " ", "vector", " ", "operations"}], " ", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetCoordinates", "[", 
     RowBox[{"Cartesian", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmag", "=", 
     RowBox[{
      RowBox[{"-", "0.5"}], " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"I", " ", "use", " ", "the", " ", "method", " ", "from", " ", 
      RowBox[{"p", ".", " ", "196"}]}], "-", 
     RowBox[{
     "197", " ", "of", " ", "\"\<Classical Electrodynamics\>\"", " ", "by", 
      " ", "John", " ", "David", " ", "Jackson"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[CapitalPhi]int", " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "\[Pi]"}]], " ", 
      FractionBox["\[Sigma]", 
       RowBox[{"|", 
        RowBox[{"ri", "-", "rb"}], "|"}]]}]}], " ", " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[CapitalPhi]", " ", "=", " ", 
     RowBox[{
      RowBox[{"\[Integral]", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"4", "\[Pi]"}]], " ", 
        FractionBox["\[Sigma]", 
         RowBox[{"|", 
          RowBox[{"ri", "-", "rb"}], "|"}]], " ", 
        RowBox[{"\[DifferentialD]", "A"}]}]}], " ", "=", " ", 
      RowBox[{"\[Integral]", " ", 
       RowBox[{"\[CapitalPhi]int", " ", 
        RowBox[{"\[DifferentialD]", "A"}]}]}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"H", " ", "=", " ", 
     RowBox[{"-", 
      RowBox[{"\[Del]", " ", "\[CapitalPhi]"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"B", "=", 
     RowBox[{"\[Mu]0", "*", "H"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPhi]int", "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      FractionBox["\[Sigma]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ri", "-", "rb"}], ")"}], ".", 
          RowBox[{"(", 
           RowBox[{"ri", "-", "rb"}], ")"}]}], ")"}], 
        FractionBox["1", "2"]]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "first", " ", "find", " ", "the", " ", "general", " ", "solution", " ", 
     "to", " ", "the", " ", "integral"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]gen", "[", 
      RowBox[{"xi_", ",", "yi_", ",", " ", "zi_"}], "]"}], "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{"\[CapitalPhi]int", ",", " ", "xi", ",", " ", "yi"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Then", " ", "evaluate", " ", "the", " ", "endpoints", " ", "of", " ", 
     "the", " ", "integral", " ", "manually"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "each", " ", "magnet", " ", "has", " ", "a", " ", "surface", " ", "of", 
      " ", "charge", " ", "on", " ", "the", " ", "top", " ", "and", " ", 
      "bottom", " ", "and", " ", "they", " ", "are", " ", "oppositely", " ", 
      "charged"}], ",", " ", 
     RowBox[{
     "so", " ", "we", " ", "put", " ", "in", " ", "that", " ", "part", " ", 
      "here"}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]first", "[", 
      RowBox[{"xi1_", ",", " ", "yi1_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"\[CapitalPhi]gen", "[", 
       RowBox[{"xi1", ",", "yi1", ",", " ", "0"}], "]"}], "-", 
      RowBox[{"\[CapitalPhi]gen", "[", 
       RowBox[{"xi1", ",", "yi1", ",", "L"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Now", " ", "we", " ", "evaluate", " ", "the", " ", "y", " ", "portion", 
     " ", "of", " ", "the", " ", "integral"}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]sec", "[", "xi2_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"\[CapitalPhi]first", "[", 
       RowBox[{"xi2", ",", 
        RowBox[{"L", "/", "2"}]}], "]"}], "-", 
      RowBox[{"\[CapitalPhi]first", "[", 
       RowBox[{"xi2", ",", 
        RowBox[{
         RowBox[{"-", "L"}], "/", "2"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "and", " ", "then", " ", "evaluate", " ", "the", " ", "x", " ", "part", 
      " ", "of", " ", "the", " ", "integral"}], " ", "-", " ", 
     RowBox[{
     "a", " ", "pair", " ", "of", " ", "terms", " ", "for", " ", "each", " ", 
      "of", " ", "the", " ", "two", " ", "magnets"}]}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"\[CapitalPhi]sec", "[", 
       RowBox[{"gap", "+", "L"}], "]"}], "-", 
      RowBox[{"\[CapitalPhi]sec", "[", "gap", "]"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalPhi]sec", "[", 
         RowBox[{"-", " ", "gap"}], "]"}], "-", 
        RowBox[{"\[CapitalPhi]sec", "[", 
         RowBox[{"-", " ", 
          RowBox[{"(", 
           RowBox[{"gap", "+", "L"}], ")"}]}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "In", " ", "principle", " ", "the", " ", "solution", " ", "here", " ", 
      "can", " ", "be", " ", "complex", " ", "if", " ", "the", " ", "inputs", 
      " ", "are", " ", 
      RowBox[{"complex", ".", " ", "So"}], " ", "mathematica", " ", "gives", 
      " ", "an", " ", "output", " ", "that", " ", "is", " ", "in", " ", "a", 
      " ", "complex", " ", 
      RowBox[{"form", ".", " ", "Since"}], " ", "our", " ", "input", " ", 
      "are", " ", "only", " ", "reals"}], ",", " ", 
     RowBox[{
     "the", " ", "imaginary", " ", "part", " ", "is", " ", "always", " ", 
      RowBox[{"zero", ".", " ", "I"}], " ", "just", " ", "truncate", " ", 
      "to", " ", "the", " ", "Real", " ", "part", " ", "and", " ", "take", 
      " ", "the", " ", "gradient", " ", "to", " ", "give", " ", "H", " ", 
      RowBox[{"here", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{"-", 
      RowBox[{"Re", "[", 
       RowBox[{"Grad", "[", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{"\[Mu]0", "*", 
      RowBox[{"H", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "This", " ", "function", " ", "gives", " ", "the", " ", "magnetic", " ", 
      "moment", " ", "of", " ", "the", " ", "bead", " ", "as", " ", "a", " ", 
      "function", " ", "of", " ", "magnetic", " ", "field", " ", "ref", " ", 
      "Lipfert", " ", 
      RowBox[{"et", ".", " ", "al"}], " ", "Biopysical", " ", "journal", " ", 
      "vol", " ", "96", " ", "540"}], "-", 
     RowBox[{"5049", " ", "2009."}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Normalize", "[", 
       RowBox[{"H", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "*", "V", "*", 
      "msat", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Coth", "[", 
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"B", "[", 
            RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "/", "B0"}], 
         "]"}], "-", 
        FractionBox["B0", 
         RowBox[{"Norm", "[", 
          RowBox[{"B", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"mdb", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", " ", 
     RowBox[{"DotProduct", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], ")"}], ",", " ", 
       RowBox[{"B", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Here", " ", "we", " ", "calculate", " ", "the", " ", "force", " ", "by",
       " ", "calculating", " ", "the", " ", "gradient", " ", "numerically"}], 
     ",", " ", 
     RowBox[{
     "simply", " ", "taking", " ", "a", " ", "small", " ", "step", " ", 
      "\[Epsilon]"}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Fz", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Epsilon]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mdb", "[", 
         RowBox[{"x", ",", "y", ",", 
          RowBox[{"z", "+", "\[Epsilon]"}]}], "]"}], "-", 
        RowBox[{"mdb", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Fx", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Epsilon]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mdb", "[", 
         RowBox[{
          RowBox[{"x", "+", "\[Epsilon]"}], ",", "y", ",", "z"}], "]"}], "-", 
        RowBox[{"mdb", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Fy", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[Epsilon]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mdb", "[", 
         RowBox[{"x", ",", 
          RowBox[{"y", "+", "\[Epsilon]"}], ",", "z"}], "]"}], "-", 
        RowBox[{"mdb", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Fx", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"Fy", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"Fz", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5044168801890664`*^9, 3.5044169653140664`*^9}, {
   3.5044171082828164`*^9, 3.5044171207046914`*^9}, {3.5044171920015664`*^9, 
   3.5044173384390664`*^9}, {3.5044174127671914`*^9, 
   3.5044174386109414`*^9}, {3.5044174784703164`*^9, 
   3.5044174809078164`*^9}, {3.5044175135796914`*^9, 
   3.5044175191578164`*^9}, {3.5044176992671914`*^9, 
   3.5044177017203164`*^9}, {3.5044184146890664`*^9, 
   3.5044185266364784`*^9}, {3.5044186057912855`*^9, 
   3.5044186087761955`*^9}, {3.5044186442825565`*^9, 
   3.5044186481582513`*^9}, {3.504418680179613*^9, 3.504418695338579*^9}, {
   3.5044187331266*^9, 3.5044187468165526`*^9}, {3.5044188425286303`*^9, 
   3.5044188787653246`*^9}, {3.5044189188928924`*^9, 
   3.5044189955853004`*^9}, {3.504419496831892*^9, 3.5044195104414415`*^9}, 
   3.5044196034582567`*^9, {3.504419638771209*^9, 3.5044196408493605`*^9}, {
   3.5044196991466265`*^9, 3.5044197139591265`*^9}, {3.5044201632716265`*^9, 
   3.5044201638185015`*^9}, {3.5044202171935015`*^9, 
   3.5044202422560015`*^9}, {3.5044208075372515`*^9, 
   3.5044208775997515`*^9}, {3.5044222678111286`*^9, 3.504422314285529*^9}, {
   3.5044223455862103`*^9, 3.5044224052158685`*^9}, {3.5044224583901253`*^9, 
   3.504422467703043*^9}, {3.504422503173382*^9, 3.5044225165177298`*^9}, {
   3.504423017013178*^9, 3.5044230172631793`*^9}, {3.504429422684017*^9, 
   3.504429430045182*^9}, {3.504429845010354*^9, 3.504429860371105*^9}, {
   3.5044329338169684`*^9, 3.5044329354733777`*^9}, 3.504433769027009*^9, {
   3.504434586127926*^9, 3.504434586471678*^9}, {3.5044346261438065`*^9, 
   3.504434718191271*^9}, {3.5044347803479185`*^9, 3.5044348926298876`*^9}, {
   3.504434925348847*^9, 3.504435431352085*^9}, {3.5044355987437816`*^9, 
   3.5044356050250716`*^9}, {3.5044356523534994`*^9, 
   3.5044356527285023`*^9}, {3.5044357033069506`*^9, 
   3.5044357354477816`*^9}, {3.5044361003094916`*^9, 
   3.5044361732787085`*^9}, {3.50443620704455*^9, 3.50443622591967*^9}, {
   3.5044379500532546`*^9, 3.504437953381401*^9}, {3.504438130226283*^9, 
   3.504438130898162*^9}, {3.504439130717061*^9, 3.504439141170253*^9}, {
   3.504439728767763*^9, 3.5044397302052727`*^9}, {3.5044420326567125`*^9, 
   3.504442097657129*^9}, {3.50444281341171*^9, 3.5044428139117126`*^9}, {
   3.5044430726321187`*^9, 3.504443146601342*^9}, {3.5045035206839876`*^9, 
   3.5045035383248386`*^9}, {3.5045036011537676`*^9, 3.504503602185031*^9}, {
   3.5045036573263617`*^9, 3.5045036577013664`*^9}, {3.5045050699381933`*^9, 
   3.5045050708913302`*^9}, {3.5045059896843405`*^9, 
   3.5045060129502635`*^9}, {3.50450606696658*^9, 3.5045061859837284`*^9}, {
   3.5045064081271963`*^9, 3.5045066217080555`*^9}, {3.504506717381155*^9, 
   3.5045067453346376`*^9}, {3.504508182790537*^9, 3.5045082639165754`*^9}, {
   3.5045083214954376`*^9, 3.504508358105281*^9}, {3.5045084942584076`*^9, 
   3.5045084951054087`*^9}, {3.5045096393207464`*^9, 
   3.5045096552925625`*^9}, {3.504510118950203*^9, 3.5045101317631946`*^9}, {
   3.5045132391943808`*^9, 3.5045132505695267`*^9}, {3.5045133277267637`*^9, 
   3.5045133319924436`*^9}, {3.504513751810317*^9, 3.504513752091571*^9}, {
   3.504518934609375*^9, 3.504518937359375*^9}, {3.50459349654151*^9, 
   3.50459350426026*^9}, {3.5046006915205283`*^9, 3.504600709895646*^9}, {
   3.5046023483873515`*^9, 3.5046023486998854`*^9}, {3.506341963441907*^9, 
   3.5063419658012967`*^9}, {3.5068709438986144`*^9, 3.506870989477031*^9}, {
   3.506871445229948*^9, 3.5068714576675277`*^9}, {3.506871528667982*^9, 
   3.506871879529602*^9}, 3.524459588163906*^9, {3.5334145643473806`*^9, 
   3.5334145906808863`*^9}, {3.533415759933764*^9, 3.5334158052783575`*^9}, {
   3.5387702593274775`*^9, 3.5387703314585133`*^9}, {3.5513125853089867`*^9, 
   3.551312669205934*^9}, 3.5513127161932163`*^9, {3.551313278450421*^9, 
   3.5513132795474815`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "represents", " ", "Magnitude", " ", "of", " ", "Magnetic", 
     " ", "Field", " ", "in", " ", "Tesla", " ", 
     RowBox[{"vs", ".", " ", "Height"}], " ", "of", " ", "magnet", " ", 
     "center", " ", "for", " ", "a", " ", "bead", " ", "which", " ", "is", 
     " ", "directly", " ", "below", " ", "the", " ", "magnets", " ", "and", 
     " ", "perfectly", " ", 
     RowBox[{"aligned", ".", " ", "Note"}], " ", "that", " ", "in", " ", 
     "this", " ", "case"}], ",", " ", 
    RowBox[{
     RowBox[{
     "the", " ", "magnetic", " ", "field", " ", "points", " ", "only", " ", 
      "in", " ", "the"}], " ", "-", 
     RowBox[{"x", " ", 
      RowBox[{"direction", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmin", "=", 
     RowBox[{
      RowBox[{"-", "2.5"}], " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"7.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fxvzmag", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.5", "+", 
          RowBox[{
           SuperscriptBox["10", "3"], 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], ",", " ", 
         RowBox[{"-", 
          RowBox[{
           RowBox[{"B", "[", 
            RowBox[{"0", ",", " ", "0", ",", " ", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"zmin", "+", 
                RowBox[{"i", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
               ")"}]}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{"fxvzmag", ",", " ", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", " ", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"measH", ",", " ", 
       RowBox[{"PlotStyle", "\[Rule]", "  ", 
        RowBox[{"PointSize", "[", "Large", "]"}]}]}], "]"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "10"}], "}"}], ",", " ", "All"}], "}"}]}], 
     ",", "  ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Magnet Height\>\"", ",", "\"\<Field (T)\>\""}], "}"}]}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBmIQ/fDiBHtdmVeOXwJXgOk96fMjQXTS26gEED2jQDcF
RC8ompUGog9UPM8F0ZyVdnkgWi7qd4AekFa/xR8IorNjysNAdHFMJ5iWbvzO
ZwCk85qbREC0G++v8EAgPb03KgJEO4jfSwbRHtNfgGkXgaK0GiC9VrQsE0RP
WLa9AkSLrfGtB9FVW3w7QXTHljgwfVoz4FIdkL6kmQSmI+5c86oH0nF3HoHp
hrfb5oHoGbm7wLT8jarGBiAdEuc6AUQfY+Qx9dMF0o2HrMA04x57CH0SQjf+
cYHwL7hC+LJRED5bNIQ2SIPQ7tkQ+boiCN+/AkLProGIR9RC+CxNEDoLTP9T
0fqU7gSktd59A9F5Tme/TS595Riw9yaY/jv1r+0UIP07vtEORAMAQtrE2A==

  "]],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw10XtI01EUB/CpKw3DR86mOV9TerlkuVoF6T1ikxWhorlQyNksDYzKsBJC
hRAb5SPMx36zxxwqw2qpWMZK0pbW0o0NnWtaCC6Y+pdZapax2q/Tgcvlx++c
z/nCjZZdzDzryWAwBH+P+/5foyuU/4Hgjlcqyl0GQp1TqlrEbURBf9tJXnbQ
y2VZD9kncJeDFJ2QOnOzdfh/nqTJOaU8wxD5py0SH13PocmmEUK3C76RmvRr
5crGUVJI1wrROU3y3flmoqTn14i4/U36b49xYhpz1zopsXrHZSms6DHAj3dr
Km/Nhv0eoOVLhFqnHfN4QTY1scEYPk2M9DwTlupnpZ7F07hvIwwL9zqCzVPo
+UA1s9GZWWlHbxOEXq9/ZnhtQ88XknNiBxRmK+bZDKbCpw0Zn8fR84P5O8ZI
kcuCXgAUyBp4Xilm7A+AeFmqVJ1rRD8Q+pMsYcnlH3B+C7Cpqtq0hXe4Lwgk
JsnsznvD6LGgekeFurRGjx4LWMdmIix9Q+gFQyW7xZrgP4jeVjB0XJ5g8wbQ
Y0Nz7fpCr1yHXgiU9euZorgX6IXAeX2Tbcb3OXqhULbntvBGTB9626C34323
q7gX3y8MEgtOq+ZmuokH7XEg9EiK0vldix4HAh3LSRMXHhOao8IhgTPovWt7
FymivQio+2X+dJKlwXyRcMr05UmzoBPzRcHiR82PkYp23B8F951XruZ/VeN7
RsHPyf66vJttmCcaOpnpAn6iCvNHwxluxqOsyAfocaFKqs9ZWm1FjwuXSuY4
+10UobkxLnAOC1Mf8hWYJwZE3qKGeHkz5o+BLknh6nHPJvRiQXxUc/Bt613y
BwUrWio=
     "]]}, 
   {Hue[0.67, 0.6, 0.6], PointSize[Large], PointBox[CompressedData["
1:eJw10ltI03EUB/DlJqYhTv2bNvOfm7d/y5kLJLr5OxEjsvteZCLYpH80GE0F
RQcWYsuUrWWXh9VD5FojYU1EhiONsanlf92mDXNFMSIoZGWXSdkmTTo+nHP4
wJfz9BU36pRsEo/HkyVm9Yb11MOD4R8kfi9k/yj3k/9eIqGwc1oUfYVeJo01
xQE/8xq9QpRqrfjp/jnStC9tztq0DgwW1wXWNo/mAyeKCk1fQ+hk6HgGbOzv
mlPge6a85NrntXwqXOKLVR7BG/QG6E25cdTtDaLTIeoO9cXZWXQG6LoEk2Z5
gIzShoWTo0KIPJL8/lDzAp0J3bmdyZopDp0Fq5s2PEFnw6mhfJeMm0BTcD/S
oNIovegcUEiNMsEuD3ojFCW+t2nH0LmQoztN/+l2o/NA4PBcDTpc6E2wV74w
eeLYCFoEpTEl0UmH0fnwbaXdWWcZQm+G5rrFAWehA10ASyO+hutVg2gasjOY
2y0GO3oLvBzvOXxlj43Um71Rpr4QJNp2va3cihbDDO99UmrfHbQEltNmjIpZ
C7oI4vNmql99E10MPfZabsdEP7oEnreKNA/GTOhS+HJreufbd5fRZeC/q3D9
jF9EMxCrUlnpgS70VmjmVxOj8DxaCiYmkv64sgO9DQ6d9bup2lZ0ORzxLSYa
0YKWwQHu+GDn7nPoCvhUFqwuMGvQ2+HMeB7X28aSRBn1VEUl/PKtDwem1OQf
lfFS6A==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Magnet Height\"", TraditionalForm], 
    FormBox["\"Field (T)\"", TraditionalForm]},
  ImageSize->{592.4444384692596, Automatic},
  PlotRange->{{0, 10}, All},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5134145742502165`*^9, 3.5134145962033415`*^9}, 
   3.5134146365470915`*^9, 3.5134146774064665`*^9, 3.524476861755369*^9, 
   3.528622761377766*^9, 3.5513038780321813`*^9, 3.551306244656996*^9, 
   3.5513133204309273`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "represents", " ", "Magnitude", " ", "of", " ", "Magnetic", 
     " ", "Force", " ", "in", " ", "PicoNewtons", " ", 
     RowBox[{"vs", ".", " ", "Height"}], " ", "of", " ", "magnet", " ", 
     "bottom", " ", "for", " ", "a", " ", "bead", " ", "which", " ", "is", 
     " ", "directly", " ", "below", " ", "the", " ", "magnets", " ", "and", 
     " ", "perfectly", " ", 
     RowBox[{"aligned", ".", " ", "Note"}], " ", "that", " ", "in", " ", 
     "this", " ", "case"}], ",", " ", 
    RowBox[{
    "the", " ", "force", " ", "points", " ", "only", " ", "in", " ", "the", 
     " ", "z", " ", 
     RowBox[{"direction", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmin", "=", 
     RowBox[{"0.4", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"7.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fxvzmag", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4"}], "+", 
          RowBox[{
           SuperscriptBox["10", "3"], 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], ",", " ", 
         RowBox[{"1.4", "*", 
          SuperscriptBox["10", "12"], "*", 
          RowBox[{"Norm", "[", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", " ", "0", ",", " ", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"zmin", "+", 
                RowBox[{"i", "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
               ")"}]}]}], "]"}], "]"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"fxvzmag", ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Magnet Height (mm)\>\"", ",", " ", "\"\<Force(pN)\>\""}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5044359811524787`*^9, 3.5044360001526003`*^9}, {
   3.5044392056862907`*^9, 3.504439207733179*^9}, 3.5044397537835484`*^9, {
   3.5044430110379744`*^9, 3.5044430147098727`*^9}, 3.5044438188169737`*^9, {
   3.5045085436981583`*^9, 3.5045085495016823`*^9}, {3.50459359385401*^9, 
   3.504593594619635*^9}, {3.5046043011834598`*^9, 3.504604331246152*^9}, {
   3.524459024206195*^9, 3.5244590292844176`*^9}, {3.524459106176519*^9, 
   3.5244591070046597`*^9}, {3.524459314774909*^9, 3.524459324744169*^9}, {
   3.5244594581885014`*^9, 3.5244594685952845`*^9}, {3.5244598468285627`*^9, 
   3.5244598753451004`*^9}, 3.524460010583063*^9, {3.524460191572071*^9, 
   3.5244602265102634`*^9}, {3.5244604807026443`*^9, 
   3.5244604952341733`*^9}, {3.5244606994724693`*^9, 
   3.5244607163634186`*^9}, {3.524477117885287*^9, 3.5244771324168158`*^9}, {
   3.5244774587980824`*^9, 3.5244775235024495`*^9}, {3.528622878130755*^9, 
   3.528622886427842*^9}, {3.528623380534241*^9, 3.528623386737525*^9}, {
   3.5286235489448023`*^9, 3.528623566664006*^9}, {3.528623614462105*^9, 
   3.5286236172278004`*^9}, {3.5513056190022964`*^9, 
   3.5513056191738973`*^9}, {3.551305661746372*^9, 3.551305714162464*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1kg0s1GEcx++8/N28njsv5w5RUs6wsmY3y+9XZs1LLEflkrAjWqOsmkrZ
UYspmlRrxvQiSXlbyVuUIy+JvFTKS05ehunKu3mp8xy/7dmzZ8+z7/f7+zw/
y9Bo3zAVGo3mqFjr+2ZtLzF75BC3Brc5aod17epAYlrdKDVUxXRy7gQepRPk
c0Id+6woyV3XXphVy6FqwqmN+yE4Rr8sbkyg8I359clD5aPAFAunTGgU9pL3
kxBpx5R4cNWRbnvD6HubHKju5eXdK5v607B/NjeVI1XBJ5n1FsUxs6DP1RM4
JtCxnOjNAzNKdL7AjYYtD93KZlYXIcwh6365zRoMEP1laObdjO8fW4bfeR88
nZJXoZkpC5hoXgIV4vcP4rOrEv07FkDr2+MzezXpGBuVUDW6Ogd3iL8KrnjI
44K9Z8FUJHb+6aOKw6P+vvJ30/CU5FHDVvnJwBjhX3DoXzdUx3pvr5V81T+g
zEeheNAq9Xn2FOwLHvm8tVcDi24tMpIiJkGZl4GyscwtdcHj4PcrV6GoiSyO
1C86cQyInKsWRvvazE+0jkA4KW2MiAxp7xYMg5z0o4MrKadcdRuH4OK49S7G
C12kY4B22VkZKHnqYWGtUfo2p0FYd+uOZWJLlti8wWYANEm/+uhjdnApSL8P
2haEigT6KGC/nh+3+LHRPwurkpyvZvj1wBHBq6YLNSz0DGVLhp99BR7hwcai
HfXVZdwvILtkUHhAxsajU3zKJa8LcgkfA+Tea+uge3VCZPU5haQhSkUvg3up
jg1ehtjvIooaKmiH9XTj1kZYoWNdFhL9CZTzYoQz7j7mqf4fIQ72BFW6G2NR
NV/NPrAZkPA0xjSu03yIpBHUFbRSTnNQu8mKny5t2ODLwVIZg3vcsh5S6+Z2
BqaZID/OVjPpQR0ICW8udpVcYUzz3wNpt5SLomShGTu/FpTzzMOKjC2lyfy3
kEMA8pAl0ggS9FRCGPkPU7wWYJ/NKi6H/zHzZM8=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Magnet Height (mm)\"", TraditionalForm], 
    FormBox["\"Force(pN)\"", TraditionalForm]},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.5513057691213603`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.551305671621189*^9, 3.5513056726195908`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Here", " ", "we", " ", "show", " ", "the", " ", "dependence", " ", "of", 
    " ", "the", " ", "magnitude", " ", "of", " ", "the", " ", "magnetic", " ",
     "force", " ", "on", " ", "a", " ", "myone", " ", "bead", " ", "as", " ", 
    "it", " ", "varies", " ", "across", " ", "the", " ", "field", " ", "of", 
    " ", "view", " ", "in", " ", "the", " ", "x", " ", "and", " ", "y", " ", 
    "directions", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"labelled", " ", "in", " ", "mm"}], ",", " ", 
      RowBox[{"field", " ", "of", " ", 
       RowBox[{"view", " ", "~", "400"}], "x400", " ", "microns"}]}], ")"}], 
    " ", "for", " ", "a", " ", "magnet", " ", "height", " ", "of", " ", "2", 
    RowBox[{"mm", " ", ".", " ", "Note"}], " ", "the", " ", "change", " ", 
    "is", " ", "less", " ", "than", " ", "1", 
    RowBox[{"%", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmag", "=", 
     RowBox[{
      RowBox[{"-", "2.4"}], "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xmax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"xmin", "=", 
     RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ymax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"ymin", "=", 
     RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fvxy", "=", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
       SuperscriptBox[
        RowBox[{"(", "npts", ")"}], "2"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "<", 
      RowBox[{"(", "npts", ")"}]}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"xm", "=", 
         RowBox[{"(", 
          RowBox[{"xmin", "+", 
           RowBox[{
            RowBox[{"(", "i", ")"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xmax", "-", "xmin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "0"}], ",", " ", 
         RowBox[{"j", "<", " ", 
          RowBox[{"(", "npts", ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"j", "++"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"ym", "=", 
              RowBox[{"(", 
               RowBox[{"ymin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"j", "-", "1"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"ymax", "-", "ymin"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"fvxy", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", "npts", ")"}], "*", 
                  RowBox[{"(", "i", ")"}]}], "+", "j"}], "]"}], "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"xm", ",", "ym", ",", 
                RowBox[{"1.4", "*", 
                 SuperscriptBox["10", "12"], "*", 
                 RowBox[{"Norm", "[", 
                  RowBox[{"F", "[", 
                   RowBox[{"xm", ",", "ym", ",", "zmag"}], "]"}], "]"}]}]}], 
               "}"}]}], ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]",
            "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Norm", "[", 
     RowBox[{"F", "[", 
      RowBox[{"xmax", ",", "0", ",", "zmag"}], "]"}], "]"}], "/", 
    RowBox[{"Norm", "[", 
     RowBox[{"F", "[", 
      RowBox[{"0", ",", "0", ",", "zmag"}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot3D", "[", 
    RowBox[{"fvxy", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], ",", "All"}], "}"}]}], ",", 
     " ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"X", ",", " ", "Y", ",", " ", "\"\<Force (pN)\>\""}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5045161258432026`*^9, 3.5045161392514257`*^9}, {
   3.504516202166936*^9, 3.504516432703556*^9}, {3.50451655128927*^9, 
   3.5045165771503*^9}, {3.504516623808344*^9, 3.50451665691899*^9}, {
   3.504516721968363*^9, 3.5045167437035723`*^9}, {3.5045168149250574`*^9, 
   3.5045168513327055`*^9}, {3.5045169280693765`*^9, 3.504516928444386*^9}, {
   3.5045169792425613`*^9, 3.5045170016493845`*^9}, {3.5045170952299056`*^9, 
   3.5045170957299185`*^9}, {3.5045171389341493`*^9, 
   3.5045172035137596`*^9}, {3.5045174187210164`*^9, 
   3.5045174387370253`*^9}, {3.5045175841304417`*^9, 
   3.5045176248499737`*^9}, {3.5045176590381303`*^9, 3.5045176991013994`*^9}, 
   3.504517730727007*^9, {3.504518546015625*^9, 3.504518547796875*^9}, 
   3.50451868234375*^9, {3.504518777625*^9, 3.504518794765625*^9}, 
   3.504518885703125*^9, {3.50451904915625*^9, 3.504519096671875*^9}, {
   3.504519152859375*^9, 3.504519167109375*^9}, {3.50451929087048*^9, 
   3.504519314417392*^9}, {3.50451940085816*^9, 3.504519430206224*^9}, {
   3.5045196395157194`*^9, 3.5045196473958836`*^9}, {3.5045196935063868`*^9, 
   3.504519693654758*^9}, {3.5045198166380796`*^9, 3.504519818830678*^9}, {
   3.5045202049368258`*^9, 3.5045202197763453`*^9}, {3.5045202863417397`*^9, 
   3.504520297067425*^9}, {3.5045203472198763`*^9, 3.5045203719426937`*^9}, {
   3.5046043542619247`*^9, 3.504604451528172*^9}, {3.5046044903877954`*^9, 
   3.5046044961847076`*^9}, {3.5102933334852033`*^9, 3.510293387392488*^9}, {
   3.510293640740605*^9, 3.5102936510531707`*^9}, {3.5102938093041835`*^9, 
   3.5102938156948495`*^9}, {3.5102951479461946`*^9, 
   3.5102951484618196`*^9}, {3.524475621247177*^9, 3.5244756242472343`*^9}, 
   3.528622438557002*^9, 3.528622502683644*^9, {3.528622801535044*^9, 
   3.528622802035057*^9}, {3.5286242880730987`*^9, 3.5286242892918797`*^9}, 
   3.5286288314706564`*^9, {3.5513058550619116`*^9, 3.551305874624346*^9}, {
   3.55130595100208*^9, 3.5513059527960835`*^9}}],

Cell[BoxData["1.0032321478797461`"], "Output",
 CellChangeTimes->{3.5244606866440983`*^9, 3.5244756519665165`*^9, 
  3.528622623233605*^9, 3.5286226836882772`*^9, 3.5286228282544785`*^9, 
  3.528624318995765*^9, 3.5286288627214565`*^9, 3.551305926198036*^9, 
  3.5513059792849293`*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1WnlcVFUbHnHJLUTHFTSXQbNxA3XQHPVmmmmJIiKL9JkiJmUu4Fa45pqo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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlGtoiFEcxt8zZsaY+521D2TMKMXQXGs223ILjbnWSpQhpmGWjcJklCEj
Xxblrqb5MLemCKUUPvjgg/t9Nvf77+n///Dred7znve85/zPc07ysqJZq2Ki
KCqDVpAC8VAI9ZAAI+AUpMPYEEXFaCfIha3QFSrhCVTDWfocRTXucwg8l6N1
wXwX/G14Bv0Ebe2CfXsTzfA5ZMEW6AgbIw0URaVIDfoA7QFrYSkkwg6YCW1h
PByCPtCb/jd8zqv1nue96BX0KdpX/YLNR74XPsnHGazveB6GvvZaqCajYWSw
5+Fqx6d5H9WqNdSqNt6uPp9hGqTRVglD8EM1DrTxWnyD+VpXsLVpjSUwiOf+
6AvtE74CPY6mwAD8S5gMHSAfugefFzyEKrhG236tDw5qjsFqdhKNhZ3408Fq
pFrt9hxoLxb6ONrre/APNsNh+v9FN6ne+CZ0EmTj3yovkIF/g46Bcfh3Xtvz
8Mf3tjrYfDSHuT6fXfh53l/jjMHv87qsgTyfq/z0YKp3Tb5Hl+Cjz2c27z+g
E5URfJX31/fvYQLMoG0PpOKPaE+C5To/WJaU5xpogM7Kqu9pjupDnxbf3wL8
l8jOx+Jg/Qtgveod7Iy9gt++X5fdL4GV/q3GHO65Uzby4DssgHXBvMYsw3/1
zGzG/9Q/YQP+l49Zgp/jNcmGH7AIimmvQzOhPFj2NH4p/hM6FSrwzZGdxe3+
L+WrCN8Y2blTrZq9f26wPVUejng2lJOjwTKj83sMHxcskw3B9kj7kuX/1Xxy
gt0n3eA+JHvOlf84P7/X0cjvk7uRrV3rWh5sjcpsYbDzsg1fj8b42bmItg92
Di6g8coW/ip6J7Jz9yiye+kAes7rqdquCJYZ3TFTguVEWT3jGVOWMj3zujNH
4Qf6naJzqvE1nxPB7iL9t9Hno3/d8n2JVR9I8rOvuzTG79JaNMHvEGUp0XOr
+6TF9znV7zfdgT19jT3xjyM7mzqP6bT9B6G4qjY=
         "]], Polygon3DBox[CompressedData["
1:eJxNl+m3iFUUxs9pUquEa47kStwkNKBCZKiUyjxUVJeQ8WbIUOEqQygZiiRE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         "]], Polygon3DBox[CompressedData["
1:eJwtlWtMz1EYx8+vUGHDbC6p0RvXijGXoouakmIKESmau63mUkg3hYkXmEtR
LlvJ3MtCRi5lyn28wMbmhVvud+Xu8+w8Lz77fs85///5n/Oc53n+Pilpcaku
xpg4aA0RjjFjYCyEMn4P0fhxEAORjD/BRHyIrsfi42AYDIUREMD8a2P3iYQo
GM34AyzCL4TFMIvxL5iLnwMLIInxD+iE7wiv8P7QWc8wCh8ke8NnmMlcNPoN
kmVPSJQzM/6q60kwFTYyboMmwHT9vfmOPVMyaz/1PqF61kn4yRAPhRIj3Wea
Y9fkTh+hBs5Cd+Y80afgie8BgRITjcdIOT90hS7QTT6jnz+PPwcXYAtjNzQD
5kl85B4al+PM7UDboiegEu4wvq17bEbvwxn8WvQGPICHsJu5XVAC2Yz/wSl8
Aerq2O/UQCmsZu4v7MHvhXrYytgDfYQ+NvastXBR19zR6+g1KMfnow6aJfHG
N0M2Psex+2bpGfbh98Nlvbu7/t4Vx67JWQ16E7mle8xAWyAXn+dYTZQYQAM0
Qj5zEZqzBRIPx2qk5s46/HqJJ2yHYr33H2Pzzg/GwwQYxFoDXIVG2KlvUAgb
oIlxf9iEr4ADcFDfwFX3LnLsG2RpbDM03yXvVuBXwlJYAsv1js26lqy1sgqf
qevLIF3v3aJrUlO/oVbeR+8oteIB/Yw9a7W+jYtj3/+05pLcqR1aBSfhKByB
Y1o7kv/yrmV6xwLdQ/qB9JBYCIZ3xtZgPDoFouAL3IO7xsZRcvgJlIIvdGCu
Dq2HEslVY+tE6qnY2FoZjA4BL3gGlzTf3TR36hytO133wntL/koew3Pwht7M
vVDfE98LfCAcwhzbB0P0Hi/lM9AX+kgMHdsPUvCzJZ7QSmsmF58DmZpDvswN
AH/H9iOJgXg/GOjYviU9Sny65APEGNvLDjN3SN+gUH+jSd9Q+oH0hfb6Nnn4
NZJ7xva3NEjVXJK6+w5B+ED0LVRClbG9ejgE6NobY2s1HA2DBP1uOZQZ2+Ol
lx0xtpcF6Hdk72DJd3yFsf8ZUnfVxtbKNnQ7FGl+/QfPAsn/
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{37, 25, 226, 225, 224, 24, 222, 221, 220, 219, 23, 218, 217, 
       216, 215, 22, 213, 212, 211, 21, 142, 141, 140, 16, 118, 117, 116, 115,
        11, 80, 79, 78, 77, 6, 51, 50, 49, 1, 153, 154, 155, 2, 157, 158, 159,
        160, 3, 161, 162, 163, 164, 4, 165, 166, 167, 5, 105, 106, 107, 108, 
       109, 110, 111, 15, 97, 98, 99, 100, 20, 35, 36, 37}]}, {
      Line3DBox[{155, 152, 281, 283, 286, 170, 274, 276, 277, 48, 183, 300, 
       243, 348, 350, 353, 198, 334, 335, 114, 213}], 
      Line3DBox[{160, 296, 297, 231, 293, 175, 323, 237, 336, 338, 341, 187, 
       367, 246, 380, 382, 385, 202, 257, 436, 438, 441, 218}], 
      Line3DBox[{4, 59, 60, 61, 9, 101, 102, 103, 104, 14, 126, 127, 128, 129,
        19, 146, 147, 148, 24}], 
      Line3DBox[{164, 171, 314, 316, 319, 179, 357, 249, 374, 376, 379, 192, 
       405, 253, 412, 414, 417, 207, 214, 448, 450, 453, 222}], 
      Line3DBox[{167, 180, 386, 388, 391, 394, 396, 397, 398, 156, 195, 426, 
       260, 342, 344, 347, 210, 223, 430, 432, 435, 226}], 
      Line3DBox[{211, 400, 399, 112, 196, 351, 245, 303, 301, 298, 181, 306, 
       305, 304, 233, 272, 168, 284, 228, 280, 278, 153}], 
      Line3DBox[{215, 203, 423, 421, 418, 199, 188, 373, 371, 368, 364, 184, 
       240, 329, 327, 324, 320, 172, 290, 288, 287, 229, 157}], 
      Line3DBox[{219, 265, 447, 445, 442, 204, 256, 411, 409, 406, 402, 189, 
       252, 363, 361, 358, 354, 176, 236, 313, 311, 308, 161}], 
      Line3DBox[{224, 433, 267, 456, 454, 208, 345, 262, 429, 427, 424, 193, 
       270, 269, 268, 232, 392, 389, 242, 332, 330, 165}], 
      Line3DBox[{154, 279, 227, 282, 285, 169, 273, 275, 47, 307, 182, 299, 
       302, 244, 349, 352, 197, 333, 113, 401, 212}], 
      Line3DBox[{158, 294, 230, 289, 291, 173, 321, 325, 328, 239, 339, 185, 
       365, 369, 372, 248, 383, 200, 419, 422, 259, 439, 216}], 
      Line3DBox[{159, 295, 30, 292, 174, 322, 326, 238, 337, 340, 186, 366, 
       370, 247, 381, 384, 201, 420, 258, 437, 440, 217}], 
      Line3DBox[{162, 309, 312, 235, 317, 177, 355, 359, 362, 251, 377, 190, 
       403, 407, 410, 255, 415, 205, 443, 446, 264, 451, 220}], 
      Line3DBox[{163, 310, 234, 315, 318, 178, 356, 360, 250, 375, 378, 191, 
       404, 408, 254, 413, 416, 206, 444, 263, 449, 452, 221}], 
      Line3DBox[{166, 331, 241, 387, 390, 393, 395, 43, 271, 194, 425, 428, 
       261, 343, 346, 209, 455, 266, 431, 434, 225}]}, {
      Line3DBox[{37, 435, 434, 433, 151, 148, 453, 452, 451, 145, 447, 135, 
       441, 440, 439, 132, 423, 121, 114, 401, 400, 142}], 
      Line3DBox[{49, 278, 279, 26, 281, 32, 287, 29, 294, 295, 296, 38, 308, 
       309, 310, 56, 314, 59, 330, 331, 70, 386, 105}], 
      Line3DBox[{77, 45, 272, 273, 274, 52, 320, 321, 322, 323, 62, 81, 354, 
       355, 356, 357, 93, 101, 41, 392, 393, 394, 108}], 
      Line3DBox[{20, 210, 209, 208, 19, 207, 206, 205, 204, 18, 202, 201, 200,
        199, 17, 198, 197, 196, 16}], 
      Line3DBox[{100, 347, 346, 345, 139, 129, 417, 416, 415, 125, 411, 69, 
       385, 384, 383, 92, 373, 88, 353, 352, 351, 76, 118}], 
      Line3DBox[{111, 398, 44, 271, 270, 104, 379, 378, 377, 96, 363, 84, 341,
        340, 339, 65, 329, 55, 48, 307, 306, 80}], 
      Line3DBox[{115, 298, 299, 300, 73, 85, 364, 365, 366, 367, 89, 66, 402, 
       403, 404, 405, 122, 126, 424, 425, 426, 136, 97}], 
      Line3DBox[{140, 112, 333, 334, 119, 418, 419, 420, 130, 436, 133, 442, 
       443, 444, 143, 448, 146, 454, 455, 149, 430, 35}], 
      Line3DBox[{36, 432, 431, 150, 456, 147, 450, 449, 144, 446, 445, 134, 
       438, 437, 131, 422, 421, 120, 335, 113, 399, 141}], 
      Line3DBox[{50, 280, 27, 282, 283, 33, 288, 289, 30, 297, 39, 311, 312, 
       57, 315, 316, 60, 332, 71, 387, 388, 106}], 
      Line3DBox[{51, 28, 284, 285, 286, 34, 290, 291, 292, 293, 31, 40, 313, 
       58, 317, 318, 319, 61, 72, 389, 390, 391, 107}], 
      Line3DBox[{78, 304, 46, 275, 276, 53, 324, 325, 326, 63, 336, 82, 358, 
       359, 360, 94, 374, 102, 268, 42, 395, 396, 109}], 
      Line3DBox[{79, 305, 47, 277, 54, 327, 328, 64, 337, 338, 83, 361, 362, 
       95, 375, 376, 103, 269, 43, 397, 110}], 
      Line3DBox[{98, 342, 137, 428, 427, 127, 412, 123, 408, 407, 406, 67, 
       380, 90, 370, 369, 368, 86, 348, 74, 302, 301, 116}], 
      Line3DBox[{99, 344, 343, 138, 429, 128, 414, 413, 124, 410, 409, 68, 
       382, 381, 91, 372, 371, 87, 350, 349, 75, 303, 117}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJyFmndUzv///0OKjKhUJCWhYSS7vHtIZFSEaFO0aAot0lAiSlNa2nvvhJ5K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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["X", TraditionalForm], 
    FormBox["Y", TraditionalForm], 
    FormBox["\"Force (pN)\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{-0.0002, 0.0002}, {-0.0002, 0.0002}, All},
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5244606866440983`*^9, 3.5244756519665165`*^9, 
  3.528622623233605*^9, 3.5286226836882772`*^9, 3.5286228282544785`*^9, 
  3.528624318995765*^9, 3.5286288627214565`*^9, 3.551305926198036*^9, 
  3.551305980782532*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "same", " ", "for", " ", "magnet", " ", "height", " ", "of", " ", "1", 
     " ", 
     RowBox[{"mm", "/", " ", "Note"}]}], ",", " ", 
    RowBox[{
    "here", " ", "we", " ", "plot", " ", "the", " ", "magnitude", " ", "of", 
     " ", "the", " ", "force", " ", "in", " ", "the", " ", "vertical", " ", 
     "direction"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmag", "=", 
     RowBox[{
      RowBox[{"-", "1.4"}], "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xmax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"xmin", "=", 
     RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ymax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"ymin", "=", 
     RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fvxyb", "=", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
       SuperscriptBox[
        RowBox[{"(", "npts", ")"}], "2"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "<", 
      RowBox[{"(", "npts", ")"}]}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"xm", "=", 
         RowBox[{"(", 
          RowBox[{"xmin", "+", 
           RowBox[{
            RowBox[{"(", "i", ")"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xmax", "-", "xmin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "0"}], ",", " ", 
         RowBox[{"j", "<", " ", 
          RowBox[{"(", "npts", ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"j", "++"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"ym", "=", 
              RowBox[{"(", 
               RowBox[{"ymin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"j", "-", "1"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"ymax", "-", "ymin"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"fvxyb", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", "npts", ")"}], "*", 
                  RowBox[{"(", "i", ")"}]}], "+", "j"}], "]"}], "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"xm", ",", "ym", ",", 
                RowBox[{"1.4", "*", 
                 SuperscriptBox["10", "12"], "*", 
                 RowBox[{"Norm", "[", 
                  RowBox[{"F", "[", 
                   RowBox[{"xm", ",", "ym", ",", "zmag"}], "]"}], "]"}]}]}], 
               "}"}]}], ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]",
            "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Norm", "[", 
     RowBox[{"F", "[", 
      RowBox[{"xmax", ",", "0", ",", "zmag"}], "]"}], "]"}], "/", 
    RowBox[{"Norm", "[", 
     RowBox[{"F", "[", 
      RowBox[{"0", ",", "0", ",", "zmag"}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot3D", "[", 
    RowBox[{"fvxyb", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], ",", "All"}], "}"}]}], ",", 
     " ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"X", ",", " ", "Y", ",", " ", "\"\<Force (pN)\>\""}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.510293354048098*^9, 3.5102933951582623`*^9}, 
   3.510293860757638*^9, {3.5102942893211946`*^9, 3.5102943233211946`*^9}, {
   3.5102945831024446`*^9, 3.5102946352430696`*^9}, {3.5102947202899446`*^9, 
   3.5102947295399446`*^9}, {3.5102948010243196`*^9, 
   3.5102948421649446`*^9}, {3.5102950508680696`*^9, 
   3.5102950511024446`*^9}, {3.524460757270454*^9, 3.5244607573954563`*^9}, {
   3.5244799287048783`*^9, 3.5244799395644617`*^9}, {3.5244800158940525`*^9, 
   3.524480015972179*^9}, {3.5244800652231245`*^9, 3.524480075863954*^9}, {
   3.5244801648969135`*^9, 3.5244801649906654`*^9}, 3.524480293946266*^9, {
   3.5244810743900747`*^9, 3.5244811290773277`*^9}, {3.5260165413079576`*^9, 
   3.5260165607303295`*^9}, 3.5286231090585413`*^9, {3.528628566901384*^9, 
   3.528628580698612*^9}, {3.528630590656316*^9, 3.528630592125103*^9}, 
   3.5513060020453696`*^9}],

Cell[BoxData["1.0121598934739575`"], "Output",
 CellChangeTimes->{3.5244800822078257`*^9, 3.5244801765221367`*^9, 
  3.5286230925268683`*^9, 3.528623141637501*^9, 3.52862445454611*^9, 
  3.5286286117306566`*^9, 3.5286306246259356`*^9, 3.5513060556314635`*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1Wnlcjdkbb7mlGlNyy1JpuyRXyM9gcvFmiSFkEAYZpRoGKRr8LCPbDIYZ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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlGtoiFEcxt8zZsaY+521D2TMKMXQXGs223ILjbnWSpQhpmGWjcJklCEj
Xxblrqb5MLemCKUUPvjgg/t9Nvf77+n///Dred7znve85/zPc07ysqJZq2Ki
KCqDVpAC8VAI9ZAAI+AUpMPYEEXFaCfIha3QFSrhCVTDWfocRTXucwg8l6N1
wXwX/G14Bv0Ebe2CfXsTzfA5ZMEW6AgbIw0URaVIDfoA7QFrYSkkwg6YCW1h
PByCPtCb/jd8zqv1nue96BX0KdpX/YLNR74XPsnHGazveB6GvvZaqCajYWSw
5+Fqx6d5H9WqNdSqNt6uPp9hGqTRVglD8EM1DrTxWnyD+VpXsLVpjSUwiOf+
6AvtE74CPY6mwAD8S5gMHSAfugefFzyEKrhG236tDw5qjsFqdhKNhZ3408Fq
pFrt9hxoLxb6ONrre/APNsNh+v9FN6ne+CZ0EmTj3yovkIF/g46Bcfh3Xtvz
8Mf3tjrYfDSHuT6fXfh53l/jjMHv87qsgTyfq/z0YKp3Tb5Hl+Cjz2c27z+g
E5URfJX31/fvYQLMoG0PpOKPaE+C5To/WJaU5xpogM7Kqu9pjupDnxbf3wL8
l8jOx+Jg/Qtgveod7Iy9gt++X5fdL4GV/q3GHO65Uzby4DssgHXBvMYsw3/1
zGzG/9Q/YQP+l49Zgp/jNcmGH7AIimmvQzOhPFj2NH4p/hM6FSrwzZGdxe3+
L+WrCN8Y2blTrZq9f26wPVUejng2lJOjwTKj83sMHxcskw3B9kj7kuX/1Xxy
gt0n3eA+JHvOlf84P7/X0cjvk7uRrV3rWh5sjcpsYbDzsg1fj8b42bmItg92
Di6g8coW/ip6J7Jz9yiye+kAes7rqdquCJYZ3TFTguVEWT3jGVOWMj3zujNH
4Qf6naJzqvE1nxPB7iL9t9Hno3/d8n2JVR9I8rOvuzTG79JaNMHvEGUp0XOr
+6TF9znV7zfdgT19jT3xjyM7mzqP6bT9B6G4qjY=
         "]], Polygon3DBox[CompressedData["
1:eJxNl+m3iFUUxs9pUquEa47kStwkNKBCZKiUyjxUVJeQ8WbIUOEqQygZiiRE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         "]], Polygon3DBox[CompressedData["
1:eJwtlWtMz1EYx8+vUGHDbC6p0RvXijGXoouakmIKESmau63mUkg3hYkXmEtR
LlvJ3MtCRi5lyn28wMbmhVvud+Xu8+w8Lz77fs85///5n/Oc53n+Pilpcaku
xpg4aA0RjjFjYCyEMn4P0fhxEAORjD/BRHyIrsfi42AYDIUREMD8a2P3iYQo
GM34AyzCL4TFMIvxL5iLnwMLIInxD+iE7wiv8P7QWc8wCh8ke8NnmMlcNPoN
kmVPSJQzM/6q60kwFTYyboMmwHT9vfmOPVMyaz/1PqF61kn4yRAPhRIj3Wea
Y9fkTh+hBs5Cd+Y80afgie8BgRITjcdIOT90hS7QTT6jnz+PPwcXYAtjNzQD
5kl85B4al+PM7UDboiegEu4wvq17bEbvwxn8WvQGPICHsJu5XVAC2Yz/wSl8
Aerq2O/UQCmsZu4v7MHvhXrYytgDfYQ+NvastXBR19zR6+g1KMfnow6aJfHG
N0M2Psex+2bpGfbh98Nlvbu7/t4Vx67JWQ16E7mle8xAWyAXn+dYTZQYQAM0
Qj5zEZqzBRIPx2qk5s46/HqJJ2yHYr33H2Pzzg/GwwQYxFoDXIVG2KlvUAgb
oIlxf9iEr4ADcFDfwFX3LnLsG2RpbDM03yXvVuBXwlJYAsv1js26lqy1sgqf
qevLIF3v3aJrUlO/oVbeR+8oteIB/Yw9a7W+jYtj3/+05pLcqR1aBSfhKByB
Y1o7kv/yrmV6xwLdQ/qB9JBYCIZ3xtZgPDoFouAL3IO7xsZRcvgJlIIvdGCu
Dq2HEslVY+tE6qnY2FoZjA4BL3gGlzTf3TR36hytO133wntL/koew3Pwht7M
vVDfE98LfCAcwhzbB0P0Hi/lM9AX+kgMHdsPUvCzJZ7QSmsmF58DmZpDvswN
AH/H9iOJgXg/GOjYviU9Sny65APEGNvLDjN3SN+gUH+jSd9Q+oH0hfb6Nnn4
NZJ7xva3NEjVXJK6+w5B+ED0LVRClbG9ejgE6NobY2s1HA2DBP1uOZQZ2+Ol
lx0xtpcF6Hdk72DJd3yFsf8ZUnfVxtbKNnQ7FGl+/QfPAsn/
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{37, 25, 226, 225, 224, 24, 222, 221, 220, 219, 23, 218, 217, 
       216, 215, 22, 213, 212, 211, 21, 142, 141, 140, 16, 118, 117, 116, 115,
        11, 80, 79, 78, 77, 6, 51, 50, 49, 1, 153, 154, 155, 2, 157, 158, 159,
        160, 3, 161, 162, 163, 164, 4, 165, 166, 167, 5, 105, 106, 107, 108, 
       109, 110, 111, 15, 97, 98, 99, 100, 20, 35, 36, 37}]}, {
      Line3DBox[{155, 152, 281, 283, 286, 170, 274, 276, 277, 48, 183, 300, 
       243, 348, 350, 353, 198, 334, 335, 114, 213}], 
      Line3DBox[{160, 296, 297, 231, 293, 175, 323, 237, 336, 338, 341, 187, 
       367, 246, 380, 382, 385, 202, 257, 436, 438, 441, 218}], 
      Line3DBox[{4, 59, 60, 61, 9, 101, 102, 103, 104, 14, 126, 127, 128, 129,
        19, 146, 147, 148, 24}], 
      Line3DBox[{164, 171, 314, 316, 319, 179, 357, 249, 374, 376, 379, 192, 
       405, 253, 412, 414, 417, 207, 214, 448, 450, 453, 222}], 
      Line3DBox[{167, 180, 386, 388, 391, 394, 396, 397, 398, 156, 195, 426, 
       260, 342, 344, 347, 210, 223, 430, 432, 435, 226}], 
      Line3DBox[{211, 400, 399, 112, 196, 351, 245, 303, 301, 298, 181, 306, 
       305, 304, 233, 272, 168, 284, 228, 280, 278, 153}], 
      Line3DBox[{215, 203, 423, 421, 418, 199, 188, 373, 371, 368, 364, 184, 
       240, 329, 327, 324, 320, 172, 290, 288, 287, 229, 157}], 
      Line3DBox[{219, 265, 447, 445, 442, 204, 256, 411, 409, 406, 402, 189, 
       252, 363, 361, 358, 354, 176, 236, 313, 311, 308, 161}], 
      Line3DBox[{224, 433, 267, 456, 454, 208, 345, 262, 429, 427, 424, 193, 
       270, 269, 268, 232, 392, 389, 242, 332, 330, 165}], 
      Line3DBox[{154, 279, 227, 282, 285, 169, 273, 275, 47, 307, 182, 299, 
       302, 244, 349, 352, 197, 333, 113, 401, 212}], 
      Line3DBox[{158, 294, 230, 289, 291, 173, 321, 325, 328, 239, 339, 185, 
       365, 369, 372, 248, 383, 200, 419, 422, 259, 439, 216}], 
      Line3DBox[{159, 295, 30, 292, 174, 322, 326, 238, 337, 340, 186, 366, 
       370, 247, 381, 384, 201, 420, 258, 437, 440, 217}], 
      Line3DBox[{162, 309, 312, 235, 317, 177, 355, 359, 362, 251, 377, 190, 
       403, 407, 410, 255, 415, 205, 443, 446, 264, 451, 220}], 
      Line3DBox[{163, 310, 234, 315, 318, 178, 356, 360, 250, 375, 378, 191, 
       404, 408, 254, 413, 416, 206, 444, 263, 449, 452, 221}], 
      Line3DBox[{166, 331, 241, 387, 390, 393, 395, 43, 271, 194, 425, 428, 
       261, 343, 346, 209, 455, 266, 431, 434, 225}]}, {
      Line3DBox[{37, 435, 434, 433, 151, 148, 453, 452, 451, 145, 447, 135, 
       441, 440, 439, 132, 423, 121, 114, 401, 400, 142}], 
      Line3DBox[{49, 278, 279, 26, 281, 32, 287, 29, 294, 295, 296, 38, 308, 
       309, 310, 56, 314, 59, 330, 331, 70, 386, 105}], 
      Line3DBox[{77, 45, 272, 273, 274, 52, 320, 321, 322, 323, 62, 81, 354, 
       355, 356, 357, 93, 101, 41, 392, 393, 394, 108}], 
      Line3DBox[{20, 210, 209, 208, 19, 207, 206, 205, 204, 18, 202, 201, 200,
        199, 17, 198, 197, 196, 16}], 
      Line3DBox[{100, 347, 346, 345, 139, 129, 417, 416, 415, 125, 411, 69, 
       385, 384, 383, 92, 373, 88, 353, 352, 351, 76, 118}], 
      Line3DBox[{111, 398, 44, 271, 270, 104, 379, 378, 377, 96, 363, 84, 341,
        340, 339, 65, 329, 55, 48, 307, 306, 80}], 
      Line3DBox[{115, 298, 299, 300, 73, 85, 364, 365, 366, 367, 89, 66, 402, 
       403, 404, 405, 122, 126, 424, 425, 426, 136, 97}], 
      Line3DBox[{140, 112, 333, 334, 119, 418, 419, 420, 130, 436, 133, 442, 
       443, 444, 143, 448, 146, 454, 455, 149, 430, 35}], 
      Line3DBox[{36, 432, 431, 150, 456, 147, 450, 449, 144, 446, 445, 134, 
       438, 437, 131, 422, 421, 120, 335, 113, 399, 141}], 
      Line3DBox[{50, 280, 27, 282, 283, 33, 288, 289, 30, 297, 39, 311, 312, 
       57, 315, 316, 60, 332, 71, 387, 388, 106}], 
      Line3DBox[{51, 28, 284, 285, 286, 34, 290, 291, 292, 293, 31, 40, 313, 
       58, 317, 318, 319, 61, 72, 389, 390, 391, 107}], 
      Line3DBox[{78, 304, 46, 275, 276, 53, 324, 325, 326, 63, 336, 82, 358, 
       359, 360, 94, 374, 102, 268, 42, 395, 396, 109}], 
      Line3DBox[{79, 305, 47, 277, 54, 327, 328, 64, 337, 338, 83, 361, 362, 
       95, 375, 376, 103, 269, 43, 397, 110}], 
      Line3DBox[{98, 342, 137, 428, 427, 127, 412, 123, 408, 407, 406, 67, 
       380, 90, 370, 369, 368, 86, 348, 74, 302, 301, 116}], 
      Line3DBox[{99, 344, 343, 138, 429, 128, 414, 413, 124, 410, 409, 68, 
       382, 381, 91, 372, 371, 87, 350, 349, 75, 303, 117}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJyNmnk0Ve3//pVI4qmQniQlRGmgNKrekQolQyhDGUpRNEjmOTInkUiZ53me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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["X", TraditionalForm], 
    FormBox["Y", TraditionalForm], 
    FormBox["\"Force (pN)\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{363.6360366037443, 264.87200755247085`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{-0.0002, 0.0002}, {-0.0002, 0.0002}, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  ViewPoint->{1.337045510612694, -2.5758512554862145`, 1.7399136795141645`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.5244800822078257`*^9, 3.5244801765221367`*^9, 
  3.5286230925268683`*^9, 3.528623141637501*^9, 3.52862445454611*^9, 
  3.5286286117306566`*^9, 3.5286306246259356`*^9, 3.5513060556626635`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Here", " ", "same", " ", "magnet", " ", "height", " ", "but", " ", "we", 
    " ", "calculte", " ", "the", " ", "force", " ", "in", " ", "the", " ", 
    "lateral", " ", "direction"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmag", "=", 
     RowBox[{
      RowBox[{"-", "1.4"}], "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xmax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"xmin", "=", 
     RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ymax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"ymin", "=", 
     RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fvxyb", "=", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
       SuperscriptBox[
        RowBox[{"(", "npts", ")"}], "2"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "<", 
      RowBox[{"(", "npts", ")"}]}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"xm", "=", 
         RowBox[{"(", 
          RowBox[{"xmin", "+", 
           RowBox[{
            RowBox[{"(", "i", ")"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xmax", "-", "xmin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "0"}], ",", " ", 
         RowBox[{"j", "<", " ", 
          RowBox[{"(", "npts", ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"j", "++"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"ym", "=", 
              RowBox[{"(", 
               RowBox[{"ymin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"j", "-", "1"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"ymax", "-", "ymin"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"fvxyb", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", "npts", ")"}], "*", 
                  RowBox[{"(", "i", ")"}]}], "+", "j"}], "]"}], "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"xm", ",", "ym", ",", 
                RowBox[{"1.4", "*", 
                 SuperscriptBox["10", "12"], "*", 
                 RowBox[{"Fx", "[", 
                  RowBox[{"xm", ",", "ym", ",", "zmag"}], "]"}]}]}], "}"}]}], 
             ";"}]}], "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]",
         "]"}]}], "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", 
    "]"}], "\[IndentingNewLine]", "zmag", "\[IndentingNewLine]", 
   RowBox[{"ListPlot3D", "[", 
    RowBox[{"fvxyb", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], ",", "All"}], "}"}]}], ",", 
     " ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"X", ",", " ", "Y", ",", " ", "\"\<Force (pN)\>\""}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.510293354048098*^9, 3.5102933951582623`*^9}, 
   3.510293860757638*^9, {3.5102942893211946`*^9, 3.5102943233211946`*^9}, {
   3.5102945831024446`*^9, 3.5102946352430696`*^9}, {3.5102947202899446`*^9, 
   3.5102947295399446`*^9}, {3.5102948010243196`*^9, 
   3.5102948421649446`*^9}, {3.5102950508680696`*^9, 
   3.5102950511024446`*^9}, {3.524460757270454*^9, 3.5244607573954563`*^9}, {
   3.524479882313363*^9, 3.5244799063138237`*^9}, {3.5244802068664694`*^9, 
   3.5244802378670645`*^9}, 3.5244803011182785`*^9, {3.52448113731959*^9, 
   3.5244811492442317`*^9}, {3.524482096464037*^9, 3.524482114918374*^9}, {
   3.5244825153940926`*^9, 3.5244825155503488`*^9}, 3.5244825512548447`*^9, {
   3.528624743381629*^9, 3.528624744584785*^9}, 3.5513061071583543`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.0014`"}]], "Output",
 CellChangeTimes->{{3.524482108824234*^9, 3.524482126465988*^9}, 
   3.52448255347368*^9, 3.5244826440865345`*^9, 3.551306143412818*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1Wntcjdka3kWhRmbkGmnYFLsQCWe2fEKkUu6Fg+SSFDpGkhBGjJpy2YgR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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlGtoiFEcxt8zZsaY+521D2TMKMXQXGs223ILjbnWSpQhpmGWjcJklCEj
Xxblrqb5MLemCKUUPvjgg/t9Nvf77+n///Dred7znve85/zPc07ysqJZq2Ki
KCqDVpAC8VAI9ZAAI+AUpMPYEEXFaCfIha3QFSrhCVTDWfocRTXucwg8l6N1
wXwX/G14Bv0Ebe2CfXsTzfA5ZMEW6AgbIw0URaVIDfoA7QFrYSkkwg6YCW1h
PByCPtCb/jd8zqv1nue96BX0KdpX/YLNR74XPsnHGazveB6GvvZaqCajYWSw
5+Fqx6d5H9WqNdSqNt6uPp9hGqTRVglD8EM1DrTxWnyD+VpXsLVpjSUwiOf+
6AvtE74CPY6mwAD8S5gMHSAfugefFzyEKrhG236tDw5qjsFqdhKNhZ3408Fq
pFrt9hxoLxb6ONrre/APNsNh+v9FN6ne+CZ0EmTj3yovkIF/g46Bcfh3Xtvz
8Mf3tjrYfDSHuT6fXfh53l/jjMHv87qsgTyfq/z0YKp3Tb5Hl+Cjz2c27z+g
E5URfJX31/fvYQLMoG0PpOKPaE+C5To/WJaU5xpogM7Kqu9pjupDnxbf3wL8
l8jOx+Jg/Qtgveod7Iy9gt++X5fdL4GV/q3GHO65Uzby4DssgHXBvMYsw3/1
zGzG/9Q/YQP+l49Zgp/jNcmGH7AIimmvQzOhPFj2NH4p/hM6FSrwzZGdxe3+
L+WrCN8Y2blTrZq9f26wPVUejng2lJOjwTKj83sMHxcskw3B9kj7kuX/1Xxy
gt0n3eA+JHvOlf84P7/X0cjvk7uRrV3rWh5sjcpsYbDzsg1fj8b42bmItg92
Di6g8coW/ip6J7Jz9yiye+kAes7rqdquCJYZ3TFTguVEWT3jGVOWMj3zujNH
4Qf6naJzqvE1nxPB7iL9t9Hno3/d8n2JVR9I8rOvuzTG79JaNMHvEGUp0XOr
+6TF9znV7zfdgT19jT3xjyM7mzqP6bT9B6G4qjY=
         "]], Polygon3DBox[CompressedData["
1:eJxNl+m3iFUUxs9pUquEa47kStwkNKBCZKiUyjxUVJeQ8WbIUOEqQygZiiRE
ROZZ5qEbzXOrWs1rNXzoQ39AH3p+9mPx4Vlnn33Ou88+++zpLSwe3X3UeSml
v4ULhJKcUm+NfYSxoj/XWFlYKLyv+WphguiJwtocPNYWCaeghfaiOwivsq6x
ktBXeEzzbRovFroJxTnO6OP18aKfEHqI7ikMFz1feFH0S8LLoks0zkvBY22E
0CuFzuheIFQSKgtVhMFC9xQykX2P0Ep0a6GL6LW+NzzWagmFousKNUXfLDQQ
3VBoKbohc+FPzesIe4TdQiPxrsveo3mRcKvoaz1HRpHovf6GvY1z8JCJLPa2
zqEb+twmurl1QO4tOWyKbTsKr1lGZ9GXpZDdTPP7NT4g3CD6LqEFugudRXdE
Zgoea+2Qn4LHGjKR3Ul43TbElk01r5rjzXg7bIptDwkzRc8SjuQ4k7O7CjeK
/lJjFWGQ8JDmyzVWEEbzpjnsNlb0OOF60eWxI/bkTqI/1lggzBD2a77GPojv
rfNevrlcqODvh4g3NAXvixQ+jJ+eFN4RvSGFj+Ardf3e9UAOHdBlvNBUdDXu
xF2EGj7ntGzhmPC45v01XiLsFLan8HHsNDDHHQan0AndjmInYbHoV3LQh4mf
HDzoQyniaJH3TPZ5fDudGNF4obBLGKX5SOFJYYywwzpw9iB8QbiPdXwix93X
CxUdJ/CIZWKavetSxASxcC+xZxs39nsV2F/KpbAlvn9pijds5DfARtjmOD4q
5BQ2xJZ32OfwtU45dLmIt7dOG4WpoqcJm1kXpqTgsfY7cSlcg719DrZhD3v3
ORbICeSGrSnyzVV8Y7/hvpOEt3O8GTbDVrwlPoav4dP4Nm9RPkVO401Opshn
2As/3GP/55td9q9y9qc6mv+hkfxaFx1yABqfw/eO58id5NCjok/YbhuQlYM+
5rud4c12DLF3k8/jTbBre9sY294pvCn++SnyD3lkm1Bf9NXCFtEHfGfueti+
hN1K7FPNUuQO8gXxTz5o7vMKHO/khiYpcs9+je+mkINvDsmRJ8i9wzgvxR7W
RjtGir1niGUhk9xxk++83n6xyfyu9jl8Dxn9/EbIXp3iztyV3LnZNmpnu3Af
5JKD9/pO3I07cTdqTk/L+897OZOz+Kat6NsdZzvtNwOt+9AcPolvYmNs/YHG
Uyny1ls56JP2HXirhJXCJ+J9yrvkyEPojO47RG8XfhX9G3fzN+z9LEVOJbcO
FPr6fbfm+A5d2F/qeFqR4815e3LyL44BYqGa8JFlIKtY6J3jmzd8JrKoIS0d
Y/9aB/qDUuuGfdqkqGGna5nQyjZr63gjV7axLTuw5hglVpelyBnkiuo5fGmf
Yxmfqun4IaaWCquElSlqaJHPaZMjB+5wDNZzvNWybes5ZrBxYY44hI/t63vE
9ltS5Ax4W6wfZ61I0QOcqduF53yLDg0cc+j2V4o9rCFrQI5+h37l4Rw6XSFc
mUPXOqbJ0+SSfqLn2sbUsTX2cXy7RY4egV6BHmaj8IjmXTRWFN5L0XM9KpSl
6MXoSYps73/83n2EB3P4EiNncha1kz6FvE5dbJJDHr0adxhgXWvnyOPovNO+
h6+Sq1mrnSLHr09nz0A2vQG6oTO6lllmf+vMWWXC4hQ58rhjYYnoGiligp6D
3qM6fiV6ojBBmCw8LfTKEc/0f93No35Tjyd6PzQ1+ilkCcNFDxOez9GTcl9y
/kHznhNmei8yu3GGzyJnkjvpa8cJH6boX+inSnO8AfekJlNvyfkL/b7fpqjx
1DN0RFdyGrmIO/TyOT0cF+TRaaKn5sgr5JoxwgLNv9b4TYoegrpF37jE+p62
hdA1R30fJXqkMC9Hjac3g8cavLk5egDmc4QXzJtn8O2IFGucTZ/+VQod4LGG
TWfZZjMtY4730ttXTfENPdAi67rUI7rTly7LcT/yFTWc3oW+Zr7lLLDsGcJs
n4HNsRG24S3wi0k5+qwjfk/emp6K3ooaPsNvlrGz/YsaT60Hu4V9XmPcK3yn
9e+dI8gV1GFyGzS5hNoDj7xNrqfuHsxRp+mF6MXvzuHjx4gH+/6ZN+et8YUy
r/0k+ucU9Anhx3SWR2ws9l7Oooemxh84R2d0/cEgdrgja1OEZ20zbMc/QCfb
Izl+sOER+2qp1/lnmOLvoflHeSaHrxPbJef4/ATHE7FAfZmWor9bLvp/UcWT
ww==
         "]], Polygon3DBox[CompressedData["
1:eJwtlWtMz1EYx8+vUGHDbC6p0RvXijGXoouakmIKESmau63mUkg3hYkXmEtR
LlvJ3MtCRi5lyn28wMbmhVvud+Xu8+w8Lz77fs85///5n/Oc53n+Pilpcaku
xpg4aA0RjjFjYCyEMn4P0fhxEAORjD/BRHyIrsfi42AYDIUREMD8a2P3iYQo
GM34AyzCL4TFMIvxL5iLnwMLIInxD+iE7wiv8P7QWc8wCh8ke8NnmMlcNPoN
kmVPSJQzM/6q60kwFTYyboMmwHT9vfmOPVMyaz/1PqF61kn4yRAPhRIj3Wea
Y9fkTh+hBs5Cd+Y80afgie8BgRITjcdIOT90hS7QTT6jnz+PPwcXYAtjNzQD
5kl85B4al+PM7UDboiegEu4wvq17bEbvwxn8WvQGPICHsJu5XVAC2Yz/wSl8
Aerq2O/UQCmsZu4v7MHvhXrYytgDfYQ+NvastXBR19zR6+g1KMfnow6aJfHG
N0M2Psex+2bpGfbh98Nlvbu7/t4Vx67JWQ16E7mle8xAWyAXn+dYTZQYQAM0
Qj5zEZqzBRIPx2qk5s46/HqJJ2yHYr33H2Pzzg/GwwQYxFoDXIVG2KlvUAgb
oIlxf9iEr4ADcFDfwFX3LnLsG2RpbDM03yXvVuBXwlJYAsv1js26lqy1sgqf
qevLIF3v3aJrUlO/oVbeR+8oteIB/Yw9a7W+jYtj3/+05pLcqR1aBSfhKByB
Y1o7kv/yrmV6xwLdQ/qB9JBYCIZ3xtZgPDoFouAL3IO7xsZRcvgJlIIvdGCu
Dq2HEslVY+tE6qnY2FoZjA4BL3gGlzTf3TR36hytO133wntL/koew3Pwht7M
vVDfE98LfCAcwhzbB0P0Hi/lM9AX+kgMHdsPUvCzJZ7QSmsmF58DmZpDvswN
AH/H9iOJgXg/GOjYviU9Sny65APEGNvLDjN3SN+gUH+jSd9Q+oH0hfb6Nnn4
NZJ7xva3NEjVXJK6+w5B+ED0LVRClbG9ejgE6NobY2s1HA2DBP1uOZQZ2+Ol
lx0xtpcF6Hdk72DJd3yFsf8ZUnfVxtbKNnQ7FGl+/QfPAsn/
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{37, 25, 226, 225, 224, 24, 222, 221, 220, 219, 23, 218, 217, 
       216, 215, 22, 213, 212, 211, 21, 142, 141, 140, 16, 118, 117, 116, 115,
        11, 80, 79, 78, 77, 6, 51, 50, 49, 1, 153, 154, 155, 2, 157, 158, 159,
        160, 3, 161, 162, 163, 164, 4, 165, 166, 167, 5, 105, 106, 107, 108, 
       109, 110, 111, 15, 97, 98, 99, 100, 20, 35, 36, 37}]}, {
      Line3DBox[{155, 152, 281, 283, 286, 170, 274, 276, 277, 48, 183, 300, 
       243, 348, 350, 353, 198, 334, 335, 114, 213}], 
      Line3DBox[{160, 296, 297, 231, 293, 175, 323, 237, 336, 338, 341, 187, 
       367, 246, 380, 382, 385, 202, 257, 436, 438, 441, 218}], 
      Line3DBox[{4, 59, 60, 61, 9, 101, 102, 103, 104, 14, 126, 127, 128, 129,
        19, 146, 147, 148, 24}], 
      Line3DBox[{164, 171, 314, 316, 319, 179, 357, 249, 374, 376, 379, 192, 
       405, 253, 412, 414, 417, 207, 214, 448, 450, 453, 222}], 
      Line3DBox[{167, 180, 386, 388, 391, 394, 396, 397, 398, 156, 195, 426, 
       260, 342, 344, 347, 210, 223, 430, 432, 435, 226}], 
      Line3DBox[{211, 400, 399, 112, 196, 351, 245, 303, 301, 298, 181, 306, 
       305, 304, 233, 272, 168, 284, 228, 280, 278, 153}], 
      Line3DBox[{215, 203, 423, 421, 418, 199, 188, 373, 371, 368, 364, 184, 
       240, 329, 327, 324, 320, 172, 290, 288, 287, 229, 157}], 
      Line3DBox[{219, 265, 447, 445, 442, 204, 256, 411, 409, 406, 402, 189, 
       252, 363, 361, 358, 354, 176, 236, 313, 311, 308, 161}], 
      Line3DBox[{224, 433, 267, 456, 454, 208, 345, 262, 429, 427, 424, 193, 
       270, 269, 268, 232, 392, 389, 242, 332, 330, 165}], 
      Line3DBox[{154, 279, 227, 282, 285, 169, 273, 275, 47, 307, 182, 299, 
       302, 244, 349, 352, 197, 333, 113, 401, 212}], 
      Line3DBox[{158, 294, 230, 289, 291, 173, 321, 325, 328, 239, 339, 185, 
       365, 369, 372, 248, 383, 200, 419, 422, 259, 439, 216}], 
      Line3DBox[{159, 295, 30, 292, 174, 322, 326, 238, 337, 340, 186, 366, 
       370, 247, 381, 384, 201, 420, 258, 437, 440, 217}], 
      Line3DBox[{162, 309, 312, 235, 317, 177, 355, 359, 362, 251, 377, 190, 
       403, 407, 410, 255, 415, 205, 443, 446, 264, 451, 220}], 
      Line3DBox[{163, 310, 234, 315, 318, 178, 356, 360, 250, 375, 378, 191, 
       404, 408, 254, 413, 416, 206, 444, 263, 449, 452, 221}], 
      Line3DBox[{166, 331, 241, 387, 390, 393, 395, 43, 271, 194, 425, 428, 
       261, 343, 346, 209, 455, 266, 431, 434, 225}]}, {
      Line3DBox[{37, 435, 434, 433, 151, 148, 453, 452, 451, 145, 447, 135, 
       441, 440, 439, 132, 423, 121, 114, 401, 400, 142}], 
      Line3DBox[{49, 278, 279, 26, 281, 32, 287, 29, 294, 295, 296, 38, 308, 
       309, 310, 56, 314, 59, 330, 331, 70, 386, 105}], 
      Line3DBox[{77, 45, 272, 273, 274, 52, 320, 321, 322, 323, 62, 81, 354, 
       355, 356, 357, 93, 101, 41, 392, 393, 394, 108}], 
      Line3DBox[{20, 210, 209, 208, 19, 207, 206, 205, 204, 18, 202, 201, 200,
        199, 17, 198, 197, 196, 16}], 
      Line3DBox[{100, 347, 346, 345, 139, 129, 417, 416, 415, 125, 411, 69, 
       385, 384, 383, 92, 373, 88, 353, 352, 351, 76, 118}], 
      Line3DBox[{111, 398, 44, 271, 270, 104, 379, 378, 377, 96, 363, 84, 341,
        340, 339, 65, 329, 55, 48, 307, 306, 80}], 
      Line3DBox[{115, 298, 299, 300, 73, 85, 364, 365, 366, 367, 89, 66, 402, 
       403, 404, 405, 122, 126, 424, 425, 426, 136, 97}], 
      Line3DBox[{140, 112, 333, 334, 119, 418, 419, 420, 130, 436, 133, 442, 
       443, 444, 143, 448, 146, 454, 455, 149, 430, 35}], 
      Line3DBox[{36, 432, 431, 150, 456, 147, 450, 449, 144, 446, 445, 134, 
       438, 437, 131, 422, 421, 120, 335, 113, 399, 141}], 
      Line3DBox[{50, 280, 27, 282, 283, 33, 288, 289, 30, 297, 39, 311, 312, 
       57, 315, 316, 60, 332, 71, 387, 388, 106}], 
      Line3DBox[{51, 28, 284, 285, 286, 34, 290, 291, 292, 293, 31, 40, 313, 
       58, 317, 318, 319, 61, 72, 389, 390, 391, 107}], 
      Line3DBox[{78, 304, 46, 275, 276, 53, 324, 325, 326, 63, 336, 82, 358, 
       359, 360, 94, 374, 102, 268, 42, 395, 396, 109}], 
      Line3DBox[{79, 305, 47, 277, 54, 327, 328, 64, 337, 338, 83, 361, 362, 
       95, 375, 376, 103, 269, 43, 397, 110}], 
      Line3DBox[{98, 342, 137, 428, 427, 127, 412, 123, 408, 407, 406, 67, 
       380, 90, 370, 369, 368, 86, 348, 74, 302, 301, 116}], 
      Line3DBox[{99, 344, 343, 138, 429, 128, 414, 413, 124, 410, 409, 68, 
       382, 381, 91, 372, 371, 87, 350, 349, 75, 303, 117}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJydWnk0Vl37ljIUJUMlQ4NZUZnHbAqZynjMs2RKZkplCo0kEUUhUtFApUi1
GyRDhRIqDZKxIqHB+Nv7vI/1fJ31Pmv9vs8/1rrWXvvsc5973/d1Xfez0j3A
wpOZiYmpZhYT02z0vyXuVc7A9CBskpZ/eWlvALxZeus81xAB1GRTlMYQ/lB9
bFD5tAuMkRwEvGMEGNJeLDSF8MfmFi/2+vLcU9TaKxc1TYCIE2yKeH17MLes
TZ4LEDdoquOeJECUe7/UJ4QbSDS+F5EOg7HFSSpatQQobZqwxuuTTiv8CSZc
4Nwv9Y98TxNg9qbIyAmEF253USpqsoIGpmuaLp4lwPVVPtL4uYPzOT8eHYvU
OnZqdtr2UgK8EWCpH0f4aeu51UqVtlBv+VUht1QCMDH4i2VP0sT7nM8+9kXM
6qpWwuZfIWaAAOuZRdQwfkc1/IOB7RI4faXyAu8mAkwEXluD8Xs+tdtDw1aD
95GivbXGBFAYjFDGuBp8o/Xr4Ar4LKJqQt6IAHeFsi2+IXyn+ztVqaBACKN0
HTXtCWDEOWiF3zfwhtqjMicXsJjtHdtJ9L6zbCv5JxG+Ny/F89YlMxCfn19d
fIwAC+LZluP9tzia/LqsLgN08o22y58jwGGHJxM4Pgbvfex0fM1h+qda4ft5
BOAUZiF+IfxMScRptu6t0NjXfEF2BQH0u3dn4e9rqWv5mSMuALxY1NRJoO+7
bik/+b24JYaW/T7rAlKP3rtih76v//rrXPi5e9QEjbZYy8DUC2+bj04RQEzl
gcFvhF8NS57Fae4BixLieg79JoBLzD/7F9f3GXPGBcC377TJ/Rs9R9fj/ddH
WfzQO+wCO9S+rej7hPbvs9THeNDKghGrXS6Qr7R7FqxH5y8v3oLxaenBnx5e
LtAp7e2ntBsEOPd75Bv+vjeVTaqel9nADJ2Ni/p7CODn7ymN46Y3x0b9abYp
VA2pTrv/igDsMR09GG/oSc4fyQKwWqDz3olHCB+92I73D56/5JVlvyN0DFUa
Vv1MgK7uNWF4/1kcT4sDVexh2PKd2c7PCWDPvHwa493bh8KS4m1gHH+1Rnw5
AXxKFu4eRbhxqArb3CQvGME05+6hJwRoHnjhPYzw+DuKJvMUfeHSH9F6u9B5
utqNlw0h3I4l0JPj7XaYuCf3vFcnAdYGB5Dft6pFYeyYsL2W7OeVdX++ECD5
4mMRjLNGVPd2lfhq+URVuYe1EWBhD78EmYdpqr6x0qFaZ7k8x79X0fM/l5L/
I35XvP8gfL4xMVwT5Qb1v3bft41HuMkrhZ8Ifya3+drPnG2QV1C51TScAOZN
u2R+4Djbbfkm+sAPCq2UdNX3JsA12j09Qrun82j3dH9i50/8XGYe5bcR72yg
7rl8/1f70fueU5bE8b9z4JfpHk8zWJEh/BQEE0BS4if5Xd6McE0yvdWBCwqK
Plx0JICseZAhfu5eXemc7wf8YM6XeYMS7QR4lNgShuNsGN4zqJDmBVU/xX1c
j+JczMkijvOwrq+gPTzHA/ZvPrXH6hq9bpyj1A1HwaB1+LllEtrvdEZNYd5a
r/CqwwTwYD50C+PCHx7zrN2kDw/IfB9/H0oA67EqMv+LlkvpqMqrwZOp425/
nAhwsWb0K37fhhb/HqEKGxDYmTYp1U+AVztfSeF9ji93MKnKMwWZfT5vQCsB
grMKyfetHSpyzj4LwDl56GaNvtc6Zv9v+JxcJU+UlQ6Zg66VBcpe6F6YKFQs
xc89INwGkzJXA5eGk8cq0fsW9n4px/tM2QukihnowRXnzr5bcJleD5+x/l0P
PXirZTF+ofj9MKfur3svtuyxazlBgINrX8th/Enjc41D5mzw4vjDZdp7CCAV
fVYJ4wLTD6cSY7gh92Rr50U3xnXvKPPzVRhnyQxoeFi4GpRGys0VcyfAN9cu
Mj8vr+aR525bDX5d0VwVtZMA/Ed+k/nMLFia5jJXBhjy6hm3JRMglylc/gu+
L861Q8m+QTAtp7/iQCUBhKWsduN8OH5PuHzYxg8O/Hw+7wV632D2+Nn4uxvP
fdT25I0HHPttv1ogl163z1Dqtv1qkXnkOfffeSQ1qQ4+d3ruL0P5ZswVYIXj
qfFx+Itc72bwdX00pw3Kz+TL7Pz4uwTY2yb1SNkAL/Fold/7Ged/3rxL7Hj9
k73cK4WibeBj3frizwkESI+LAnh/kWsb8g6am0JZk2fazjsI4L0mdBzjAvr8
zTcMAbweabev1Zr+Ha8u+/s7Bk3/ksH4Tq+LW1OjOUB8b1L/7Ey0j+TctRif
4i29/3KnIGjeuUg7K4oAJ85mk/hQA4fkYKYY4OPJTpP3pMenmBKfRXY3yO9b
sa+y0DJTCgzvdnhdYUeALDtp8py51/m7PXdoAY8bBQMu2wlQOTv2DMahbsmA
mYEBkPYK6WWJpudJFSVPmCKXkvEXr1206tFvdVByuCJsA7pHvvmpDXif/pVr
520T1AULjt0auY3iY/FNOBrj+WWNIb63jUB4OoenQgy9vmVR6ttdxcu/cfxj
4+xn3y0xh9O7o65XovWuDTKP8D5SFjy9+0304J3CMLbFAQRw/7yPzFsxychq
4r0MZC/o5g90Ytyv/fTHtL4jvIbFPE+r0x+WnGY6xofyJDMhphPnp9cS3v0y
n33hhM3T9K8HCTDcsEYb1ysddX5ZgS4vqOlq41uVx/j8cn8Uq8nzH+vYVL7Q
Es5x9n9FoPMXe8vG4vN7scitC3tqBBPDO9yNUHyGPAfI73ItYmjZ8IAW1K/Q
eayF8tlsrnBZJ8Kbb6zMF00NheZHzix2RvdIW0xGuQvhw+GXXMTGQ2CBw8KB
vege+Vxbcqkb4YK6kE98awhcYdt/93QOAb5e+7C4F+HVwxceij8LhiH3FRLv
Ih4yKhYf3ofwSKdyHwnlYGj+clj/3T4C3Gdjqe/H620150nmBMGdDXJMk2EE
SLV35/uKcM27+wok2YPg5eGRUiHUR6aXPzLB9+iDopw9a4ALiOTOlqtF/f3W
hRRdjEcZiwxZx7gA/xJrhz+IDwQX2mhinGmY88D5Yy7gVTtngjTqmzP8bVbx
3/ztVOPoGJm3RtMs4T4AsHe/5u1E98vQO0oL44NWhRO5bqZgQkPCPQzFs6BB
gg3HP/Lmj80b99sAmQNWzmyJKP+fHz+I8TresiubfK3Ahlohp9Zi1K/9/N6T
POSHTl+rpC1g+1z2kbmaAJ5rNizB+EqjLQu9uxxA3EkT8zUf6fxQmcIPM9hj
SVzquGKtigcLjDQ80f7DFeXDdJY8xvk/rwzyd2MD6rfqKq5FEGDOyxoyb0/q
tBTFz10JRFKc0oKT6ftrU/Z36tDgw3hMfqbc1GkVmMlzyH0x2v/qjkPNOA7O
ibzOMbs3whuWN2/8Qd9rY4ZHBMbfpw6nzZIyhjGzVg+3o/5ofT2E7DvflqRz
7RXSA01EbN6e2+geJQgM4vhoWjzRk0w3B+Mne49XN6A+Mj7+EMchVdCmjSvb
Fmx4J7xxYReKp2CmGD7PKq7VLe9khMDhK41PD6L8ZP32WRTjsTvXmm3Ozbqn
3rtUuqMJ1eff30h9MVF1KGTZViF4//7yWNVe+j2NoNzT8IDDw/g+HrKS/c7S
6gtLd60MXobqVdqwSiDmw9V+hhtu12+F/OxjVdN70Tmt8mpwXslsqwh7G+ME
k8RfW348SoAKAV8R3F/2bD2efj7fAwi9VLl3APGKUylFwfheXxBfxRma6QVK
nMaX70R92X1XiR5+btMbyTXaSX7gMrwk44V4i1HWGU8ct2cH1ec9+WwMh09x
i40g3ig9y+Mmxlv9/TdxjOrCgI28AlKNKA+P8A2SPHZ3zOcz8zThyKUb0w6I
39a6KonhOH/wrwUq5dZQhkiYG3IL8WEWO14c5zXJiWyyrI7wyXaFBvFniB+a
yNdhvtfIaW7OXeQK3/Wc2tGGeEXpodbjOA6CQtdv1cRshdefdz+2Qfrr5HWv
Jow3cAk1HRTcCvd55+3hfY3udUbZfByHNQnlfUY3PSCXUYx8A4p/E43Pa9H4
/CcanxcXf7Aex0HjhY1g3zE/6JxiwWk+TICON1dccdwkFUL7xQq9YNDSTKHU
UQI0JJ1hx/tzGovYuN72gFLGu9te/KLzz3IK/1Sn6dAHNB0aS9OhZ20z+nEc
1BbHsPcjXaDyYf7eHeOongiWiJB5ri5vrHbaFKo/cNlaO0EALr837zC+zUe1
ReM0gLxv20dFka75QdOzAY5KpJ5VoulZO5OL5PqIcwnBVnkAqHo8yuxE62vl
Zcn9c31fQWvE9+Yu4i4yQDgYyevD56nneB06C/HDwXYfz8tI/2rtluLH+5te
3RcwFiUGUma1XRX9TgCC094dr5+Izl6SE2sPG1YUcMih+sa+8BQPjsPT0pC4
pFo/KKum9EmtBdVV4YwRHIcR3tY3MTcc4XVWifTbZwhgG+YSj/cR1fxxJZnX
Hlo6rnKah3hRdhvBStYxdrWI7GAb6MjTJmifR+exjRQeO8OfCyj8+bZwlAp+
31ArnSJDdVM4nthRbl+IeG+H+T2M/8rSyddq0oWxlUO7OYoQnz82ugC/7+vF
7h+3NSrC5COEwJ3/4KuO1zn+4jlZ5vvmYNzozheXHxWq0FS1eXbRRdS/WCWO
4/2/39+uWHfbAP6IeA560PlzDcxf4XPKLDFM3HzEAt6UXmAgdorOJxMpfLL6
ggDZLzRT1JnNsn/e+33bX0dHhwB7r7lrYFyhpy89dykb/DJctkB+I7qP4p7q
GC9PNkg/EswN5/5oeCuiR+dRNyk8Ki2VmdwH3G9P6tQYuPc24JiGjgEBXkR3
kevPyjhM5KRygT/8vk93GCL9VVtH8u2lKY+UF1xeCXhi9Byyjeg+wB6KDzDD
ryop/Cq8yPSfPiJWH38ybAV4+45bbivCLSbFyPNfM1HbNtbCAiaF9kRMof1T
feRJfNFwj3GQFCs0MXKvzES4sK3NTxxPB+8knqVT5jB1jpKpyhYCJC6dvI3r
CYvZ+uRdo66Q7/BaM3ULVDfUfOJHEO7tEP2464s3nBVpNa2B+myju/0anFct
jq+2hJc6AHbpjhen0Xex+FRH5tvk5BRUZrEFP+qKD5/NIMDlg9op+LkpZQ6C
v2ytwGSptvz5NMZxaO8vi8R46tIvPPeqjcBAXV9CEtI1PqKLn2C821VOd76i
LvDYkqsckIXqxqz2SdJXEVKtL9+gAcw0H7aZ5dJ9Dy6K7zHjt+hS/JYs8ZtS
GF82p7+cyVwQEqOGC60LCFBllULysRs+RoGtjzWgzVP5o7vyCSDDfSID46Ll
9ka3HAxgqDNbXza6R5PRW5jx+w7mlIiWxdnAvOP2nrfOE6CmOeEuPs8JlcTH
UllOcBxcjbyC7kuzo/8aHP+Y2Fa+56/doNry607nrhNgD89GdVwfXN/rJvem
+4HdUgpEBqq3xp9GnHC95TFjgVUXvcC2x2uC21C9DQLHWHG9tVignJR71wPM
7r2pvvQ3Wk/rUw20PjVC61Mz8VlAic+qIXZe8t51JBgdaLUGHPuKW71Qve0J
NrDB+wRXEbfX8puAa0/sToShens+uYUJxy00JsM+m1kJsJc96I+bpPtLRyj+
0olFr+PxPo0lUm4aeQbQ/8VqVS603uIqjyt+bm/y28SgxQT8EFYil4ye68Tp
mofPOcr9jFOv3QmGeIc+4Bxj3O9CWPtMsO+xCs53N3HaBgtNRn/c/Yn62iRk
xfms/rgk/YiPD4yucqv/PoJ0t6h+OPZtru58fexp2HZ4Vv55oOgwY/9qPs2/
Ylr1j3/lTPOvGPWvQoqvlUnztWb8q2aKfzVK8XM20fycGR9mDsWHmfElTjLw
Jd5SfImZ+vwo9t/9hGwGfsJDBn7CEoqfMFM/b1Pq54zez6To/RCa3jen6f1x
mt6f0fVDif+u65Upuv4oTdf703S9N03Xz6Lp0+U0fVpK0ac9FH1qSdOnZ2n6
NIKmT+/RdGgCTYcy7flHh7rRdOhamg69S9GhWhQdOlPnSyl1fkYvaDLQC3MY
6IV0il6YqW/GlPpmQ+P5fTSe/4LG8z1oPF+NxvMnaDxfmsbzk2k8fyON58/w
8BQGPLyOAQ9fR+Hhq2g8+S2NJwfSePI5Gk82pfHkURpPnqkncZR68t/y25n7
xUG5X42Ll7Xhc0ouedjNZ+kEbQrnPNmM8krKz5rUj3IT7HoZF2xg/gnOvA3o
uww8jV+C92/TfLy1vM4DKiaKrtLb+r/zt1oKf7vLrO6PcREiIT1Bk4D5svvF
xA8innPwHsmLftst0T+eZQHT/gi/CD2EdIGpYTiOm1KhyQfeg8bQq/KC99EQ
dF849P1wvzD11PGXOe0F46c8przeIz37UIiH9PlvzX/tVeoBMx9er7iA9Oyc
DWmCGL/4pdM+4IIHfODHmxVVS9cF6ym6YKZOBlLqpIV70WeMz7sU3OLe5gi7
0z6/XPCMXj9n/P+Z+hkjUPCVxK2d2oKqHWE6/6Ebn8sIUHmgbg+O28InTy9F
i9tD8aS2PYpIH82l+fxBNJ/fiebzd9N8fiaazx9O8/m75N19cdyk2PTDvzAT
UOQrfzHXCwI40Pz/Lpr/v4/m/+9PU2/D608HDIqzm1nAj07Dykp30L3mk9iN
4+xryOLJomIEL0UR87shvZ6/oNRzRvU/UYdTAq//VPz4ITPSL5lsOyZ0+xAP
WazUgXEzG5vHz7MB/KOyMDkH8XbdmiOfSV9RJvSGG8LP5nlJCLbSeW/N0X/n
vX+6/533ZlF47+J1RmQffyu66jvr9/Xgz7hy10tbVD//2LKQfMmA501GuCaY
d8HzZhXS4zz7Txri8+zeviO0r2ALSOP0VdkWyHheEOeyVwGvN3rvlLKCzQzu
fHCE1RSt79iuPorxGqfE78fctOF1w98mNei59XyVAxjXqn4XbrhMB3674r24
wp4+T1laqPTXPGXiBhMZN+sBjukHSMet4PixzgXh7Y1x4hjXaZ8uSEL9sV5u
yYaqfvr8pdT5yV/zlytiBBnnMPZHm9eivsk6plf7ppU+lznOrvbXXGZGZz1n
MC9IpvTlQI59JI/VVpMdHd64EXSMLmzc20Dv15WUfl0QeYj0VZgHIz36swTB
sKM5XxrKw6a+n6T/86r+t/35Zjn4ZH1fatMNur7LZ6DvghjouxEG+q6Zou9m
5izXKHMWnzaeSoyr+e1/o3xEDzbd+q4Rhup8XUw8WbcrI5gJG31lyPdprF38
OH0uI0CZy7Tl15LrFaOz6jbdUYECgftzju6kz2sKKPMaxXJX0q8eVC2zSFmw
CSrXhXWGv0J8O9ijDPeFvnwhPg+TrVCf+9P8uBoC8E5HZeDvNW/wZIz/GTt4
7sk4Ry3qg1NyVyQwruom0Fn90AF8j+OefIZ40cHtZ7owrmPCZbl/sS0Qlta4
+eIKAd6GjS/DOHT8tnNJswOIIJQkp2roPCqKAY8qo/AolslBEn9zef4m4dxp
LcLMv8R/L51fcVP4FfeaMyRPELXm2rc67qNWyNyl4a3u6B6pZSuSc6IE8JE7
bxH4FGLPyrKV3q+TGPTrGkq/dlg6xxT3i0UlTjHDrV7Q+5Sz/s999D6+htLH
r32rU8f9VOBwlsv5p24wL01UtTUd6QJY4I73nz6f/P5j21Y4mWbV/yyLzusm
GPA6NQqvm8o1LMP4vK/Mu64d1QdX1LMSHQLofC+Awvfm568uw/h9y+ov5/dY
gjKz0dcTqL/PuW9J5n/0o5DAxlxTIBap5zsrjs6Hhar+3a8w+B/9ijKaXzEz
3zGmzHcSXhfzYHz1y81zSoyV4PmPXG46KahvavcW4/359L8tvzh7E2wPn1UQ
dYA+D+qhzINky6zJejgWaZXg/04Oej30vdsWTp8TdTOYE51j4G9A+O/+xkMG
/oYIxd+YmTfdocyb4hyjxDEux94x5LhODjAva9jag+p54x0jch76LHk2Vwqf
MpjdvnGAz5E+n8qjzKe4G9u7MX6CNSja5KIO6I68EpzkT4A7tLnVA9rcahVt
bjXD2/cx4O2rKLx9PRd3AdkvXJKSojgNoGVJgHLJDjqfl6bw+We5Vcsw/kG8
eQv/oAL02/fRah7Cz4evJ+vVWIhHOUuAGpRca5Vc4Pjf65Eza+ey4vV5l1pc
fLk1QPTTWyeyQxjrFJa91vUYXymndL5CUhfAznOLFiUQgO3ayCy8z7y6I+nc
qzRA7PXbt34eZOynzei1DIpe83Uci8Bzn8GijKCjLwOhp8oW7wv/oePMKDru
1ZR0JP69RNNm980j0r6wxQ8eGMpBeSXscA37/I8+xA0c1QyEAz4DC2oQ/mxt
cSXeJ0XEWaTmkjts3c2zSy2VAJfl2v2xfr8tfKF7ZNwbLlpdM7UQ4R90Mzvw
71IGL15vWmEcAEPCX1zuOYb4SYKvNa5jIXdPvhp95gWn5rrtWIfqgHtxKQue
9+XJOvWvFN4Bz3RU6LEhXCvhPPn7jV5Zx2GRwe1wtkNUi0Q4Y786x1FqKT7n
7lCFXtNLHiCOJ6WnHPHk71MW3vi5B/OKPIXyvICK1xeDC4hv7+f9yEXOtWdD
9d83PMC+ai7uvo//u+9X8v/0/Wbm+MyUOX6c9h5SVyraS3X3FK4AChJrLe6h
/tKe4U4+N8KRs08hmxXUchVm2rrR5/5FlLm/c34Bef4v3DIGym0rAL+HQQj/
f/weYFrg798DzOjcMAY6t77zb50rHjhJ3i/9p0EnfFjkoQtHgWFLOF3/Hqbo
X732RrLO1CfnNF98LQVz7qivOZFEgP7gOf34XrCO2PIqX9WGB8Wl8yuO0OeA
tZQ5YECY6By8/pzoL5vBFebgyHpV2YoSArx8wO+D8Y3fl/bJXjUG3+6UDJwq
o88Nyyhzw53iKUF4//E/R89Ev7cC79yKHnyuo88TV1DmiTM+rRMDn5aVgU/r
Q/Fpzey67PA+j9IrbeybCXizI8JTAPGBZ8JEAc5Dgb480VMf3SF4EbpIGOWz
2fRkDqmD2NXEs4rs4K3J+V6Tu+g+mzCDuVITRXfL39Z7iPNf48ph6TpJL3hR
wT9Sv5Wux9dR9PiJWFV27NfBZU2bDj/cBsf0eVWYkT5afsK3HNeNjVsyQ+uf
+8DK9Gp2pS66j9HLwMdQpfgYi/zbWvD6nFp/P//jOqBDQ5O3uZHubxyh+BsS
LpakLjvxQGk5QLw9zXl88bJuxLdd/5B6JFeqIK2STxMEHJ6KWd1Dn3suocw9
uRdUCWL8aMiRXPh0NbQdCt96GZ3zdZJgOzmfeix4YNwP6RrZjpbGCvqc9Mrh
v+ekTuuS2THOe3eBR/RvRejsvOnGHISb0OanCx//Mz99QJufzvi9TRS/d8Zv
+UjxWwqXN5fiuJ05/GWfnbYl9P+0SPr8c7oP40TxYZTYXMnffX1f4m/2K8UU
xgcVq75FcfPRhY9xPC/L7XY1TbaFWj2G7PZIjwccXdhH/h5vZW9PUaMjzPaL
EPe9SwCxoSwPnM9ZIvyrjoa6wZbVIwvckF7u0j6QgfGUC1paZlxu8PtdHSj0
kgD/B+A+POs=
    "]],
  Axes->True,
  AxesLabel->{
    FormBox["X", TraditionalForm], 
    FormBox["Y", TraditionalForm], 
    FormBox["\"Force (pN)\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{-0.0002, 0.0002}, {-0.0002, 0.0002}, All},
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.524482108824234*^9, 3.524482126465988*^9}, 
   3.52448255347368*^9, 3.5244826440865345`*^9, 3.551306143459618*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Here", " ", "I", " ", "show", " ", "the", " ", "angle", " ", "between", 
     " ", 
     RowBox[{"(", 
      RowBox[{
      "a", " ", "tether", " ", "at", " ", "the", " ", "very", " ", "edge", 
       " ", "of", " ", "the", " ", "field", " ", "of", " ", "view"}], ")"}], 
     " ", "and", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"straight", " ", "up", " ", "and", " ", "down"}], ")"}], ".", 
      " ", "Note"}], " ", "that", " ", "Zmag", " ", "is", " ", "the", " ", 
     "distance", " ", "between", " ", "the", " ", "magnet", " ", "and", " ", 
     "the", " ", 
     RowBox[{"bead", ".", " ", "A"}], " ", "flow", " ", "cell", " ", "is", 
     " ", "something", " ", "like", " ", "a", " ", "few", " ", "hundred", " ",
      "microns", " ", 
     RowBox[{"wide", ".", " ", "So"}], " ", "as", " ", "long", " ", "as", " ", 
     RowBox[{"you", "'"}], "re", " ", "1", "mm", " ", "or", " ", "above"}], 
    ",", " ", 
    RowBox[{"the", " ", 
     RowBox[{"angle", "'"}], "s", " ", "gonna", " ", "be", " ", "5", " ", 
     "degrees", " ", "at", " ", 
     RowBox[{"most", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmin", "=", 
     RowBox[{"0.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"7.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"phi2", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{"360", "*", 
      RowBox[{
       RowBox[{
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"Normalize", "[", 
            RowBox[{"F", "[", 
             RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", 
        "2"}], "/", "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fzvy", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4"}], "+", 
          RowBox[{
           SuperscriptBox["10", "3"], 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], ",", " ", 
         RowBox[{"phi2", "[", 
          RowBox[{
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", "0", ",", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"zmin", "+", 
              RowBox[{"i", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
             ")"}]}]}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"fzvy", ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "  ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", " ", "7.5"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "22"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Magnet Height\>\"", ",", "\"\<Angle of Tether (Degrees)\>\""}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5063424554294305`*^9, 3.506342527836144*^9}, {
   3.506342662399505*^9, 3.5063426763058443`*^9}, {3.5063428564788723`*^9, 
   3.506342860932026*^9}, {3.5068710896807976`*^9, 3.5068712500880737`*^9}, {
   3.5085881591839685`*^9, 3.5085881599964943`*^9}, 3.508588191825638*^9, {
   3.5134151758595915`*^9, 3.5134151781877165`*^9}, {3.5134152114845915`*^9, 
   3.5134152492033415`*^9}, {3.5134154099377165`*^9, 
   3.5134154101252165`*^9}, {3.52448145585213*^9, 3.5244814572285643`*^9}, 
   3.5513041452606506`*^9, {3.551306166688059*^9, 3.551306171820468*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtkn8slHEcxx+knNyc635xnFk0ms3ya1R8PmuHOlstYhmVpNI4d6rbpJof
i61W01oaphhlarFsmhOt8IcSmqU5U41yOMfx3Dk/blKer+e9PXv2PM/3+35e
7/fn65OhSrhoT1FUyNbF3CurGHWAUtHjmvowFNtkpcaT2iHQBDW6r8UEYoKW
eaGDH5fXIy3hvvhcHeU82jABZ6Tvvq3QXujNLJfpwTbbbOSYRUjsqgyw79Xf
YDqQj8KWuMkCgQlc2vLu93Vy8ejWU0scDTPWG13dPA7eYbaXWoB2eZtW3e6I
PVb/tPIeK1zJWUzixjrg5j9Gq9DxIraG0thh9Nbf1VE2SBf/1B8RUMi4TRZs
QE2YyLXCcRMIrnYT+ImPKnMTN+Am+U7hM+/rb7zMNqgmfHb4+4nsvd+XdXa9
PaYKHcaqh9aAcXcedcAytWTCn16FbZwdmJWtGNHuXwViJ9iJSQ+S04s0KxAc
wmgXNp24q0kZtMJ2X074tFNVHh9khTymLjUHnSKUK+FVy1BOAjpjzOfh+ErO
MhC7lt1Ykj1sSCu0wOAAIxd04ecoetfNQOoxctE0EsqV55uBQwBdUSPJyyq2
0SwPDw1nI74fLKKB4DfwUGHoviDn0CyfG2b3ceYLK5agmwRyw/F7p8Z1vkss
Lx9rSxqDinMXYYIUyse5il7B6SoTqAj/Hrx1eFDu278AFJEAlZnTX0eoBTaP
AOUZ8rCUqHkgdcqEWFmWmVlbaITXJJ8QRbcP8R73zQGxixLhLz/rBx/hHJC4
AyIc9qzzOZBlgFRiKMa96g1d08dZNr8YS0OuHlPKZmF73hI0SVrHzhfPsH24
46K2mcoyTMP2eXbHcLOv5VzyNAQw4/P3QGHthjjgkx7aCaAHtql4ifXReogl
51GK/cmDAS87ptj5S7G1Lt8ijZyCS0SeOFp/7biu6w/8ByoQfwU=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Magnet Height\"", TraditionalForm], 
    FormBox["\"Angle of Tether (Degrees)\"", TraditionalForm]},
  ImageSize->{338., Automatic},
  PlotRange->{{-0.5, 7.5}, {0, 22}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.506342597195963*^9, 3.5063429309012237`*^9, 
  3.508588253655741*^9, 3.5134152282189665`*^9, 3.5134153146408415`*^9, 
  3.5134157084064665`*^9, 3.524481655269043*^9, 3.5513040825797405`*^9, 
  3.551304197333542*^9, 3.5513062253909616`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
   "Here", " ", "I", " ", "show", " ", "the", " ", "fractional", " ", 
    "difference", " ", "in", " ", "force", " ", "magnitude", " ", "between", 
    " ", "a", " ", "tether", " ", "at", " ", "the", " ", "very", " ", "edge", 
    " ", "of", " ", "the", " ", "field", " ", "of", " ", "view", " ", "and", 
    " ", "the", " ", "center", " ", "of", " ", "the", " ", "field", " ", "of",
     " ", "view"}], " ", "=", 
   RowBox[{"abs", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Force", "[", "egde", "]"}], "-", 
        RowBox[{"Force", "[", "center", "]"}]}], ")"}], "/", 
      RowBox[{"Force", "[", "center", "]"}]}], ")"}], "  ", "Once", " ", 
    "again", " ", "above", " ", "one", " ", "millimeter", " ", "the", " ", 
    "change", " ", "is", " ", "small", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"~", "5"}], "%", " ", "at", " ", "most"}], ")"}]}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.506871259150632*^9, 3.506871396526511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"phi2", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"360", "*", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"F", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", 
      "2"}], "/", "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"zmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"F", "[", 
            RowBox[{
             RowBox[{"0.2", " ", 
              SuperscriptBox["10", 
               RowBox[{"-", "3"}]]}], ",", " ", 
             RowBox[{"0.2", " ", 
              SuperscriptBox["10", 
               RowBox[{"-", "3"}]]}], ",", 
             RowBox[{"(", 
              RowBox[{"zmin", "+", 
               RowBox[{"i", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
              ")"}]}], "]"}], "]"}], "-", " ", 
          RowBox[{"Norm", "[", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", " ", "0", ",", 
             RowBox[{"(", 
              RowBox[{"zmin", "+", 
               RowBox[{"i", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
              ")"}]}], "]"}], "]"}]}], ")"}], "/", 
        RowBox[{"Norm", "[", 
         RowBox[{"F", "[", 
          RowBox[{
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", " ", 
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Zmag", ",", " ", "\"\<change in force\>\""}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5064007980446672`*^9, 3.5064008717951393`*^9}, {
  3.506400989047954*^9, 3.5064010288945093`*^9}, {3.5064012127355757`*^9, 
  3.5064012369560304`*^9}, {3.5064014612751627`*^9, 3.506401462681449*^9}, {
  3.5064016748103685`*^9, 3.506401686810522*^9}, {3.5064019226729164`*^9, 
  3.506401923626054*^9}, {3.5064019797048965`*^9, 3.5064019807986603`*^9}, {
  3.5513040688517165`*^9, 3.551304071550521*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtknkwFGAYxjdkaKTGmmx0EJUONZJB0rMsNbZMLYWRNbXSpHJU6NrGaMcR
U3KVnJuVHA1aOaM1Ua0Sa3SsRq1qO8xSuRex7UfvzDfff8+8v9/zmnHCPIM0
KBSKjfqRP+sOmTZYMYYLlbMSBKcMcmHbAY8GE55E8zVyWk0rz57oQpxSailT
icFrfnnXraYbpfYlJrV1z3CqMSKNpvUO/eFXlAaaLfCsWxWrYEmh96zsUu6T
Zux4JI56kv8BWW8ZDsFFTTBTp6UM9qLl/WBIPLsBug9W+B1zlEGu2tq0L74W
Sq+v97Jb+7DBjb57SL8aAywS+Bmrd+brRMiF6Nt//XaowVdItlSk+k1XotuD
s9TXQQ4LWpwiJa0cz/faXXM+8g1nt8eOCpPL0OCup7Ep/jsCX9W7uX4qRvme
z5cMy3+gn9t9tCaiCAVuNSMzb37CPnlIuoNZiFuMpNM/pvtR5fTWMtCnACRM
skaBrgjbUGkGH1dgG9DgPgAa9YAjk5KHM06L3gvCB9HznVlmZJ6NIEeZesNf
EHHpyZ1JmfB1IAJ+44GeEdPS5haKsonQP+BTq/kPDdLBN9760UJ7CO2a9x9W
W6Rivo8h7Cw5KF997CbSaVre+lbD8H6TeEGSeR031PS85mEwhtcv0KpKRMKy
no4JrxGohJP+WUsSEJNBAEbwWve8nFoci8uGhHgU0VnXMrOjeIhMI4FjUBm7
ho1GxiDMgDQ6BsHyVO0ul+j//Y+jwu6RUWT/ZQQuJQTjONzIvmotvQB28tMx
S/8JHAp0oa/RiYKPvpUw9/cEOKVd9YvPnQOL1MNTwoj5LYdFPQMm0b9sEk5t
la8KXoTAlegtmURqLmNvuygYu4g+pylQxHaKPO3jsJ8TPgV2YabYPZ2DbTrk
QKYxm58hMG0JwOZ4AjwN7so9RexOX6zTJsR/wepsmuHSvWCqvr66VTN4LBZ8
OWm4D8ZEn3AGAxtj+WudXUCdO+BZlHWYlSTJrDG3Xs8s4szHTS+OVu2aizut
Aq1XkNG60FpEmR96u4LjmNhEF/0DA+eLug==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["Zmag", TraditionalForm], 
    FormBox[
     RowBox[{"change", " ", "force", " ", "in"}], TraditionalForm]},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.5064010200501366`*^9, 3.506401151762533*^9, 
  3.50640164756002*^9, 3.506401862265893*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Here", " ", "I", " ", "show", " ", "the", " ", "angle", " ", "between", 
     " ", 
     RowBox[{"(", 
      RowBox[{
      "the", " ", "magnetic", " ", "field", " ", "at", " ", "the", " ", 
       "very", " ", "edge", " ", "of", " ", "the", " ", "field", " ", "of", 
       " ", "view"}], ")"}], " ", "and", " ", 
     RowBox[{
      RowBox[{"(", "horizontal", ")"}], ".", " ", "Note"}], " ", "that", " ", 
     "Zmag", " ", "is", " ", "the", " ", "distance", " ", "between", " ", 
     "the", " ", "magnet", " ", "and", " ", "the", " ", 
     RowBox[{"bead", ".", " ", "A"}], " ", "flow", " ", "cell", " ", "is", 
     " ", "something", " ", "like", " ", "a", " ", "few", " ", "hundred", " ",
      "microns", " ", 
     RowBox[{"wide", ".", " ", "So"}]}], ",", " ", 
    RowBox[{
    "the", " ", "magnetic", " ", "field", " ", "is", " ", "about", " ", "six",
      " ", "degrees", " ", "from", " ", "horizontal", " ", "at", " ", 
     RowBox[{"worst", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmin", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"7.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"phi3", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{"360", "*", 
      RowBox[{
       RowBox[{
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"Normalize", "[", 
            RowBox[{"H", "[", 
             RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}], 
        "/", "2"}], "/", "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fzvy", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["10", "3"], 
          RowBox[{"(", 
           RowBox[{"zmin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
           ")"}]}], ",", " ", 
         RowBox[{"phi3", "[", 
          RowBox[{
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", "0", ",", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"zmin", "+", 
              RowBox[{"i", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
             ")"}]}]}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"fzvy", ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Zmag", ",", " ", "Degrees"}], "}"}]}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.508587503381733*^9, 3.5085875411016903`*^9}, {
  3.508587623588705*^9, 3.508587628104474*^9}, {3.5085877892502556`*^9, 
  3.5085878460176973`*^9}, {3.5085879880378666`*^9, 3.50858809594757*^9}, {
  3.5085889927106404`*^9, 3.508588998054561*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdkX1MzHEcx89Dxbnq9/vd736/UlcxI6xlLJTyfethJOTOPB0jhjWiCDWp
1aIcuxpGV63yuNzEip6kh9shPXlqYa2sUHTMQ+qch4r7/d7bd9+/Pu+9X+/3
tJ2x6t3jJRLJAtsT/rxcQc2kQq8LVZ22kIaiqb5vZrwipY3m1uSciSg7FH32
y/EeEiELHhg+KcOL6V2/U/b2EeuzsT3tK2islI2fm8mZyfaq78o5yXKYLN5b
s01fyNcf5x5HShUo/FbcGLFokIws3OGR7sJBs2tJT6RuiLTV+YVMaubAdz61
rntvIeHBMaoEPx4dq3dSm/x/kahxRdsa43hki4Z/SHp9SmHdKR6rFmmXRfWP
kA+S7FurMnlMLnG3Wf4ja4PmsnnxPITr8iYJGmckFT9R8zC2XA6rHBoH58iM
S1e8eXie/Kyq9pgAS7wm7ZmVQzLx21YTPhET2tdejDRxEOhqD9th4UDv2EUt
h4DypqP1RfbgApcaqtZw0B9g0o0tDrh/cPGDJIbDTwHXMgm/q5tMiS8VWP/+
ev5DLym2bN83X6lX4E6BUMAUqAwJD2o0CojxjspADduV65QKxAp2lx3h0/cm
zNTL4kmbICekepa1JV5jMSeTszXkDEt37t2maBYPvUpti1CwLnZsMPmwGBrt
SDTPpPHYK6vu0JAc4jy1NDICRlp778mhrvawETOQzr+zgkmTI/VCyJmYjwwa
0ou10nA5SsV95QjXlOxqpeWwjZNzgGHhX0FfWN/FwMlHIGBhzAp1MFxnECR9
fTUuSIGApDbqURyDmI9/DYPtCjRs1uXeCGSQLwa07bxh1F89mYFY/yiH7iNu
KuMrGn+Ees/zsI8NYwev0RDr83aB61hG3rt4GmI99S7YeFzfdy6Ehoi/zhUZ
BUfe/ZPTqBSBXbH7REDCrH4K/c8F4qkoIc1JDlUU2NvL3x5j3SCNyDEWaCkI
tH8Nbph+2uw0sJWCiEvcEbW/bHbfPApXhHgd7qjV+z7NtqMg2u1VIib3U/SL
CmdIRHngxKWbnp07nPEf9A5wBQ==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["Zmag", TraditionalForm], 
    FormBox["Degrees", TraditionalForm]},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.508587607369436*^9, 3.508587630135789*^9}, 
   3.5085877907034273`*^9, {3.508587825017025*^9, 3.508587847439618*^9}, 
   3.5085890014921713`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "interested", " ", "in", " ", "making", " ", "the", " ", 
     "precession", " ", "animations"}], ",", " ", 
    RowBox[{
    "run", " ", "this", " ", "below", " ", "to", " ", "generate", " ", "the", 
     " ", "positions", " ", "of", " ", "the", " ", "bead", " ", "under", " ", 
     "magnet", " ", 
     RowBox[{"rotation", ".", " ", "This"}], " ", "calculation", " ", "takes",
      " ", "several", " ", 
     RowBox[{"minutes", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmag", "=", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}], "*", 
      RowBox[{"(", 
       RowBox[{"0.1", "+", "0.4"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tethrad", "=", 
     RowBox[{"0.2", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tethlength", "=", "2.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tethx", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"tethrad", "*", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tethy", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"tethrad", "*", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cycxy", "[", 
      RowBox[{"\[Theta]_", ",", "z_"}], "]"}], ":=", 
     RowBox[{"tethlength", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dot", "[", 
         RowBox[{
          RowBox[{"Normalize", "[", 
           RowBox[{"F", "[", 
            RowBox[{
             RowBox[{"tethx", "[", "\[Theta]", "]"}], ",", 
             RowBox[{"tethy", "[", "\[Theta]", "]"}], ",", "z"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", " ", "0"}], "}"}]}], 
         "]"}], " ", ",", 
        RowBox[{"Dot", "[", 
         RowBox[{
          RowBox[{"Normalize", "[", 
           RowBox[{"F", "[", 
            RowBox[{
             RowBox[{"tethx", "[", "\[Theta]", "]"}], ",", 
             RowBox[{"tethy", "[", "\[Theta]", "]"}], ",", "z"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
            RowBox[{"-", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", " ", "0"}], 
           "}"}]}], "]"}], " ", ",", 
        RowBox[{"Dot", "[", 
         RowBox[{
          RowBox[{"Normalize", "[", 
           RowBox[{"F", "[", 
            RowBox[{
             RowBox[{"tethx", "[", "\[Theta]", "]"}], ",", 
             RowBox[{"tethy", "[", "\[Theta]", "]"}], ",", "z"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "  ", 
       "}"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fzvy", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"cycxy", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"i", " ", "2", " ", "\[Pi]"}], "npts"], ",", " ", "zmag"}], 
        "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rot", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"i", " ", "2", " ", "\[Pi]"}], "npts"], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"ToFileName", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], ",", 
        RowBox[{"StringJoin", "[", "\"\<xyz.xls\>\"", "]"}]}], "]"}], ",", 
      " ", "fzvy"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"ToFileName", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], ",", 
        RowBox[{"StringJoin", "[", "\"\<rot.xls\>\"", "]"}]}], "]"}], ",", 
      " ", "rot"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.551306410701088*^9, 3.551306481993213*^9}, {
  3.5513076913957396`*^9, 3.551307692300541*^9}, {3.5513077699896774`*^9, 
  3.55130777691609*^9}, {3.551312780306985*^9, 3.5513127849120626`*^9}}]
},
WindowSize->{667, 620},
WindowMargins->{{Automatic, 39}, {Automatic, 6}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 23944, 568, 2711, "Input"],
Cell[CellGroupData[{
Cell[24514, 592, 3474, 93, 277, "Input"],
Cell[27991, 687, 2326, 45, 355, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30354, 737, 3788, 86, 257, "Input"],
Cell[34145, 825, 1407, 28, 199, "Output"]
}, Open  ]],
Cell[35567, 856, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[35686, 861, 6982, 160, 494, "Input"],
Cell[42671, 1023, 285, 4, 30, "Output"],
Cell[42959, 1029, 25812, 425, 264, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68808, 1459, 5346, 138, 434, "Input"],
Cell[74157, 1599, 259, 3, 30, "Output"],
Cell[74419, 1604, 25953, 427, 280, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100409, 2036, 4773, 122, 413, "Input"],
Cell[105185, 2160, 188, 3, 30, "Output"],
Cell[105376, 2165, 24723, 406, 260, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130136, 2576, 4402, 113, 297, "Input"],
Cell[134541, 2691, 1631, 31, 191, "Output"]
}, Open  ]],
Cell[136187, 2725, 1050, 24, 92, "Input"],
Cell[CellGroupData[{
Cell[137262, 2753, 3746, 104, 221, "Input"],
Cell[141011, 2859, 1524, 30, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142572, 2894, 3651, 95, 257, "Input"],
Cell[146226, 2991, 1532, 30, 237, "Output"]
}, Open  ]],
Cell[147773, 3024, 4626, 126, 388, "Input"]
}
]
*)
m63WZNylug
5kk5bFp6YsP/7E3Q+JN2CEpOXPDi/gZ7RrB5Mg5NLs6znn9ZBzVPxkH18Ve7
K3lr7MHGzZR1MJI5wK6ptso+HWyenEPf7wt3wkVWQN0n72B87snaacbLoO5T
cDh+Y8WPY3VLoPYrOMx9XlqW8HERND4VHH5d294X174Q6h5FhxoWf2MD2wVQ
9ys67FQKWB0sPw9qnpLD9fjDkZ++z4aap+QgXfhCxvT/THuwcWeUHGbbmLnN
N5gBdY+yw0c210l6HdOg7ld2WBWW9t2HaSrUPBUHD88VFkdmT7YHAFGPVok=

     "]]}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw10ltI03EUB/DlJqYhTv2bNvOfm7d/y5kLJLr5OxEjsvteZCLYpH80GE0F
RQcWYsuUrWWXh9VD5FojYU1EhiONsanlf92mDXNFMSIoZGWXSdkmTTo+nHP4
wJfz9BU36pRsEo/HkyVm9Yb11MOD4R8kfi9k/yj3k/9eIqGwc1oUfYVeJo01
xQE/8xq9QpRqrfjp/jnStC9tztq0DgwW1wXWNo/mAyeKCk1fQ+hk6HgGbOzv
mlPge6a85NrntXwqXOKLVR7BG/QG6E25cdTtDaLTIeoO9cXZWXQG6LoEk2Z5
gIzShoWTo0KIPJL8/lDzAp0J3bmdyZopDp0Fq5s2PEFnw6mhfJeMm0BTcD/S
oNIovegcUEiNMsEuD3ojFCW+t2nH0LmQoztN/+l2o/NA4PBcDTpc6E2wV74w
eeLYCFoEpTEl0UmH0fnwbaXdWWcZQm+G5rrFAWehA10ASyO+hutVg2gasjOY
2y0GO3oLvBzvOXxlj43Um71Rpr4QJNp2va3cihbDDO99UmrfHbQEltNmjIpZ
C7oI4vNmql99E10MPfZabsdEP7oEnreKNA/GTOhS+HJreufbd5fRZeC/q3D9
jF9EMxCrUlnpgS70VmjmVxOj8DxaCiYmkv64sgO9DQ6d9bup2lZ0ORzxLSYa
0YKWwQHu+GDn7nPoCvhUFqwuMGvQ2+HMeB7X28aSRBn1VEUl/PKtDwem1OQf
lfFS6A==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  ImageSize->{371., Automatic},
  PlotRange->{{0, 10}, All},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044336685413475`*^9, {3.504433912247592*^9, 3.5044339241539946`*^9}, {
   3.504433958529434*^9, 3.504433975467151*^9}, 3.5044340373741937`*^9, 
   3.5044358059794827`*^9, 3.504435849964139*^9, 3.50443590398011*^9, 
   3.5044362648417945`*^9, 3.5044380611477156`*^9, 3.504439179482998*^9, {
   3.504439440094041*^9, 3.5044394638441925`*^9}, 3.504442108610324*^9, 
   3.5044437779932423`*^9, 3.504507598314306*^9, 3.504507680737236*^9, 
   3.504508508453514*^9, 3.504593525057135*^9, {3.5045957800649996`*^9, 
   3.5045957895339317`*^9}, {3.5045959333800097`*^9, 3.504595963692898*^9}, 
   3.5045960442095537`*^9, 3.5046007251144934`*^9, 3.504600832224554*^9, {
   3.504601675058073*^9, 3.5046016898706675`*^9}, 3.5046023722805758`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "represents", " ", "Magnitude", " ", "of", " ", "Magnetic", 
     " ", "Force", " ", "in", " ", "PicoNewtons", " ", 
     RowBox[{"vs", ".", " ", "Height"}], " ", "of", " ", "magnet", " ", 
     "center", " ", "for", " ", "a", " ", "bead", " ", "which", " ", "is", 
     " ", "directly", " ", "below", " ", "the", " ", "magnets", " ", "and", 
     " ", "perfectly", " ", 
     RowBox[{"aligned", ".", " ", "Note"}], " ", "that", " ", "in", " ", 
     "this", " ", "case"}], ",", " ", 
    RowBox[{
    "the", " ", "force", " ", "points", " ", "only", " ", "in", " ", "the", 
     " ", "z", " ", 
     RowBox[{"direction", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zmin", "=", 
     RowBox[{
      RowBox[{"-", "2."}], " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"7.5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fxvzmag", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.5", "+", 
          RowBox[{
           SuperscriptBox["10", "3"], 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], ",", " ", 
         RowBox[{"1.4", "*", 
          SuperscriptBox["10", "12"], "*", 
          RowBox[{"Fz", "[", 
           RowBox[{"0", ",", " ", "0", ",", " ", 
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"zmin", "+", 
               RowBox[{"i", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
              ")"}]}]}], "]"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"fxvzmag", ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5044359811524787`*^9, 3.5044360001526003`*^9}, {
   3.5044392056862907`*^9, 3.504439207733179*^9}, 3.5044397537835484`*^9, {
   3.5044430110379744`*^9, 3.5044430147098727`*^9}, 3.5044438188169737`*^9, {
   3.5045085436981583`*^9, 3.5045085495016823`*^9}, {3.50459359385401*^9, 
   3.504593594619635*^9}, {3.5046043011834598`*^9, 3.504604331246152*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1kXtIU3EUx+fMNafO5pw6p5vz0cOkwqn0j55jUUZoPqKmYWQLBSnbRErL
B4KKkWEq9jRmqVk4WGUUKymv71hbFuUjMp1mD1FQyZXOjLbfXQcu94/L/Zzv
93OkCmVKJpPBYMisj+1Njwn2+qXrJzTOlKc2bvK85zfQfmLl1Z/lUKHpl7vN
m+egOyYj67rKhRJXzCbrxIuwX5OXdqjMldpCvi/Bl4LSgtUKN0pG5jeUv2lh
h4ZzqWjOSLMq2gIPONNZhQIutc9K18atgb4tkd1V+f9/BlatyfmKF2yKrNc6
YOyPtiuf/ZlUBOE54l/NwQLF68XOZyTAOlzVDndWj/QDzWdh8ZnWA5cUZrDC
rMT1+Ko9rj8s1QHpfc4Y1v4Y5AInNBpsw8E+/dUm3TkWpuhsQFdcEAxtDU9i
4aiVxhlxQ3NHpqFwlxOSeOnu6NenOhbZ64i5ZOEGvDiYODAvYiKdj4dpVcOj
mlwG/rKtN/OwxFHcIHiyBnReDyx6dC1E1mWBIiKYjwxL48xO92V7fk9UGf1F
hkYz0PcQ4PEYt6UV5U97HwG+FUqXhYWLQPRXeGGtl2/58/x5oPt54+wK83R/
2hwQHMcH1R8QuHUzQPf1wfv6C5ucvb9DDQEKUVJcm8U2TQPd3xepqJltUV+n
QEAOIELFRga3UjIJtA8R5ntHRyXwJuDmDdv4YW6O7x195BgcJX780ZgicTnc
9BEkJKAY/SST/PGEEZiyxZsUo8nAP5m9Ywju2nDNEtyTMVrF3/0eaH8BmJfs
9IdV+g6InvoAdA95mmrqHQTaZwB65RhPWbsAqSeXoqVEEdzA09v9SrE3m1l2
pHqAzicMxNb42y4+0Gf3HYjKVnlxTUAPkHuOBaIpaVy2sL3L7j8IW9Q9bbFD
L+n86iCMqDuhjL/VYb9HMJbca1J7PNTBP/CuZNQ=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5044359937775593`*^9, 3.504436004262002*^9}, 
   3.504439224780163*^9, 3.504439772627419*^9, 3.5044398053932533`*^9, 
   3.504442129688584*^9, 3.504442837208737*^9, 3.5044430316631064`*^9, {
   3.504443140726304*^9, 3.5044431679452286`*^9}, 3.504443797639272*^9, 
   3.5044438384317455`*^9, 3.5045081633684134`*^9, 3.50459356141651*^9, 
   3.504593624213385*^9, 3.504602397219305*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"xmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Norm", "[", 
         RowBox[{"F", "[", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"xmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}], ",", "0", ",", "zmag"}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvx", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044431874453535`*^9, 3.504443213164268*^9}, {
  3.5044432432738357`*^9, 3.5044433180555644`*^9}, {3.504443360852713*^9, 
  3.5044434125249186`*^9}, {3.5044434896816626`*^9, 3.5044434902910414`*^9}, {
  3.5044435224474974`*^9, 3.5044435256975183`*^9}, {3.504443632588827*^9, 
  3.504443638635741*^9}, {3.504444040913062*^9, 3.504444041194341*^9}, {
  3.50450187631919*^9, 3.5045018768191967`*^9}, {3.504503491464864*^9, 
  3.504503492418001*^9}, {3.5045036899361544`*^9, 3.504503706733244*^9}, {
  3.504509665763323*^9, 3.5045096714987984`*^9}, {3.504513546057684*^9, 
  3.5045135625578947`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-0.2, 1.325217854603624}, {-0.16, 
    1.3230039012060346`}, {-0.12000000000000001`, 
    1.3212661081815176`}, {-0.07999999999999999, 
    1.3200162947394316`}, {-0.039999999999999994`, 1.3192629992704485`}, {0., 
    1.3190113839981095`}, {0.04000000000000002, 1.3192631748228942`}, {
    0.08000000000000002, 1.3200166431542804`}, {0.12000000000000002`, 
    1.3212666245635154`}, {0.16, 1.323004577822832}, {0.2, 
    1.3252186818054665`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.504443304852355*^9, 3.5044433319775286`*^9}, 
   3.5044433768684406`*^9, {3.5044434092905235`*^9, 3.5044434311969137`*^9}, 
   3.504443504541133*^9, 3.504443724822364*^9, 3.504443814409511*^9, 
   3.5044440444134207`*^9, 3.504501891116255*^9, 3.504503509746348*^9, 
   3.504503577262837*^9, 3.504503620700893*^9, 3.5045036788422623`*^9, 
   3.5045037442649746`*^9, 3.5045096241303306`*^9, 3.504509928362895*^9, 
   3.504513580761253*^9, 3.5046041766201625`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"ymin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Norm", "[", 
         RowBox[{"F", "[", " ", 
          RowBox[{"0", ",", 
           RowBox[{"(", 
            RowBox[{"ymin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], 
            ")"}], ",", "zmag"}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044435316819315`*^9, 3.5044435766509695`*^9}, {
  3.5044436414326344`*^9, 3.5044436691671867`*^9}, {3.504444031646489*^9, 
  3.5044440319433937`*^9}, {3.5045020097115226`*^9, 3.5045020103677807`*^9}, {
  3.5045096159881425`*^9, 3.5045096163007026`*^9}, {3.504509748802231*^9, 
  3.5045097559590306`*^9}, {3.5045136113710194`*^9, 3.504513611667898*^9}, {
  3.50451366921551*^9, 3.504513669840518*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-0.2, 1.316856449423227}, {-0.16, 
    1.3176328316568158`}, {-0.12000000000000001`, 
    1.3182361638562416`}, {-0.07999999999999999, 
    1.3186668573287224`}, {-0.039999999999999994`, 1.318925204924186}, {0., 
    1.3190113839350026`}, {0.04000000000000002, 1.318925453263078}, {
    0.08000000000000002, 1.31866735391539}, {0.12000000000000002`, 
    1.3182369089950703`}, {0.16, 1.3176338251472293`}, {0.2, 
    1.3168576918075119`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044435958542175`*^9, {3.5044436605733814`*^9, 3.5044436859991827`*^9}, 
   3.504443860515946*^9, 3.504444035287486*^9, 3.504502025977356*^9, 
   3.504513634527566*^9, 3.5045136834656925`*^9, 3.504513784545111*^9, 
   3.504604157104413*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Here", " ", "we", " ", "show", " ", "the", " ", "dependence", " ", "of", 
    " ", "the", " ", "magnitude", " ", "of", " ", "the", " ", "magnetic", " ",
     "force", " ", "on", " ", "a", " ", "myone", " ", "bead", " ", "as", " ", 
    "it", " ", "varies", " ", "across", " ", "the", " ", "field", " ", "of", 
    " ", "view", " ", "in", " ", "the", " ", "x", " ", "and", " ", "y", " ", 
    "directions", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"labelled", " ", "in", " ", "mm"}], ",", " ", 
      RowBox[{"field", " ", "of", " ", 
       RowBox[{"view", " ", "~", "300"}], "x400", " ", "microns"}]}], ")"}], 
    " ", "for", " ", "a", " ", "magnet", " ", "height", " ", "of", " ", "2", 
    RowBox[{"mm", " ", ".", " ", "Note"}], " ", "the", " ", "change", " ", 
    "is", " ", "less", " ", "than", " ", "1", 
    RowBox[{"%", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"npts", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xmax", "=", 
     RowBox[{"0.2", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"xmin", "=", 
     RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ymax", "=", 
     RowBox[{"0.15", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}], ";", " ", 
    RowBox[{"ymin", "=", 
     RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fvxy", "=", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
       SuperscriptBox[
        RowBox[{"(", "npts", ")"}], "2"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", " ", 
     RowBox[{"i", "<", 
      RowBox[{"(", "npts", ")"}]}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"xm", "=", 
         RowBox[{"(", 
          RowBox[{"xmin", "+", 
           RowBox[{
            RowBox[{"(", "i", ")"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xmax", "-", "xmin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "0"}], ",", " ", 
         RowBox[{"j", "<", " ", 
          RowBox[{"(", "npts", ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"j", "++"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"ym", "=", 
              RowBox[{"(", 
               RowBox[{"ymin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"j", "-", "1"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"ymax", "-", "ymin"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"npts", "-", "1"}], ")"}]}]}]}], ")"}]}], ";"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"fvxy", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", "npts", ")"}], "*", 
                  RowBox[{"(", "i", ")"}]}], "+", "j"}], "]"}], "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"xm", ",", "ym", ",", 
                RowBox[{
                 SuperscriptBox["10", "12"], "*", 
                 RowBox[{"Norm", "[", 
                  RowBox[{"F", "[", 
                   RowBox[{"xm", ",", "ym", ",", "zmag"}], "]"}], "]"}]}]}], 
               "}"}]}], ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]",
            "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{"ListPlot3D", "[", 
    RowBox[{"fvxy", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], ",", "All"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5045161258432026`*^9, 3.5045161392514257`*^9}, {
   3.504516202166936*^9, 3.504516432703556*^9}, {3.50451655128927*^9, 
   3.5045165771503*^9}, {3.504516623808344*^9, 3.50451665691899*^9}, {
   3.504516721968363*^9, 3.5045167437035723`*^9}, {3.5045168149250574`*^9, 
   3.5045168513327055`*^9}, {3.5045169280693765`*^9, 3.504516928444386*^9}, {
   3.5045169792425613`*^9, 3.5045170016493845`*^9}, {3.5045170952299056`*^9, 
   3.5045170957299185`*^9}, {3.5045171389341493`*^9, 
   3.5045172035137596`*^9}, {3.5045174187210164`*^9, 
   3.5045174387370253`*^9}, {3.5045175841304417`*^9, 
   3.5045176248499737`*^9}, {3.5045176590381303`*^9, 3.5045176991013994`*^9}, 
   3.504517730727007*^9, {3.504518546015625*^9, 3.504518547796875*^9}, 
   3.50451868234375*^9, {3.504518777625*^9, 3.504518794765625*^9}, 
   3.504518885703125*^9, {3.50451904915625*^9, 3.504519096671875*^9}, {
   3.504519152859375*^9, 3.504519167109375*^9}, {3.50451929087048*^9, 
   3.504519314417392*^9}, {3.50451940085816*^9, 3.504519430206224*^9}, {
   3.5045196395157194`*^9, 3.5045196473958836`*^9}, {3.5045196935063868`*^9, 
   3.504519693654758*^9}, {3.5045198166380796`*^9, 3.504519818830678*^9}, {
   3.5045202049368258`*^9, 3.5045202197763453`*^9}, {3.5045202863417397`*^9, 
   3.504520297067425*^9}, {3.5045203472198763`*^9, 3.5045203719426937`*^9}, {
   3.5046043542619247`*^9, 3.504604451528172*^9}, {3.5046044903877954`*^9, 
   3.5046044961847076`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyNWXtcztcfL19jlcevPNTTc0npsnq6u23YnrO5ldzSUNotuWRym5FhuSRk
MsSKTYaY8JvChOI5ZqNkjML80sVcxiTKg0T49aznc875njP7/fzj9Xq/Tp9z
vu/z/nzO+/N53GKnRoxrYWVllWBtZSU1/e/fR1t9tbsej+48Iki/wx33n/u8
iz7wIZLjSnz29p7o8s4Ut7L8O7HKOcupK8Vjm9ejqr2HL7LrLfHRe956P18S
X032XeprqnPX8rgSP7Hvr7nckeKw77bFrRxUbhSHfdfcs13Hrod9v4laXu3R
FB/+Hvbds9N62P4OPK7EnqFfeE9xpjj8i/MfsXuXmuKw77RRa7ex62Hfm+sd
B+Y1xQ9oPg+CfX1SvxxvPo8cV+IrrltWms8POMRLmh++2Py9gMO+XyVPbFPe
UYiPZkV6xHgSPvVk37Qh+9pR/vVk35j2t96ooPdF9p33iddCFb1fsm+HOw9+
YNfDvgVFVbZ+TfEL8w+uaFXrhTukht1u2dUN74s5O3mk70PL3zed49T8UJyo
w679t2xPeu0hatxRVzI41hU3zJt4eMYaFV7hO+P33e40zpi//s5kLM31WPhq
II0T89f/Er5yNvCjBh8apzm+AtfU9nzrtgeNA98b/eCirTaAxgH8xrOn+e8x
cQCf2tot/hsPgpPvLepSanvTlcQhuLN90v5sT7IvwSfeCYqZqKfnAZ6fn15r
jGS+C/DudvZlGXp6HsAnhy5/+Jsn/13uKDWv9apGX/673JGx7w3TaW/+u9zR
vZJjkd96ivniNnpTwbROEEdJ8HfvJXbsTfLLluDJie8tUhK9PTECnmfX4+Z1
FY0D9zuh/ofsYToaZ7VFDxcr3LsXqWkc0E/fn9N+MqiE78Ujt8/NmqAXvheP
L33cbrun8L044cXMpBuu/Hcp8XGXjErkwn+XEq/yu7V5q/BdTfrp2WOcjYae
Z2yzPg2zb43YxOqzeb2E/N5Oy2T1uaZZn6gq48zXrD4hv9r0tl/K6hPwHufG
vP4+Ewfw8TEHbpr1Cd8VY8mXfgk30/2F+5LwjfFF2j46+l2QL4sjd2yJ0hDc
APc40CbaPsKJxCF6zvks80INvV+CK29d+XoZuUexLnH1AflEdwqJZHTbzI8O
1S9Xxy5i6sOTZv2g40faJea403OCrrxG2R3UqOk5QVevTUwNOamm5wRdec9V
/JagEc5J6jOnfxxxKm9AilrQP9bGz9l8RyXoH/9ha2gId6JxIH/TA6Mff87c
C+BL/vN91e/MvQCesMi6sL+WvxclHm4IT7LR8PeixIu6OpZv1fL3osR79eXd
3nbhv5e+OxCf6Gdi9nf1THyot+7bn2406wfir7bop8X1IRkrmfgxXHzgAfT/
6vzMzJVM3sVa8iWxbVAWq89YS37dzzyWbT4PxAE9eJed7hvB1BPL+4KO/Lyq
7m/qCYrIeXcjUtF6/tiin0GTxk8z6wrqOejn0AH9MLMOoZ63t+jHU7oXbNYt
ly/4X9fGOg4T8wVP1hRdviPmCz71ru/mFDFfiA4hPujhrnX761QPtuS9nnmx
xPkqcy+AN+5cPTSR+iLBV8jfNSU+mmlqoPXEneCb1P3GmuuP/F1T4gUZ6WfM
9QrifGjRz6Gx3fcu8+TjSLhugLbqCRNnlUU/3oEt2kwK4Pk0GTovKjteL+hc
Qs8vfVTB6tBSx1BxwI0HK0WdE78E8UEPaWvjC5CKxgf9GFYe9WXrBujtz2Ud
NlC9qdEYLj7wADxbN/ZLvsTwAPiCz3otWkf9AMFfPAhKigoU/Ab+6XCGwx+i
38Af1Gw6vF30G7hetzPuY+of0FoLP7/OX+9Tzdwv5J3N3KL+7L2Ms/DfJ6F+
jA1zHuBjpsuKhA1CHCUacTDnCqsTwLtFlITpGJ1Y6jbaeKF1m1wm74D/bK9t
dslM3sF97ZnV2y6K5J2e+EzvyF1HHIMoDj7TrktUiBRMcXgv7rZ95dy9YH69
Ag85f8rPtwvfv0j41JEbz2cLuMkYuv3F2SIRNwwa1aJWxCVU4lb95pwuwr4o
6nbpMnFfsZ8C3gz2qkm1wvl1KHPyp9YtgwV+UGPxmXQnwo+a8Hb9eshhB6pn
wts7GzcsecHgwNvGyLrwmqb8KpL5Mep/5HEU2DMgL0rvyvtMCYcP9EqfLeAm
45wJ6aVFIm5w3VR4X8QltCE/5TwbB/hUXRiQJ+5L+0TIN+Chbcm1JVmOFAce
4huOH17tRHHgocg1+/58Fb9egROsny07IvSDEj6RP7W6jZrHTUbHGVcHvd+E
+/2PcwIP9dE11gohjoSWpiwewfahwINTnm7Hryqhz0Xbr+1vDFIJ34VedxgS
nuYk8IAKDX9kmRwF3lDkpHn1w5vwMXKfT97lInn+kncT+lbAIz8pDWqnozjw
v3ik6ukLBgf+9/X64LhZh/L1CpxyUHHafO/yvljCweGzbecIuMlYdvN6yElX
es407j3i1hsKrZziTorxUZukilA2PvAfLm3V+wrrxf4deBvSEDX6rvBdOtRq
SkielYvAGzJe7WanJHmqJ3y2WvD2BprvesLn7D2nPZn6QPisuRqdY64ngf/4
buoJP9m76m39aL0iPN/r3bpijoCbjN3LHHNOirjBw159RsQlVLxboZnbRdgX
TRtsPUHcV5xLAJ8oa2pYXbDAA5oQfbuK5YH4AYdxM1VBfL8pzh/ge2H+oJf7
T9LPcnMJ0vcFvCTf5X0H7ePIHIfrj57K5yekPwqS+xnSBwXI/RXx+QFyf0V8
PvgbuHfw+eD/4LvAz/vJ+03i5/1k/RH188/kfoD48DFyP0B8uNwXUZ8J52zg
fBrET3uJ/4Fzgv8pkvko6n/g3kEn0bde7PT25u9Xh7zVj48Pp/Misj41oaLt
Ew/hPUWPBtZeWSC8XzoUnX3Bx8tNeK+RsWXB9FNuVCewPrX7vhX11A+T9bVp
6y5uYPoswF3dEnpOob6avO9dXmk1KY/OAYzA/+bqGQ1+zhSH9c/bRQZq1AI/
+KfUwRVrvQQecOnB4kGlbgJvOGh6R6cfO9G8A/yrNxPre/tRHPb9TKVfGOhP
9wVc6jQ0eKo3H0eBL1XUlk8M4PNawiMLbXMOMfMWWB97s8OKnT4vz/f/rz6Y
jHZ3v90QqufnURJWtd01p4cwpzIZe/tqDqaQuRzpU/Ak25BBtE95YgB+Tgb7
JPmTe7El9b+4906HywzO1wFOJzgn2a59gkbQFbYzxFSO0Qr6wbM9fo0vo/GF
ulf4En/I8WPY43muQOTHZLgVO+i3FIEfCY1NVBxieePrKne/6EWuoeZQgKAH
tGT2az3jBT2I8zdYv/fVubdFPYhzOcD5uRzoqrZXa625TsrrvITVo2aNqhRw
cY4HcfIHRFWZtEJeoPhv47VB/kIeoeLGE3v6+An5gtYF4F/M+cLN54X5G/++
QB0GPdRtLr/M5DXRm8tSt+/Med34kjoPdRjiLC+5seQrL6EfFOYwvJ+Uz+Wa
/IZrr3lpzBwJeL5gr22ZreFxk9Gr+Mtx7JwB6uQjKWeBOY/kcwYd2vJcqhvL
zNnIu/Dp/X6zmLki7+sA530d4H/v62wJbyOGnnM4oBHOg0fGRGxmzwPrk/tl
xLPzCt5vc+chfps7P/HbnD4NDmGaMn/Bt0godWx5Aatn3idw92Vo8WDKj2k6
Hhfngbx/kNdDBd5af+yaOMeW8IPcbv2yBVycc0Kc0pqUtx4wczbeF3FzJ+KL
uN8X0Lp/d6urZd5lvj/i8hop3ix6tFXL86BEmR/HhLXSCu818s94nBkn6FlC
SaeiG6OEd1yB2jXcH5qv5tcr0Rav5VkaBof4nYe713/uzMfRoWMLC8IqVTw/
JuMvhrjyNIYf4G3X3PzzjB7I+uFKr3YBHXkd0j5OPsejfZwcp32cvP4o8IRu
H71eLfx+J2H708Uzenq+3E/K648Ch+7N3byLmWvxfSKsh3zx+/NAGeNDSH6t
7/p5QR/qZ8h6xXibfua6zfFpyI9c/1Tk02R4xy8qOKCjwDNa8r2LskqYf9K+
leOT9K0c/6Rv5fIIHcud7jxKzDsUUWk7mdEV/E6BrtplHWV0Bb/XoOk9erVP
dObj6FCLuNK4SmEeq0BftnoctE3IRyVy6boqmckLUm93j/a+FKfh+VGi6PcT
Q+t0Qp0k/QL3fqHIsEcxxzoJ7x2yx9f3n3cT3i8U882amHTm/QJdvfG7754B
en5OK+FpJxwq8wN43GQ8+IFbro0wBzYZ+ie2Gb9M0K2EvnheEsLq+Z/7HZPh
5wbrcQP0PC7Ogfk+iPu9QJgDw745zofX7PLh44vzYdj3z/bVuSwPEGflvspn
8QI/dJ7M5R2aP1WfMM1byC/0oc3gK4wvIve79GjhzL5N+fhfZy3TVw==
   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlElsiFEUhd9DQw0pbSjaGipNNBaqTRotiVkNjTYlWrS0NUZoVWtcGRLD
hpUEK0LCSu0sSCQkVhQ1jzVFIogQC2LjO3ln8eW9/777hnvPvf/E1va6tn4h
hN3QH4ohAxbCNhgBLXAdcmAXXIZhsBPuQyl8hxKYBt+gBoZ47R4UwF/YDMOh
WnfGEI4xHoV3cAC2YstnHAiF3q9zzsNYYDmUeU0+46ErpjOOQLntJY4pC67A
V1gHzXDaPrrnLowJ6R2PYBF8sp/2ToUXsEZnxjRvhJnMXzI2wayY8lUFH+Gx
zxmN/ZbjamN+wznUO385njw47rj0/RkyoRu+wFq/+wMcgu047mfMhnbflel9
l/zOSnzeMx6Uhsy3WK96qOO709qtYN4V0nd9TNrqe6n1mYJtpWtgNTyHVVCB
/Yn9ipn3MI6DPyHZl4QUUI/1+QfTYSjM0VtYq2R84HVpcRYGY68Iae2c43oY
Uo2prgawfjKkOj3jeDPt+wwadA8+fYz7oIj5K8eumv3tfOe7JrKscy0Mko4h
+UvTMvZeZVyv2Jgv9/sXG8U4Gfu8mM6QRntgL0yKKU75XwypTlQzpTHVpPwK
mfcyzlYOmM+ISetu27R/Ara5fqf2ZcrPeevzXS3Y3vidta5D9e8puAaj4La1
k4ZV+Dx1rubHlDdpuoB5a0y1qV7a4J5SXzS7TlQfJdZLPdQQUx11ei3HeW9y
jXV5v/qrKCRfaaF6/Gkd8vzODljmnI+Em/A6pH9PXkz/B9Vzu9+ouw6H1LPq
u1zXvHqkI6Z+yYU78MP3qL92+K5N+Lz198aY/lGqqxPKt/Os2lNuW6EgJt2l
6QW/TfYan6NerLbu0i+HeYbrWbXa6/rKjkl/6dno/4Ni0f9VuqhHy7H/B9gB
kUE=
         "]], Polygon3DBox[CompressedData["
1:eJw1lnmw0FMUx+8l6aV47VHpPa/ltWjVIm1emzbV67V4UkqLqNceEv6QsmTG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         "]], Polygon3DBox[CompressedData["
1:eJwt0jssg1EUwPGvEkMl2BCUiBAslHhUSQ1esWglHlVEK0SpViUSjwW7x2pi
w8QmYSAIk/f7Xe9IMBow+N/0DL+cc+/5vvvd756b5PLVeEM0TUtDKA5hhl6n
aTPEWZSR24kXqCCvRDSiEKPGzB9jAuP4hgG7iKAejgNZN5LcgHgkoI25W8SR
x0rNxfgGpeQNxHPZQzms8s4S1rCu9s5cFfEU6eQZcKIV/cwN4h7VjHuIHjjl
G8nMDUg9hTwVechFgXz/DD7yUeID/OR9eCN/xSJa8C61MeIjtrGDduaGiUNq
HdzJuarzzaLmIM4hkdxGtMKCI6lnIhtNjC/xpPogZ/6MF/wgAXv4xR+mMIlp
mBDGGh3wky9jE1tYxQq6qI0QN2Rd1dcT+Uf1rybqtcQ6NMp9UPsyIgfNjK+0
4Lnl64LP26V/6oz08p+FzJthkXeuMY8FFMl/qnVUvUQXvAduxp2ol36ovbrh
kb4EpL8uuU/qnth0wW855NzU2sXyTre6C9Ir1dMPGLGPT3zBK+cRkP734h8C
9GLD
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{37, 25, 204, 203, 202, 24, 201, 200, 199, 198, 23, 197, 196, 
       195, 22, 193, 192, 191, 21, 127, 126, 125, 16, 103, 102, 101, 100, 11, 
       79, 78, 77, 6, 53, 52, 51, 1, 137, 138, 139, 2, 140, 141, 142, 3, 143, 
       144, 145, 146, 4, 147, 148, 149, 5, 41, 42, 43, 44, 45, 46, 47, 15, 66,
        67, 68, 69, 20, 35, 36, 37}]}, {
      Line3DBox[{2, 32, 33, 34, 7, 54, 55, 56, 12, 83, 84, 85, 86, 17, 108, 
       109, 110, 22}], 
      Line3DBox[{139, 243, 244, 28, 152, 48, 236, 238, 163, 73, 296, 298, 301,
        179, 283, 220, 335, 337, 193}], 
      Line3DBox[{3, 38, 39, 40, 8, 80, 81, 82, 13, 104, 105, 106, 107, 18, 
       122, 123, 124, 23}], 
      Line3DBox[{142, 205, 249, 250, 252, 156, 274, 210, 287, 289, 166, 310, 
       214, 324, 326, 329, 182, 332, 222, 357, 359, 197}], 
      Line3DBox[{146, 268, 270, 271, 209, 160, 167, 314, 317, 321, 171, 346, 
       350, 352, 117, 187, 194, 366, 368, 371, 201}], 
      Line3DBox[{149, 70, 227, 229, 232, 234, 235, 96, 174, 118, 290, 292, 
       295, 190, 355, 356, 136, 204}], 
      Line3DBox[{191, 176, 286, 284, 281, 177, 299, 75, 255, 253, 161, 50, 
       259, 257, 150, 240, 239, 26, 137}], 
      Line3DBox[{195, 183, 334, 333, 330, 180, 327, 216, 313, 311, 308, 164, 
       65, 275, 272, 154, 31, 247, 245, 140}], 
      Line3DBox[{198, 226, 365, 363, 360, 184, 341, 339, 338, 114, 168, 219, 
       307, 305, 302, 157, 263, 262, 261, 153, 143}], 
      Line3DBox[{202, 373, 372, 134, 188, 293, 223, 353, 351, 347, 172, 322, 
       318, 315, 175, 230, 212, 280, 278, 276, 147}], 
      Line3DBox[{138, 242, 27, 241, 151, 258, 260, 207, 237, 162, 254, 256, 
       213, 297, 300, 178, 282, 285, 221, 336, 192}], 
      Line3DBox[{141, 246, 248, 206, 251, 155, 273, 64, 288, 165, 309, 312, 
       215, 325, 328, 181, 331, 112, 358, 196}], 
      Line3DBox[{144, 266, 58, 264, 158, 303, 306, 218, 319, 169, 344, 115, 
       340, 342, 185, 361, 364, 225, 369, 199}], 
      Line3DBox[{145, 267, 269, 208, 265, 159, 304, 217, 316, 320, 170, 345, 
       349, 116, 343, 186, 362, 224, 367, 370, 200}], 
      Line3DBox[{148, 277, 279, 211, 228, 231, 233, 95, 323, 173, 348, 119, 
       291, 294, 189, 354, 135, 374, 203}]}, {
      Line3DBox[{37, 136, 374, 373, 133, 371, 370, 369, 130, 365, 124, 359, 
       358, 113, 334, 110, 337, 336, 99, 286, 127}], 
      Line3DBox[{15, 174, 173, 172, 171, 170, 169, 168, 13, 166, 165, 164, 12,
        163, 162, 161, 11}], 
      Line3DBox[{47, 96, 323, 322, 321, 320, 319, 93, 307, 82, 289, 288, 65, 
       56, 238, 237, 50, 79}], 
      Line3DBox[{51, 26, 242, 243, 32, 245, 246, 29, 249, 38, 261, 57, 266, 
       267, 268, 60, 276, 277, 70, 41}], 
      Line3DBox[{69, 295, 294, 293, 121, 117, 343, 342, 341, 107, 329, 328, 
       327, 90, 86, 301, 300, 299, 76, 103}], 
      Line3DBox[{6, 150, 151, 152, 7, 154, 155, 156, 8, 157, 158, 159, 160, 9,
        230, 231, 232, 44}], 
      Line3DBox[{77, 257, 258, 48, 54, 272, 273, 274, 63, 80, 302, 303, 304, 
       91, 314, 315, 94, 233, 234, 45}], 
      Line3DBox[{100, 253, 254, 73, 83, 308, 309, 310, 87, 104, 114, 344, 345,
        346, 347, 348, 118, 66}], 
      Line3DBox[{125, 281, 282, 283, 97, 108, 330, 331, 332, 111, 122, 360, 
       361, 362, 128, 366, 131, 134, 354, 355, 35}], 
      Line3DBox[{36, 356, 135, 372, 132, 368, 367, 129, 364, 363, 123, 357, 
       112, 333, 109, 335, 98, 285, 284, 126}], 
      Line3DBox[{42, 227, 71, 279, 278, 61, 270, 269, 58, 262, 39, 250, 30, 
       248, 247, 33, 244, 27, 239, 52}], 
      Line3DBox[{43, 229, 228, 72, 280, 62, 271, 59, 265, 264, 263, 40, 252, 
       251, 31, 34, 28, 241, 240, 53}], 
      Line3DBox[{46, 235, 95, 318, 317, 316, 92, 306, 305, 81, 287, 64, 275, 
       55, 236, 49, 260, 259, 78}], 
      Line3DBox[{67, 290, 119, 351, 350, 349, 115, 338, 105, 324, 88, 312, 
       311, 84, 296, 74, 256, 255, 101}], 
      Line3DBox[{68, 292, 291, 120, 353, 352, 116, 340, 339, 106, 326, 325, 
       89, 313, 85, 298, 297, 75, 102}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJyVmHc01fH/x2lQSpFRqEhLkkRW6yVZkWTvjFIkRHYlSRrKzHaNa5SE7O1t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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  ImageSize->{454.81444033988305`, 222.},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{-0.0002, 0.0002}, {-0.00015, 0.00015}, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  ViewPoint->{1.0803140904432877`, -3.1238867509255064`, 0.7240531978948108},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{
  3.5045196521272793`*^9, 3.504519694627414*^9, 3.504519823512617*^9, {
   3.5045200020014706`*^9, 3.504520012598179*^9}, {3.504520208634903*^9, 
   3.5045202204215417`*^9}, {3.5045202929982796`*^9, 
   3.5045202984810553`*^9}, {3.5045203481308823`*^9, 3.504520376136463*^9}, 
   3.504520422613476*^9, 3.5046036543511953`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"7.5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"phi2", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"360", "*", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"F", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", 
      "2"}], "/", "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"zmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{"phi2", "[", 
        RowBox[{
         RowBox[{"0.2", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "3"}]]}], ",", 
         RowBox[{"0.2", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "3"}]]}], ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"zmin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
           ")"}]}]}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Zmag", ",", " ", "Degrees"}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5063424554294305`*^9, 3.506342527836144*^9}, {
  3.506342662399505*^9, 3.5063426763058443`*^9}, {3.5063428564788723`*^9, 
  3.506342860932026*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdkXkw1HEAxX+7m5V1tLutdey2K6lMxpgG48p8X5mU2CSVsxhDh5SGppHp
0Gk6KTpQKU2k0rjGNOUayWym3ZBSI7ZLolTGkL1of783853vX9/3fZ/3Fial
b0xhUxTlaTr0XVxE6yXxv/Ylq3BHKFpKHT0GXN4RVc4zjSIfqMnYeWnskIZE
jUScbI3yRrdzv/ZI6jcypLib/VHijnVWbLdc8QjJcCIxYR9c0DbpGp/XNkY+
lsbu4kXIcetPRUeozzjJPV4+2FBlj9jkAE34hQmiXxsen5Asgt0H9b/Ir5OE
6ynvVRcJ0KtI4kf7TZOB4qvj1afmIY8x1JFcHy+qwsoaYT5nViYOGciR37Zx
HVssYfFIarKcJd+dpLaOUh7o1/VKCv39mawtHhZo7byzumGChcj0Tyv0mXMh
P/Uz4omMg+eG5qOC9+Y4TLy3PQ2ZA36MxNl/gzlousb9ZohcHDND3nLhX688
0FzKRde/YF5BEhfX9wpPtHaag7uqcnTTpBmmaNzJuZBOCAqbz5lh89d7Je1O
PKzTGHY2uZih9iZdgCWCFwhldS2mf+h4B6wQLFR1hcbPQTptd8ca/Lg9p5N0
HKhe0bKB0u7N6O8iDpblik0NzQPrwfYErT8H7U7VpkX4+ME661wwwMaEsTdr
ZIkAt6vy3bqPscHM0yhAljhkWrmUjY1PZCZiISo7FPkXX7OQcyXoXNqwEBn5
yn2eB1moZvadj8eHfAdfuLBgGufaXqEIEQpOy4YeCjbuNIEI0qmH9/uPUQjk
9d3dF2iLup4x1m5PCmnD+srxHlvE/a3NotSzpIQJKIZGtT7Hy2+WMPUbxdAO
uHrsvj9DdHS9BXZQfxotL5LMEKY+V3t8i+6rr7lsJEw9zfY4ujwzvMzaSBj8
SAeEZ343Rp03kAYG2AFtvvzGJhsDGeqiiR1hkb20rLFQT0SP13zOFkkQ1O21
KFCmJzStvlICr7O/SpY81BEGl0ghWiGXJwboSBkdr1eKG0JNSJdaSxi71AU4
HTxydWuKllCMZAiqUln8mZkm/wF0AXeu
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["Zmag", TraditionalForm], 
    FormBox["Degrees", TraditionalForm]},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.506342597195963*^9, 3.5063429309012237`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Plot"}]], "Input",
 CellChangeTimes->{{3.5063426173054667`*^9, 3.5063426183210983`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Plot\\\", \\\"[\\\", RowBox[{StyleBox[\\\
\"f\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) generates \
a plot of \\!\\(\\*StyleBox[\\\"f\\\", \\\"TI\\\"]\\) as a function of \\!\\(\
\\*StyleBox[\\\"x\\\", \\\"TI\\\"]\\) from \
\\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]]\\) to \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]\\). \\n\\!\\(\\*RowBox[{\\\"Plot\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) plots \
several functions \\!\\(\\*SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.506342619086728*^9},
 CellTags->"Info3506346218-2109733"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"phi2", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"360", "*", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"F", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", 
      "2"}], "/", "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"zmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"F", "[", 
            RowBox[{
             RowBox[{"0.2", " ", 
              SuperscriptBox["10", 
               RowBox[{"-", "3"}]]}], ",", " ", 
             RowBox[{"0.2", " ", 
              SuperscriptBox["10", 
               RowBox[{"-", "3"}]]}], ",", 
             RowBox[{"(", 
              RowBox[{"zmin", "+", 
               RowBox[{"i", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
              ")"}]}], "]"}], "]"}], "-", " ", 
          RowBox[{"Norm", "[", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", " ", "0", ",", 
             RowBox[{"(", 
              RowBox[{"zmin", "+", 
               RowBox[{"i", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
              ")"}]}], "]"}], "]"}]}], ")"}], "/", 
        RowBox[{"Norm", "[", 
         RowBox[{"F", "[", 
          RowBox[{
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", " ", 
           RowBox[{"0.2", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]]}], ",", 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Zmag", ",", " ", 
      RowBox[{"change", " ", "in", " ", "force"}]}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5064007980446672`*^9, 3.5064008717951393`*^9}, {
  3.506400989047954*^9, 3.5064010288945093`*^9}, {3.5064012127355757`*^9, 
  3.5064012369560304`*^9}, {3.5064014612751627`*^9, 3.506401462681449*^9}, {
  3.5064016748103685`*^9, 3.506401686810522*^9}, {3.5064019226729164`*^9, 
  3.506401923626054*^9}, {3.5064019797048965`*^9, 3.5064019807986603`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtknkwFGAYxjdkaKTGmmx0EJUONZJB0rMsNbZMLYWRNbXSpHJU6NrGaMcR
U3KVnJuVHA1aOaM1Ua0Sa3SsRq1qO8xSuRex7UfvzDfff8+8v9/zmnHCPIM0
KBSKjfqRP+sOmTZYMYYLlbMSBKcMcmHbAY8GE55E8zVyWk0rz57oQpxSailT
icFrfnnXraYbpfYlJrV1z3CqMSKNpvUO/eFXlAaaLfCsWxWrYEmh96zsUu6T
Zux4JI56kv8BWW8ZDsFFTTBTp6UM9qLl/WBIPLsBug9W+B1zlEGu2tq0L74W
Sq+v97Jb+7DBjb57SL8aAywS+Bmrd+brRMiF6Nt//XaowVdItlSk+k1XotuD
s9TXQQ4LWpwiJa0cz/faXXM+8g1nt8eOCpPL0OCup7Ep/jsCX9W7uX4qRvme
z5cMy3+gn9t9tCaiCAVuNSMzb37CPnlIuoNZiFuMpNM/pvtR5fTWMtCnACRM
skaBrgjbUGkGH1dgG9DgPgAa9YAjk5KHM06L3gvCB9HznVlmZJ6NIEeZesNf
EHHpyZ1JmfB1IAJ+44GeEdPS5haKsonQP+BTq/kPDdLBN9760UJ7CO2a9x9W
W6Rivo8h7Cw5KF997CbSaVre+lbD8H6TeEGSeR031PS85mEwhtcv0KpKRMKy
no4JrxGohJP+WUsSEJNBAEbwWve8nFoci8uGhHgU0VnXMrOjeIhMI4FjUBm7
ho1GxiDMgDQ6BsHyVO0ul+j//Y+jwu6RUWT/ZQQuJQTjONzIvmotvQB28tMx
S/8JHAp0oa/RiYKPvpUw9/cEOKVd9YvPnQOL1MNTwoj5LYdFPQMm0b9sEk5t
la8KXoTAlegtmURqLmNvuygYu4g+pylQxHaKPO3jsJ8TPgV2YabYPZ2DbTrk
QKYxm58hMG0JwOZ4AjwN7so9RexOX6zTJsR/wepsmuHSvWCqvr66VTN4LBZ8
OWm4D8ZEn3AGAxtj+WudXUCdO+BZlHWYlSTJrDG3Xs8s4szHTS+OVu2aizut
Aq1XkNG60FpEmR96u4LjmNhEF/0DA+eLug==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["Zmag", TraditionalForm], 
    FormBox[
     RowBox[{"change", " ", "force", " ", "in"}], TraditionalForm]},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.5064010200501366`*^9, 3.506401151762533*^9, 
  3.50640164756002*^9, 3.506401862265893*^9}]
}, Open  ]]
},
WindowSize->{1272, 907},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3506346218-2109733"->{
  Cell[68961, 1533, 1768, 30, 62, "Print",
   CellTags->"Info3506346218-2109733"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3506346218-2109733", 76420, 1720}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 19018, 469, 1751, "Input"],
Cell[CellGroupData[{
Cell[19588, 493, 3535, 87, 155, "Input"],
Cell[23126, 582, 2688, 49, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25851, 636, 2724, 69, 155, "Input"],
Cell[28578, 707, 1589, 29, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30204, 741, 2003, 52, 115, "Input"],
Cell[32210, 795, 1134, 21, 220, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[33381, 821, 1808, 49, 109, "Input"],
Cell[35192, 872, 910, 19, 212, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[36139, 896, 5835, 135, 388, "Input"],
Cell[41977, 1033, 22948, 384, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64962, 1422, 2405, 72, 135, "Input"],
Cell[67370, 1496, 1434, 28, 251, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68841, 1529, 117, 2, 31, "Input"],
Cell[68961, 1533, 1768, 30, 62, "Print",
 CellTags->"Info3506346218-2109733"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70766, 1568, 3720, 104, 177, "Input"],
Cell[74489, 1674, 1524, 30, 245, "Output"]
}, Open  ]]
}
]
*)
";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxvzmag", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2.5", "+", 
        RowBox[{
         SuperscriptBox["10", "3"], 
         RowBox[{"(", 
          RowBox[{"zmin", "+", 
           RowBox[{"i", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
          ")"}]}]}], ",", " ", 
       RowBox[{"-", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", " ", "0", ",", " ", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"zmin", "+", 
              RowBox[{"i", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
             ")"}]}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fxvzmag", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.50443366052562*^9, 3.504433661260004*^9}, {
  3.504433868981413*^9, 3.5044339228414774`*^9}, {3.5044339534199944`*^9, 
  3.5044339728264923`*^9}, {3.50443403123349*^9, 3.504434033952275*^9}, {
  3.5044358478547506`*^9, 3.50443584849538*^9}, {3.5044358917300315`*^9, 
  3.5044358922925353`*^9}, {3.50443941573451*^9, 3.5044394600785437`*^9}, {
  3.5045075838141203`*^9, 3.504507586829784*^9}, {3.504507678940338*^9, 
  3.504507679268467*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw10WtIk2EUB/CZIW5azXmbbuamflkFGWukYT4nySJI0LWStFIEb2EXKhsF
XlZNh2mlBTkRdUvFMkS3JtNmOs1Z7lJTSBwadvlSWYmj4bRl7e104OHh5T3n
d/7w8PPOi/M30Gg04d/jvf+X2aXcsie0I6lN6a1X5OhFWYIxook0Ut+zxDgj
fF0X/5jsFnrrI2mpeXDnyIgW/38mt/Kgf7J6kPzTlojoZFKZfHCEUO1CJ2FK
k7dlHnhBCqhykUbPjdNVcxOkiZp3k27Ndb+0UjOxWbz1iwQs1+4sWrahRwOp
2O2sCrJjvw84FK7ow7lTmMcXlA2Sy/Z908RKzW+Ema7n5QW3p3GfH8gz3opl
4mn0/EF1NXPc1jmFHh2GHMaQH1o7egEwyGmoFrW8wTyBEO/Iz4r8bUNvM5RY
VlcyzBb0mLDjy/uw8KeT2M+E1uOd21uGX6IfBNr81aKoJRPOs2BtVGHmpY7j
vmCov8JJWzCMoRcC99R0vUcyil4IiBKb474yjOiFQmhdFmO/fhi9MJhNXYeS
2iH0wqFMMFaxUPcMPTacYjHscv0AemzglKc71P569CLAnT3xaeZaP3qRcKHf
EMEO1OH7ccC6vneXekBLfCiPC5tGuYnuSg16XDg7yzHN5/QRilNGQc47Q98h
SS8ppLytQF9qnR/R92C+aMiuLP6wtvgE8/Egt/luclJKN+7nQaGgVzaue4Tv
yYOBResQJ7UL8/DhZw2L6fnWifn5cFDOnsvu6UAvBoITLnWcuNmOXgyIHGml
KeceEoqzxED8Cs+gOKPGPLFwrL1YZZSqMH8smJp9dar7bejFgUZQ/91Z0Ur+
ACi9YUU=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044336685413475`*^9, {3.504433912247592*^9, 3.5044339241539946`*^9}, {
   3.504433958529434*^9, 3.504433975467151*^9}, 3.5044340373741937`*^9, 
   3.5044358059794827`*^9, 3.504435849964139*^9, 3.50443590398011*^9, 
   3.5044362648417945`*^9, 3.5044380611477156`*^9, 3.504439179482998*^9, {
   3.504439440094041*^9, 3.5044394638441925`*^9}, 3.504442108610324*^9, 
   3.5044437779932423`*^9, 3.504507598314306*^9, 3.504507680737236*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"m", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Normalize", "[", 
     RowBox[{"H", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "*", "V", "*", "msat", 
    "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Coth", "[", 
       RowBox[{
        RowBox[{"Norm", "[", 
         RowBox[{"B", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "/", "B0"}], "]"}],
       "-", 
      FractionBox["B0", 
       RowBox[{"Norm", "[", 
        RowBox[{"B", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mdb", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", " ", 
   RowBox[{"DotProduct", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"m", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ")"}], ",", " ", 
     RowBox[{"B", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5045077380348444`*^9, 3.5045077764884615`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Grad", "[", 
     RowBox[{"mdb", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.50450778694172*^9, 3.504507832489178*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mdb", "[", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "1.0"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5045078411455393`*^9, 3.504507851614423*^9}, {
  3.504507884677346*^9, 3.5045079169121337`*^9}, {3.5045079546626167`*^9, 
  3.504507955522003*^9}, {3.5045079948662567`*^9, 3.504507997944421*^9}}],

Cell[BoxData["4.3329373112489226`*^-14"], "Output",
 CellChangeTimes->{{3.5045078696146536`*^9, 3.5045078914899335`*^9}, 
   3.5045079225372057`*^9, 3.5045079569282713`*^9, 3.50450799863193*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Fz", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Epsilon]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"mdb", "[", 
       RowBox[{"x", ",", "y", ",", 
        RowBox[{"z", "+", "\[Epsilon]"}]}], "]"}], "-", 
      RowBox[{"mdb", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.504508001147587*^9, 3.5045080690234556`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fz", "[", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "1.0"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5045080722891226`*^9, 3.5045080934300184`*^9}}],

Cell[BoxData["7.964337634230051`*^-12"], "Output",
 CellChangeTimes->{{3.5045080852267885`*^9, 3.50450809433628*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{
    RowBox[{"-", "2."}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"7.5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxvzmag", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2.5", "+", 
        RowBox[{
         SuperscriptBox["10", "3"], 
         RowBox[{"(", 
          RowBox[{"zmin", "+", 
           RowBox[{"i", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
          ")"}]}]}], ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", 
         RowBox[{"0", ",", " ", "0", ",", " ", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fxvzmag", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044359811524787`*^9, 3.5044360001526003`*^9}, {
   3.5044392056862907`*^9, 3.504439207733179*^9}, 3.5044397537835484`*^9, {
   3.5044430110379744`*^9, 3.5044430147098727`*^9}, 3.5044438188169737`*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1kn1I00EYxzd1vsx0m27qtL1ruiWWGSKi3SNYrnLgNPSPFEqTqBC1oGBJ
BWohGi4RQ4Wy7EVqTdP+sIn48wUsMWWMNGPqlFTSsk2aUzFru1sPHMdx3Of5
fr/PSQpLs4s9aDRagnO5dlIWFFVc+XdsXEJx9RkLGu4y+qnTjAyUSClFfv2Q
PeYHqrMy2GKBjBJWr6l7hTbkfz/5doNZRsnx/W9kUabOfdZGUgm4HMije3CD
7hdFpTKn28tSdxDrVVfiTXskpXTS9Rl/UHLiSJFi4f97GhRFq8uUxyQUbq+n
Q9OKT3RnOp86inme8Jhff8Xf7Eu9xwK8wOuuIi3m1DwifG+4t6UvWe4PACfM
SfSBTvOagXsgDEg/Pxid7qjYKRDAp3FXMUHOsaoUWSLI7nUB90F9kvBtVqgI
vjhpzOkAOGO02lhtAsDy8lmgtah1b2ojoBw3ZMP2B4mhJYUPRB8HuGlPSjtW
Q2DT1d7OgcrQFENODxeI3iBgeVyoffosCCpwwMFQHn4ycmqYDUQ/FwLnb0gN
0kAg8+BBrbnAmBji7/bDg81ZU1bJWV/A8VeHwJ1b8TWtqwy3v1DQcA6zBvs8
AeOYYTA0eW6PPUp3+w2DzdhJRwqDBloM5MOWLU+umt9FxH84yOuq4r3oO4iH
BxABDN2JOFOxA5E8IiCdoWX3MeyopdlV++Ei79Lc5a8bqADnI4Dvft39e3NW
JMIChWCLM+6eF62jRZe8BedZZzEyTavouQvXLoK2dVXLtmkFkfzE4GhVRXUK
lhCOp1EMvw7GNk+9XkQkTzEc/8g9zdVYELaXJ4EjS5nXv/nMIpKvBKqSMnOH
a2aIPr4UDtU0zjSUTSGStxS6gscmEnpMCM/TLIVr4ocDw0qj+//IIPcBzbtS
PUH0P5JB4dX2FzlNY4jMIxKaX46/46lH0T/+zWJa
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5044359937775593`*^9, 3.504436004262002*^9}, 
   3.504439224780163*^9, 3.504439772627419*^9, 3.5044398053932533`*^9, 
   3.504442129688584*^9, 3.504442837208737*^9, 3.5044430316631064`*^9, {
   3.504443140726304*^9, 3.5044431679452286`*^9}, 3.504443797639272*^9, 
   3.5044438384317455`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"xmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xmin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "0"}], " ", ".5", " ", "*", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvx", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044431874453535`*^9, 3.504443213164268*^9}, {
  3.5044432432738357`*^9, 3.5044433180555644`*^9}, {3.504443360852713*^9, 
  3.5044434125249186`*^9}, {3.5044434896816626`*^9, 3.5044434902910414`*^9}, {
  3.5044435224474974`*^9, 3.5044435256975183`*^9}, {3.504443632588827*^9, 
  3.504443638635741*^9}, {3.504444040913062*^9, 3.504444041194341*^9}, {
  3.50450187631919*^9, 3.5045018768191967`*^9}, {3.504503491464864*^9, 
  3.504503492418001*^9}, {3.5045036899361544`*^9, 3.504503706733244*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1k21Ik1EUxzc/jLKIiMhYGhYpRWDGKmlbO9mXslDJokgkzLIXsQk2Dcfc
FpQRvSjOcpuLRWRUjBgxYg7d2dbMVTQhGhQaYX0QMwqfS0ZtWts93guXh8t5
7nn5/393XV1TVX2WTCZTpXfm63Rk1ivUblKqf7kl/GtuGDTYYnjtzfuWQp+E
1ac0nytvjuBY/2TFuREJA2VLszZffYkrDoWPhT9KuGbLpw2KS8PorNNpVNMS
Glc+3TthjOJobk57LCnh2J9Mwhd4P3v/6IUlDLXpbL36CAZDd/L2KBm6ovne
5rNh/GE54962kWHq8cy78roQZi+v76nYztC/9sr0QX8QQ0VxZXcpw7apwq2L
PIOY8owH5OUMd/pirUF3AI98e1jiPsqQl7P50VqgPdl4gi30+xxXfa8MNzSw
hf58WNbRWOBqZqjh/TzDvnhJXG5kmOT1vThwms28tjJs5fU8eDm5w6DvYDjL
8z/CPHvOrYvX03Ge7wHqv/TN+jvF/XvY032+VmUT/9ux0mipmbzN8DePd+GE
d6A60cvwJz9b8Ub06/CcnaEss3ZbtG+LI6ZaB8NlT3gcRFzBz11wvI3uz1N+
EPn/UX1wyvW8vpn6A9FfloX3D6J/M80HYr45mh8wQfPrSB8Q+phIPxD6BUlf
EPqmSH9o+qDm+uvIH4Cifu6PifwDg4L8GyJ/YV+C/J0n/0H4f5f4AMHHLuIH
BD/jxBcU5x/gfLUTf1B1mPjLJT5h/WLgfA4Rv7A6QvzWEN/Q4pjifCeJf+hU
Jzj/LnofUGqn9/EfOk7Jqw==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.504443304852355*^9, 3.5044433319775286`*^9}, 
   3.5044433768684406`*^9, {3.5044434092905235`*^9, 3.5044434311969137`*^9}, 
   3.504443504541133*^9, 3.504443724822364*^9, 3.504443814409511*^9, 
   3.5044440444134207`*^9, 3.504501891116255*^9, 3.504503509746348*^9, 
   3.504503577262837*^9, 3.504503620700893*^9, 3.5045036788422623`*^9, 
   3.5045037442649746`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"10", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"ymin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{"0", ",", 
          RowBox[{"(", 
           RowBox[{"ymin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044435316819315`*^9, 3.5044435766509695`*^9}, {
  3.5044436414326344`*^9, 3.5044436691671867`*^9}, {3.504444031646489*^9, 
  3.5044440319433937`*^9}, {3.5045020097115226`*^9, 3.5045020103677807`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEqB67ss3Ty1svYbwwGygfCXvut8nmetT8NDJQO
TDjGM/MIV87+WTNBQPHAzMCdoparM/efPQMCCgdOHFw+xyopYT/EPIUDOW2z
V8ZNcLOH6Jc7oL7NMGm+QKU9RL3MgT97+w9rzZ5gD7FP+sCLh/sdL6QvtIeY
L3lg67G0n6kJG+wh5kkcuBi6JGzd+T1Q88QOJGe/f5IjdgJqnsgBlsBU0YMe
l6HmCR+o0fFuVN18F2qe4IE3rTdrN4s9g5oncICXX2Gn3533UP08B3yK2zOY
Q75B1XMe2N3Omh4U+Q9qH9sBn7/WE9Y9YHaAmM98IGji/IJHLzkcoAF4wOfm
vjdHD/E6QPT/3N8p9Vzg+A8BqPrP+y8kuvj1zRCCyr/c7/ZphtPFHcJQ/s39
QZPnXP8ZLwIzj+EMy/oTLdNEYPL2MHmofnuYfqj59qjm/7SH2Q81zgHmPqj7
HWDuh/rPAeY/qP8dYP6Hho8DLHyg4ecACz9o+DrAwhca/g6w8IfGjwMsfqDx
5wCLP2j8OsDiFxr/DrD4h6YPB1j6gKYfB1j6gaYvB1j6gqY/B1j6g6ZPB1j6
hKZfB1j6haZvB1j6hqZ/B1j6h+YPB1j+AADPDWXd
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044435958542175`*^9, {3.5044436605733814`*^9, 3.5044436859991827`*^9}, 
   3.504443860515946*^9, 3.504444035287486*^9, 3.504502025977356*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"xmin", "+", 
       RowBox[{"i", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"ymin", "+", 
       RowBox[{"j", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}], ",",
      "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox["10", "12"], "*", 
  RowBox[{"F", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.504443983547814*^9, 3.50444409626248*^9}, {
  3.504444591013158*^9, 3.5044446555616856`*^9}, {3.5044447152507133`*^9, 
  3.5044447223915215`*^9}, {3.504444989303854*^9, 3.5044450692741394`*^9}, {
  3.504445100087231*^9, 3.5044451413067727`*^9}, {3.504445179573085*^9, 
  3.504445199213961*^9}, {3.5044452396363535`*^9, 3.5044452410582466`*^9}, {
  3.504445274293047*^9, 3.504445280293124*^9}, {3.5044454298106627`*^9, 
  3.504445434857602*^9}, {3.5045013339216223`*^9, 3.504501334562256*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.010417453958328446`"}], ",", "0.5166533014621376`", ",", 
   "0.11287531272545727`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5044452186204596`*^9, {3.5044452538396606`*^9, 3.5044452815118895`*^9}, 
   3.5044454416545644`*^9, 3.5045011404035206`*^9, 3.5045013382029276`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "[", 
  RowBox[{"0.0", ",", "0.0"}], "]"}]], "Input",
 CellChangeTimes->{{3.504501220357669*^9, 3.504501239357912*^9}, {
  3.5045012788115425`*^9, 3.504501281233448*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0002`"}], ",", 
   RowBox[{"-", "0.00015`"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5045012234358335`*^9, 3.5045012398266683`*^9}, 
   3.5045012816709538`*^9, 3.5045013414060936`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["ymin"], "Input",
 CellChangeTimes->{{3.5045013203433237`*^9, 3.5045013228277307`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", "100"]}]], "Output",
 CellChangeTimes->{3.504501323483989*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.504445158353975*^9, 3.5044451769480515`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", "0.00012`"}]], "Input",
 CellChangeTimes->{3.504446620091523*^9}],

Cell[BoxData[
 RowBox[{"-", "0.00012`"}]], "Output",
 CellChangeTimes->{3.5044466201227736`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["10", "12"], "*", 
          RowBox[{"F", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]]}]}], "]"}]}]}]}], " ", "}"}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "npts"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "0", ",", " ", "npts"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{"fxy", ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.504445298183978*^9, 3.5044454150292234`*^9}, {
  3.5044454709518147`*^9, 3.504445502561594*^9}, {3.5044455641717577`*^9, 
  3.5044455770156717`*^9}, {3.5044456388758388`*^9, 3.5044456452352953`*^9}, {
  3.504446581153525*^9, 3.5044465816847816`*^9}, {3.504500204329039*^9, 
  3.504500219844863*^9}, {3.504500256110952*^9, 3.5045003235649405`*^9}, {
  3.504500388425145*^9, 3.5045003976440134`*^9}, {3.5045013515624733`*^9, 
  3.504501352124981*^9}}],

Cell[BoxData[
 Graphics3DBox[{{
    Arrow3DBox[{{-0.0002, -0.00015, 0}, {-0.18525512893991844`, 
      0.16647626544725413`, 5.160489014386318}}], 
    Arrow3DBox[{{-0.0002, -0.00011999999999999999`, 0}, {-0.1851724312533626, 
      0.13307528773117838`, 5.163160009081063}}]}, {
    Arrow3DBox[{{-0.00016, -0.00015, 0}, {-0.14884814661079715`, 
      0.16656481686984628`, 5.153001244008351}}], 
    Arrow3DBox[{{-0.00016, -0.00011999999999999999`, 
       0}, {-0.14879549160161087`, 0.1331476210791715, 5.155677663118941}}]}},
  AutomaticImageSize->True,
  BoxRatios->{1, 1, 1},
  ImageSize->{315.6566907277673, 320.4299606415143},
  ViewPoint->{0.26573989853559116`, -3.3103483242542997`, 0.6488268478053623},
  ViewVertical->{-0.06778576211178625, -0.4334804025960546, 
   0.8986099437576277}]], "Output",
 CellChangeTimes->{3.5045013655470276`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"fxy", ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{
    ArrowBox[{{-0.0002, -0.00015}, {-0.00038505512893991845`, 
     0.000016626265447254157`}}], 
    ArrowBox[{{-0.0002, -0.00011999999999999999`}, {-0.0003849724312533626, 
     0.0000131952877311784}}]}, {
    ArrowBox[{{-0.00016, -0.00015}, {-0.0003086881466107972, 
     0.000016714816869846318`}}], 
    ArrowBox[{{-0.00016, -0.00011999999999999999`}, {-0.0003086354916016109, 
     0.000013267621079171511`}}]}},
  ImageSize->{253., Automatic},
  PlotRange->{{-0.0002, 0.0002}, {-0.00015, 0.00015}}]], "Output",
 CellChangeTimes->{3.504501422469631*^9, 3.504501725520385*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["fxy"], "Input",
 CellChangeTimes->{{3.504500809789914*^9, 3.504500810211794*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.0002`"}], ",", 
          RowBox[{"-", "0.00015`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.00038505512893991845`"}], ",", 
          "0.000016626265447254157`"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.0002`"}], ",", 
          RowBox[{"-", "0.00011999999999999999`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.0003849724312533626`"}], ",", 
          "0.0000131952877311784`"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.00016`"}], ",", 
          RowBox[{"-", "0.00015`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.0003086881466107972`"}], ",", 
          "0.000016714816869846318`"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.00016`"}], ",", 
          RowBox[{"-", "0.00011999999999999999`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.0003086354916016109`"}], ",", 
          "0.000013267621079171511`"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5045008108055515`*^9, {3.5045008528998404`*^9, 3.504500928728936*^9}, {
   3.504501047886711*^9, 3.504501073012033*^9}, 3.504501162435053*^9, 
   3.504501443704278*^9, {3.504501634831724*^9, 3.5045016618008194`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"r", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"r", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"r", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "+", 
         RowBox[{
          SuperscriptBox["10", "7"], "*", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"r", "[", 
                 RowBox[{"i", ",", "j"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"r", "[", 
                 RowBox[{"i", ",", "j"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox["10", 
                 RowBox[{"-", "3"}]]}]}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"r", "[", 
                 RowBox[{"i", ",", "j"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"r", "[", 
                 RowBox[{"i", ",", "j"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox["10", 
                 RowBox[{"-", "3"}]]}]}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "}"}]}]}]}], " ", "}"}], 
      "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "npts"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "0", ",", " ", "npts"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5045005394583282`*^9, 3.5045006501628704`*^9}, {
  3.5045006884289856`*^9, 3.504500689725877*^9}, {3.5045007355233383`*^9, 
  3.504500771211295*^9}, {3.5045008357746215`*^9, 3.5045008896971865`*^9}, {
  3.5045009234476185`*^9, 3.504500923885124*^9}, {3.5045009673544307`*^9, 
  3.5045009864015493`*^9}, {3.504501041355378*^9, 3.5045010674963374`*^9}, {
  3.504501395391159*^9, 3.5045013962036695`*^9}, {3.504501615847106*^9, 
  3.5045016451443563`*^9}, {3.50450170639514*^9, 3.50450172084845*^9}, {
  3.5045017618333497`*^9, 3.504501765208393*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "0"}], ";", 
  RowBox[{"j", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"r", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"r", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox["10", "10"], "*", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]]}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]]}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], " ", "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "+", 
  RowBox[{
   SuperscriptBox["10", "7"], "*", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}]}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], " ", "}"}]}]}]}], "Input",
 CellChangeTimes->{{3.504501535158573*^9, 3.5045015796903934`*^9}, {
  3.504501791630606*^9, 3.5045017931306257`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0002`"}], ",", 
   RowBox[{"-", "0.00015`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5045015810185356`*^9, 3.504501796224415*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0018505512893991845`"}], ",", "0.0016662626544725414`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5045015810185356`*^9, 3.5045017996307087`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0002018505512893992`"}], ",", 
   RowBox[{"-", "0.00014833373734552744`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5045015810185356`*^9, 3.5045018030526276`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044460230057554`*^9, 3.5044460666781893`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8576667939541273`*^-13", ",", 
   RowBox[{"-", "6.203515084191319`*^-16"}], ",", 
   "5.1678996383660714`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044460812096252`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"0", ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446117944471*^9, 3.5044461352728176`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.706602212727872`*^-16", ",", 
   RowBox[{"-", "2.2377084788736653`*^-13"}], ",", 
   "5.133732888772609`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.504446139804126*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446160148136*^9, 3.504446166616969*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.860817384471168`*^-13", ",", 
   RowBox[{"-", "2.2344295219755645`*^-13"}], ",", 
   "5.1547162346024545`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044461719607873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.5044462159769754`*^9, 3.5044462335553255`*^9}, {
  3.5044462804309254`*^9, 3.5044463740258737`*^9}}],

Cell[BoxData["0.008968509606979556`"], "Output",
 CellChangeTimes->{3.5044463284784155`*^9, 3.504446376166526*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.504446402885618*^9, 3.5044464108857203`*^9}}],

Cell[BoxData["0.000022955493555877015`"], "Output",
 CellChangeTimes->{3.5044464254327817`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Dot"}]], "Input",
 CellChangeTimes->{{3.5044462365241137`*^9, 3.5044462371334963`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\".\\\", \
StyleBox[\\\"b\\\", \\\"TI\\\"], \\\".\\\", StyleBox[\\\"c\\\", \\\"TI\\\"]}]\
\\) or \\!\\(\\*RowBox[{\\\"Dot\\\", \\\"[\\\", RowBox[{StyleBox[\\\"a\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"b\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\
\\\"c\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives products of vectors, matrices \
and tensors. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Dot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.5044462379772573`*^9},
 CellTags->"Info3504449837-4660416"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044462447742195`*^9, 3.5044462677901387`*^9}}],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.5044462682276444`*^9}]
}, Open  ]]
},
WindowSize->{615, 750},
WindowMargins->{{Automatic, 135}, {63, Automatic}},
ShowSelection->True,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3504449837-4660416"->{
  Cell[52975, 1486, 701, 14, 42, "Print",
   CellTags->"Info3504449837-4660416"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3504449837-4660416", 54402, 1529}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 13494, 313, 1666, "Input"],
Cell[14042, 335, 1702, 49, 112, "Input"],
Cell[15747, 386, 709, 20, 52, "Input"],
Cell[CellGroupData[{
Cell[16481, 410, 1983, 55, 157, "Input"],
Cell[18467, 467, 1549, 29, 238, "Output"]
}, Open  ]],
Cell[20031, 499, 1112, 34, 90, "Input"],
Cell[21146, 535, 344, 10, 47, "Input"],
Cell[CellGroupData[{
Cell[21515, 549, 401, 9, 33, "Input"],
Cell[21919, 560, 194, 2, 30, "Output"]
}, Open  ]],
Cell[22128, 565, 513, 15, 48, "Input"],
Cell[CellGroupData[{
Cell[22666, 584, 252, 7, 33, "Input"],
Cell[22921, 593, 117, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23075, 599, 1711, 50, 157, "Input"],
Cell[24789, 651, 1496, 28, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26322, 684, 1988, 53, 159, "Input"],
Cell[28313, 739, 1432, 27, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29782, 771, 1678, 49, 137, "Input"],
Cell[31463, 822, 1044, 21, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32544, 848, 1991, 56, 155, "Input"],
Cell[34538, 906, 336, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34911, 918, 198, 4, 31, "Input"],
Cell[35112, 924, 256, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35405, 935, 100, 1, 31, "Input"],
Cell[35508, 938, 110, 3, 47, "Output"]
}, Open  ]],
Cell[35633, 944, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[35752, 949, 93, 2, 31, InheritFromParent],
Cell[35848, 953, 96, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35981, 960, 2274, 62, 201, "Input"],
Cell[38258, 1024, 854, 16, 335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39149, 1045, 307, 9, 31, "Input"],
Cell[39459, 1056, 612, 12, 205, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40108, 1073, 95, 1, 31, "Input"],
Cell[40206, 1076, 1862, 55, 88, "Output"]
}, Open  ]],
Cell[42083, 1134, 3552, 94, 222, "Input"],
Cell[CellGroupData[{
Cell[45660, 1232, 3038, 98, 161, "Input"],
Cell[48701, 1332, 190, 5, 30, "Output"],
Cell[48894, 1339, 205, 5, 30, "Output"],
Cell[49102, 1346, 222, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49361, 1356, 323, 10, 33, "Input"],
Cell[49687, 1368, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49942, 1378, 321, 10, 33, "Input"],
Cell[50266, 1390, 215, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50518, 1400, 393, 13, 33, "Input"],
Cell[50914, 1415, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51169, 1425, 821, 24, 55, "Input"],
Cell[51993, 1451, 114, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52144, 1457, 577, 17, 33, "Input"],
Cell[52724, 1476, 95, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52856, 1482, 116, 2, 31, "Input"],
Cell[52975, 1486, 701, 14, 42, "Print",
 CellTags->"Info3504449837-4660416"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53713, 1505, 267, 7, 31, "Input"],
Cell[53983, 1514, 72, 1, 30, "Output"]
}, Open  ]]
}
]
*)
2.5", "+", 
        RowBox[{
         SuperscriptBox["10", "3"], 
         RowBox[{"(", 
          RowBox[{"zmin", "+", 
           RowBox[{"i", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
          ")"}]}]}], ",", " ", 
       RowBox[{"-", " ", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", " ", "0", ",", " ", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"zmin", "+", 
              RowBox[{"i", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
             ")"}]}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fxvzmag", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.50443366052562*^9, 3.504433661260004*^9}, {
  3.504433868981413*^9, 3.5044339228414774`*^9}, {3.5044339534199944`*^9, 
  3.5044339728264923`*^9}, {3.50443403123349*^9, 3.504434033952275*^9}, {
  3.5044358478547506`*^9, 3.50443584849538*^9}, {3.5044358917300315`*^9, 
  3.5044358922925353`*^9}, {3.50443941573451*^9, 3.5044394600785437`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxd0W1Ik1EUB/Bnaqmo5WzmtpzupaAtaS2NoA/d44eNTLKsVUQGvrCCoLKw
0klYbhYybGxL5kzBocZIBmI5LG2+MF+m28xEWIqQaVBW4tbKBIva0/nUgcvl
4Tnnd/5wBcXXTqoiKIrK/HvC9//VYgmXmzQxRmfuaUykgf5+S84WRi8rrK0k
KzNci2RrWcNiVq8d/38iWs1Pv531nPxTVolE4aYWql4Quj3zG5kukIy3i/rJ
Rbp+EG9SbGTKnSHSSM+vk9l8fWDu5jDxecK1Qd5VPxTYisbQo0DDu/A1hzmB
/QwoC73UFxEv5omE3LruY9pmH/HS81Egywtt6gz5cN9maOyUJI/IfejFQL2c
E693e9CLBeryLqfi9Th6cfDe2Vi/zzqGeeLBLdZ9rrwygt4WYIls5sF8F3qJ
sDBsmMooGML+RFAfLhwWGAfQZ0JMk1Sa/fEVzidBf6WDc4TqxX3bwJESpdtQ
9aDHAsVIBlOW5ECPBQH2ZG7Xr2foJYPkw1GGXdCF3naYnqp+M3e7E70U8Ne0
/c74bkePDWJl4GpLTgd6bGCsGbp5Szb0ONB/0CXv63uCHhd8Yv+AxtOG77cD
BmfKgycSWgmD9lJBpjLX9lVY0UsF4/kVWVRCC6E5Cw/WtFbypaaZXKK9NDiw
NBHtlD7GfOlQ7lOWhhItmI8P2cGV+VGRGffz4e5+9SluST2+Jx8866aq4nET
5hFAhWteYzltxPwCWN19iLuHYUBPCGZ9hH7SpEdPCDdm49oD5+oIzXmEcEap
M3Qc12EeESyr9rbfKq3F/CJITwsWKXoeoLcTHj0tua4W3Sd/AL8mVAc=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044336685413475`*^9, {3.504433912247592*^9, 3.5044339241539946`*^9}, {
   3.504433958529434*^9, 3.504433975467151*^9}, 3.5044340373741937`*^9, 
   3.5044358059794827`*^9, 3.504435849964139*^9, 3.50443590398011*^9, 
   3.5044362648417945`*^9, 3.5044380611477156`*^9, 3.504439179482998*^9, {
   3.504439440094041*^9, 3.5044394638441925`*^9}, 3.504442108610324*^9, 
   3.5044437779932423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{
    RowBox[{"-", "2."}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"7.5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxvzmag", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2.5", "+", 
        RowBox[{
         SuperscriptBox["10", "3"], 
         RowBox[{"(", 
          RowBox[{"zmin", "+", 
           RowBox[{"i", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
          ")"}]}]}], ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", 
         RowBox[{"0", ",", " ", "0", ",", " ", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fxvzmag", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044359811524787`*^9, 3.5044360001526003`*^9}, {
   3.5044392056862907`*^9, 3.504439207733179*^9}, 3.5044397537835484`*^9, {
   3.5044430110379744`*^9, 3.5044430147098727`*^9}, 3.5044438188169737`*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1kn1I00EYxzd1vsx0m27qtL1ruiWWGSKi3SNYrnLgNPSPFEqTqBC1oGBJ
BWohGi4RQ4Wy7EVqTdP+sIn48wUsMWWMNGPqlFTSsk2aUzFru1sPHMdx3Of5
fr/PSQpLs4s9aDRagnO5dlIWFFVc+XdsXEJx9RkLGu4y+qnTjAyUSClFfv2Q
PeYHqrMy2GKBjBJWr6l7hTbkfz/5doNZRsnx/W9kUabOfdZGUgm4HMije3CD
7hdFpTKn28tSdxDrVVfiTXskpXTS9Rl/UHLiSJFi4f97GhRFq8uUxyQUbq+n
Q9OKT3RnOp86inme8Jhff8Xf7Eu9xwK8wOuuIi3m1DwifG+4t6UvWe4PACfM
SfSBTvOagXsgDEg/Pxid7qjYKRDAp3FXMUHOsaoUWSLI7nUB90F9kvBtVqgI
vjhpzOkAOGO02lhtAsDy8lmgtah1b2ojoBw3ZMP2B4mhJYUPRB8HuGlPSjtW
Q2DT1d7OgcrQFENODxeI3iBgeVyoffosCCpwwMFQHn4ycmqYDUQ/FwLnb0gN
0kAg8+BBrbnAmBji7/bDg81ZU1bJWV/A8VeHwJ1b8TWtqwy3v1DQcA6zBvs8
AeOYYTA0eW6PPUp3+w2DzdhJRwqDBloM5MOWLU+umt9FxH84yOuq4r3oO4iH
BxABDN2JOFOxA5E8IiCdoWX3MeyopdlV++Ei79Lc5a8bqADnI4Dvft39e3NW
JMIChWCLM+6eF62jRZe8BedZZzEyTavouQvXLoK2dVXLtmkFkfzE4GhVRXUK
lhCOp1EMvw7GNk+9XkQkTzEc/8g9zdVYELaXJ4EjS5nXv/nMIpKvBKqSMnOH
a2aIPr4UDtU0zjSUTSGStxS6gscmEnpMCM/TLIVr4ocDw0qj+//IIPcBzbtS
PUH0P5JB4dX2FzlNY4jMIxKaX46/46lH0T/+zWJa
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5044359937775593`*^9, 3.504436004262002*^9}, 
   3.504439224780163*^9, 3.504439772627419*^9, 3.5044398053932533`*^9, 
   3.504442129688584*^9, 3.504442837208737*^9, 3.5044430316631064`*^9, {
   3.504443140726304*^9, 3.5044431679452286`*^9}, 3.504443797639272*^9, 
   3.5044438384317455`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"10", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"xmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xmin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvx", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044431874453535`*^9, 3.504443213164268*^9}, {
  3.5044432432738357`*^9, 3.5044433180555644`*^9}, {3.504443360852713*^9, 
  3.5044434125249186`*^9}, {3.5044434896816626`*^9, 3.5044434902910414`*^9}, {
  3.5044435224474974`*^9, 3.5044435256975183`*^9}, {3.504443632588827*^9, 
  3.504443638635741*^9}, {3.504444040913062*^9, 3.504444041194341*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-10., 0.17489518056036796`}, {-8., 1.028783910370256}, {-6., 
    4.063592085817313}, {-4., 5.711561321840935}, {-2., 
    5.9037982087229555`}, {0., 5.146990905458733}, {2., 
    5.9037982087229555`}, {4., 5.711561321840935}, {6., 4.063592085817313}, {
    8., 1.028783910370256}, {10., 0.17489518056036796`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.504443304852355*^9, 3.5044433319775286`*^9}, 
   3.5044433768684406`*^9, {3.5044434092905235`*^9, 3.5044434311969137`*^9}, 
   3.504443504541133*^9, 3.504443724822364*^9, 3.504443814409511*^9, 
   3.5044440444134207`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"10", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"ymin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{"0", ",", 
          RowBox[{"(", 
           RowBox[{"ymin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044435316819315`*^9, 3.5044435766509695`*^9}, {
  3.5044436414326344`*^9, 3.5044436691671867`*^9}, {3.504444031646489*^9, 
  3.5044440319433937`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-10., -0.0029517621895179622`}, {-8., 
    0.0006885969371206008}, {-6., 0.11254396071702578`}, {-4., 
    0.9956430068709509}, {-2., 3.7201040740721165`}, {0., 
    5.146990905458733}, {2., 3.7201040740721165`}, {4., 0.9956430068709509}, {
    6., 0.11254396071702578`}, {8., 0.0006885969371206008}, {
    10., -0.0029517621895179622`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044435958542175`*^9, {3.5044436605733814`*^9, 3.5044436859991827`*^9}, 
   3.504443860515946*^9, 3.504444035287486*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"xmin", "+", 
       RowBox[{"i", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"ymin", "+", 
       RowBox[{"j", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}], ",",
      "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox["10", "12"], "*", 
  RowBox[{"F", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.504443983547814*^9, 3.50444409626248*^9}, {
  3.504444591013158*^9, 3.5044446555616856`*^9}, {3.5044447152507133`*^9, 
  3.5044447223915215`*^9}, {3.504444989303854*^9, 3.5044450692741394`*^9}, {
  3.504445100087231*^9, 3.5044451413067727`*^9}, {3.504445179573085*^9, 
  3.504445199213961*^9}, {3.5044452396363535`*^9, 3.5044452410582466`*^9}, {
  3.504445274293047*^9, 3.504445280293124*^9}, {3.5044454298106627`*^9, 
  3.504445434857602*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.010417453958328446`"}], ",", "0.5166533014621376`", ",", 
   "0.11287531272545727`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5044452186204596`*^9, {3.5044452538396606`*^9, 3.5044452815118895`*^9}, 
   3.5044454416545644`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5044454531547117`*^9, 3.504445455295364*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.00016`"}], ",", 
   RowBox[{"-", 
    FractionBox["3", "500"]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5044454560297484`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "[", "2", "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.504445219729849*^9, 3.5044452441051607`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["3", "500"]}]], "Output",
 CellChangeTimes->{{3.5044452237611504`*^9, 3.5044452459020586`*^9}}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.504445158353975*^9, 3.5044451769480515`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", "0.00012`"}]], "Input",
 CellChangeTimes->{3.504446620091523*^9}],

Cell[BoxData[
 RowBox[{"-", "0.00012`"}]], "Output",
 CellChangeTimes->{3.5044466201227736`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["10", "12"], "*", 
          RowBox[{"F", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]]}]}], "]"}]}]}]}], " ", "}"}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "npts"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "0", ",", " ", "npts"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{"fxy", ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.504445298183978*^9, 3.5044454150292234`*^9}, {
  3.5044454709518147`*^9, 3.504445502561594*^9}, {3.5044455641717577`*^9, 
  3.5044455770156717`*^9}, {3.5044456388758388`*^9, 3.5044456452352953`*^9}, {
  3.504446581153525*^9, 3.5044465816847816`*^9}, {3.504500204329039*^9, 
  3.504500219844863*^9}, {3.504500256110952*^9, 3.5045003235649405`*^9}, {
  3.504500388425145*^9, 3.5045003976440134`*^9}}],

Cell[BoxData[
 Graphics3DBox[{{
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 100], 0}, {-0.0007840201482762852, 
       0.009460140610499773, -0.00293486655975446}}, {{-0.0002, -0.01, 
        0}, {-0.0007840201482762852, 
       0.009460140610499773, -0.00293486655975446}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 125], 0}, {-0.0032504237088211087`, 
       0.09322238404232153, 
       0.0008070010367038983}}, {{-0.0002, -0.008, 
        0}, {-0.0032504237088211087`, 0.09322238404232153, 
       0.0008070010367038983}}]]}, {
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 100], 0}, {-0.0006274455884074565, 
       0.009443609506769273, -0.0029409437298631245`}}, {{-0.00016, -0.01, 
        0}, {-0.0006274455884074565, 
       0.009443609506769273, -0.0029409437298631245`}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 125], 0}, {-0.002602395865310854, 
       0.09312710004817265, 
       0.0007644287754009542}}, {{-0.00016, -0.008, 
        0}, {-0.002602395865310854, 0.09312710004817265, 
       0.0007644287754009542}}]]}},
  AutomaticImageSize->True,
  BoxRatios->{1, 1, 1},
  ImageSize->{355.5230562026266, 354.62048545269545`},
  ViewPoint->{3.3720667681249785`, -0.16322718705863365`, 
   0.22917808951143395`},
  ViewVertical->{0.6288210266019727, 0.7770470612206366, 
   0.027963925897721474`}]], "Output",
 CellChangeTimes->{
  3.5044454986240435`*^9, 3.5044458908165636`*^9, 3.504446864891532*^9, 
   3.504500222923027*^9, {3.5045002930489244`*^9, 3.5045003263306007`*^9}, {
   3.504500391847064*^9, 3.5045004003159227`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["10", "12"], "*", 
          RowBox[{"F", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]]}]}], "]"}]}]}]}], " ", "}"}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "npts"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "0", ",", " ", "npts"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{"fxy", ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044460230057554`*^9, 3.5044460666781893`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8576667939541273`*^-13", ",", 
   RowBox[{"-", "6.203515084191319`*^-16"}], ",", 
   "5.1678996383660714`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044460812096252`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"0", ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446117944471*^9, 3.5044461352728176`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.706602212727872`*^-16", ",", 
   RowBox[{"-", "2.2377084788736653`*^-13"}], ",", 
   "5.133732888772609`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.504446139804126*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446160148136*^9, 3.504446166616969*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.860817384471168`*^-13", ",", 
   RowBox[{"-", "2.2344295219755645`*^-13"}], ",", 
   "5.1547162346024545`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044461719607873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.5044462159769754`*^9, 3.5044462335553255`*^9}, {
  3.5044462804309254`*^9, 3.5044463740258737`*^9}}],

Cell[BoxData["0.008968509606979556`"], "Output",
 CellChangeTimes->{3.5044463284784155`*^9, 3.504446376166526*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.504446402885618*^9, 3.5044464108857203`*^9}}],

Cell[BoxData["0.000022955493555877015`"], "Output",
 CellChangeTimes->{3.5044464254327817`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Dot"}]], "Input",
 CellChangeTimes->{{3.5044462365241137`*^9, 3.5044462371334963`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\".\\\", \
StyleBox[\\\"b\\\", \\\"TI\\\"], \\\".\\\", StyleBox[\\\"c\\\", \\\"TI\\\"]}]\
\\) or \\!\\(\\*RowBox[{\\\"Dot\\\", \\\"[\\\", RowBox[{StyleBox[\\\"a\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"b\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\
\\\"c\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives products of vectors, matrices \
and tensors. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Dot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.5044462379772573`*^9},
 CellTags->"Info3504449837-4660416"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044462447742195`*^9, 3.5044462677901387`*^9}}],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.5044462682276444`*^9}]
}, Open  ]]
},
WindowSize->{615, 750},
WindowMargins->{{143, Automatic}, {51, Automatic}},
ShowSelection->True,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3504449837-4660416"->{
  Cell[43455, 1211, 701, 14, 42, "Print",
   CellTags->"Info3504449837-4660416"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3504449837-4660416", 44882, 1254}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 18636, 467, 2184, "Input"],
Cell[CellGroupData[{
Cell[19206, 491, 1888, 53, 157, "Input"],
Cell[21097, 546, 1492, 28, 244, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22626, 579, 1711, 50, 157, "Input"],
Cell[24340, 631, 1496, 28, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25873, 664, 1824, 51, 137, "Input"],
Cell[27700, 717, 761, 15, 254, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28498, 737, 1628, 49, 137, "Input"],
Cell[30129, 788, 689, 15, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30855, 808, 1943, 56, 155, "Input"],
Cell[32801, 866, 288, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33126, 878, 145, 3, 31, "Input"],
Cell[33274, 883, 197, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33508, 894, 173, 4, 31, "Input"],
Cell[33684, 900, 138, 3, 47, "Output"]
}, Open  ]],
Cell[33837, 906, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[33956, 911, 93, 2, 31, InheritFromParent],
Cell[34052, 915, 96, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34185, 922, 2223, 61, 201, "Input"],
Cell[36411, 985, 1588, 34, 370, "Output"]
}, Open  ]],
Cell[38014, 1022, 1802, 55, 179, "Input"],
Cell[CellGroupData[{
Cell[39841, 1081, 323, 10, 33, "Input"],
Cell[40167, 1093, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40422, 1103, 321, 10, 33, "Input"],
Cell[40746, 1115, 215, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40998, 1125, 393, 13, 33, "Input"],
Cell[41394, 1140, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41649, 1150, 821, 24, 55, "Input"],
Cell[42473, 1176, 114, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42624, 1182, 577, 17, 33, "Input"],
Cell[43204, 1201, 95, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43336, 1207, 116, 2, 31, "Input"],
Cell[43455, 1211, 701, 14, 42, "Print",
 CellTags->"Info3504449837-4660416"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44193, 1230, 267, 7, 31, "Input"],
Cell[44463, 1239, 72, 1, 30, "Output"]
}, Open  ]]
}
]
*)
bwJESpdtQ
9aDHAsVIBlOW5ECPBQH2ZG7Xr2foJYPkw1GGXdCF3naYnqp+M3e7E70U8Ne0
/c74bkePDWJl4GpLTgd6bGCsGbp5Szb0ONB/0CXv63uCHhd8Yv+AxtOG77cD
BmfKgycSWgmD9lJBpjLX9lVY0UsF4/kVWVRCC6E5Cw/WtFbypaaZXKK9NDiw
NBHtlD7GfOlQ7lOWhhItmI8P2cGV+VGRGffz4e5+9SluST2+Jx8866aq4nET
5hFAhWteYzltxPwCWN19iLuHYUBPCGZ9hH7SpEdPCDdm49oD5+oIzXmEcEap
M3Qc12EeESyr9rbfKq3F/CJITwsWKXoeoLcTHj0tua4W3Sd/AL8mVAc=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044336685413475`*^9, {3.504433912247592*^9, 3.5044339241539946`*^9}, {
   3.504433958529434*^9, 3.504433975467151*^9}, 3.5044340373741937`*^9, 
   3.5044358059794827`*^9, 3.504435849964139*^9, 3.50443590398011*^9, 
   3.5044362648417945`*^9, 3.5044380611477156`*^9, 3.504439179482998*^9, {
   3.504439440094041*^9, 3.5044394638441925`*^9}, 3.504442108610324*^9, 
   3.5044437779932423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zmin", "=", 
   RowBox[{
    RowBox[{"-", "2."}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zmax", "=", 
   RowBox[{"7.5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxvzmag", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2.5", "+", 
        RowBox[{
         SuperscriptBox["10", "3"], 
         RowBox[{"(", 
          RowBox[{"zmin", "+", 
           RowBox[{"i", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
          ")"}]}]}], ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", 
         RowBox[{"0", ",", " ", "0", ",", " ", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"zmin", "+", 
             RowBox[{"i", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "npts"}]}]}], 
            ")"}]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fxvzmag", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044359811524787`*^9, 3.5044360001526003`*^9}, {
   3.5044392056862907`*^9, 3.504439207733179*^9}, 3.5044397537835484`*^9, {
   3.5044430110379744`*^9, 3.5044430147098727`*^9}, 3.5044438188169737`*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1kn1I00EYxzd1vsx0m27qtL1ruiWWGSKi3SNYrnLgNPSPFEqTqBC1oGBJ
BWohGi4RQ4Wy7EVqTdP+sIn48wUsMWWMNGPqlFTSsk2aUzFru1sPHMdx3Of5
fr/PSQpLs4s9aDRagnO5dlIWFFVc+XdsXEJx9RkLGu4y+qnTjAyUSClFfv2Q
PeYHqrMy2GKBjBJWr6l7hTbkfz/5doNZRsnx/W9kUabOfdZGUgm4HMije3CD
7hdFpTKn28tSdxDrVVfiTXskpXTS9Rl/UHLiSJFi4f97GhRFq8uUxyQUbq+n
Q9OKT3RnOp86inme8Jhff8Xf7Eu9xwK8wOuuIi3m1DwifG+4t6UvWe4PACfM
SfSBTvOagXsgDEg/Pxid7qjYKRDAp3FXMUHOsaoUWSLI7nUB90F9kvBtVqgI
vjhpzOkAOGO02lhtAsDy8lmgtah1b2ojoBw3ZMP2B4mhJYUPRB8HuGlPSjtW
Q2DT1d7OgcrQFENODxeI3iBgeVyoffosCCpwwMFQHn4ycmqYDUQ/FwLnb0gN
0kAg8+BBrbnAmBji7/bDg81ZU1bJWV/A8VeHwJ1b8TWtqwy3v1DQcA6zBvs8
AeOYYTA0eW6PPUp3+w2DzdhJRwqDBloM5MOWLU+umt9FxH84yOuq4r3oO4iH
BxABDN2JOFOxA5E8IiCdoWX3MeyopdlV++Ei79Lc5a8bqADnI4Dvft39e3NW
JMIChWCLM+6eF62jRZe8BedZZzEyTavouQvXLoK2dVXLtmkFkfzE4GhVRXUK
lhCOp1EMvw7GNk+9XkQkTzEc/8g9zdVYELaXJ4EjS5nXv/nMIpKvBKqSMnOH
a2aIPr4UDtU0zjSUTSGStxS6gscmEnpMCM/TLIVr4ocDw0qj+//IIPcBzbtS
PUH0P5JB4dX2FzlNY4jMIxKaX46/46lH0T/+zWJa
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5044359937775593`*^9, 3.504436004262002*^9}, 
   3.504439224780163*^9, 3.504439772627419*^9, 3.5044398053932533`*^9, 
   3.504442129688584*^9, 3.504442837208737*^9, 3.5044430316631064`*^9, {
   3.504443140726304*^9, 3.5044431679452286`*^9}, 3.504443797639272*^9, 
   3.5044438384317455`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"10", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"xmin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xmin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvx", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044431874453535`*^9, 3.504443213164268*^9}, {
  3.5044432432738357`*^9, 3.5044433180555644`*^9}, {3.504443360852713*^9, 
  3.5044434125249186`*^9}, {3.5044434896816626`*^9, 3.5044434902910414`*^9}, {
  3.5044435224474974`*^9, 3.5044435256975183`*^9}, {3.504443632588827*^9, 
  3.504443638635741*^9}, {3.504444040913062*^9, 3.504444041194341*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-10., 0.17489518056036796`}, {-8., 1.028783910370256}, {-6., 
    4.063592085817313}, {-4., 5.711561321840935}, {-2., 
    5.9037982087229555`}, {0., 5.146990905458733}, {2., 
    5.9037982087229555`}, {4., 5.711561321840935}, {6., 4.063592085817313}, {
    8., 1.028783910370256}, {10., 0.17489518056036796`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.504443304852355*^9, 3.5044433319775286`*^9}, 
   3.5044433768684406`*^9, {3.5044434092905235`*^9, 3.5044434311969137`*^9}, 
   3.504443504541133*^9, 3.504443724822364*^9, 3.504443814409511*^9, 
   3.5044440444134207`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ymax", "=", 
   RowBox[{"10", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fzvy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["10", "3"], 
        RowBox[{"(", 
         RowBox[{"ymin", "+", 
          RowBox[{"i", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}]}],
        ",", " ", 
       RowBox[{
        SuperscriptBox["10", "12"], "*", 
        RowBox[{"Fz", "[", " ", 
         RowBox[{"0", ",", 
          RowBox[{"(", 
           RowBox[{"ymin", "+", 
            RowBox[{"i", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}],
           ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "npts"}], "}"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"fzvy", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5044435316819315`*^9, 3.5044435766509695`*^9}, {
  3.5044436414326344`*^9, 3.5044436691671867`*^9}, {3.504444031646489*^9, 
  3.5044440319433937`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   LineBox[{{-10., -0.0029517621895179622`}, {-8., 
    0.0006885969371206008}, {-6., 0.11254396071702578`}, {-4., 
    0.9956430068709509}, {-2., 3.7201040740721165`}, {0., 
    5.146990905458733}, {2., 3.7201040740721165`}, {4., 0.9956430068709509}, {
    6., 0.11254396071702578`}, {8., 0.0006885969371206008}, {
    10., -0.0029517621895179622`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.5044435958542175`*^9, {3.5044436605733814`*^9, 3.5044436859991827`*^9}, 
   3.504443860515946*^9, 3.504444035287486*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"xmin", "+", 
       RowBox[{"i", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "npts"}]}]}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"ymin", "+", 
       RowBox[{"j", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "npts"}]}]}], ")"}], ",",
      "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SuperscriptBox["10", "12"], "*", 
  RowBox[{"F", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", "2", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.504443983547814*^9, 3.50444409626248*^9}, {
  3.504444591013158*^9, 3.5044446555616856`*^9}, {3.5044447152507133`*^9, 
  3.5044447223915215`*^9}, {3.504444989303854*^9, 3.5044450692741394`*^9}, {
  3.504445100087231*^9, 3.5044451413067727`*^9}, {3.504445179573085*^9, 
  3.504445199213961*^9}, {3.5044452396363535`*^9, 3.5044452410582466`*^9}, {
  3.504445274293047*^9, 3.504445280293124*^9}, {3.5044454298106627`*^9, 
  3.504445434857602*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.010417453958328446`"}], ",", "0.5166533014621376`", ",", 
   "0.11287531272545727`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5044452186204596`*^9, {3.5044452538396606`*^9, 3.5044452815118895`*^9}, 
   3.5044454416545644`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5044454531547117`*^9, 3.504445455295364*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.00016`"}], ",", 
   RowBox[{"-", 
    FractionBox["3", "500"]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5044454560297484`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "[", "2", "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.504445219729849*^9, 3.5044452441051607`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["3", "500"]}]], "Output",
 CellChangeTimes->{{3.5044452237611504`*^9, 3.5044452459020586`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.504445158353975*^9, 3.5044451769480515`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.00012`"}]], "Output",
 CellChangeTimes->{{3.504445142306792*^9, 3.504445172229241*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"xmin", "=", 
   RowBox[{"-", "xmax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", " ", 
  RowBox[{"ymin", "=", 
   RowBox[{"-", "ymax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npts", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{
         RowBox[{"r", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["10", "7"], "*", 
          RowBox[{"F", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"r", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]]}]}], "]"}]}]}]}], " ", "}"}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "npts"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "0", ",", " ", "npts"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{"fxy", ",", 
   RowBox[{"BoxRatios", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.504445298183978*^9, 3.5044454150292234`*^9}, {
  3.5044454709518147`*^9, 3.504445502561594*^9}, {3.5044455641717577`*^9, 
  3.5044455770156717`*^9}, {3.5044456388758388`*^9, 3.5044456452352953`*^9}, {
  3.504446581153525*^9, 3.5044465816847816`*^9}}],

Cell[BoxData[
 Graphics3DBox[{{
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 100], 
        0}, {-0.00020584020148276287`, -0.009805398593895003, \
-0.0000293486655975446}}, {{-0.0002, -0.01, 
        0}, {-0.00020584020148276287`, -0.009805398593895003, \
-0.0000293486655975446}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 125], 
        0}, {-0.0002305042370882111, -0.006987776159576785, 
       8.070010367038983*^-6}}, {{-0.0002, -0.008, 
        0}, {-0.0002305042370882111, -0.006987776159576785, 
       8.070010367038983*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-3, 500], 
        0}, {-0.0003732939703430103, -0.0008241120185168054, 
       0.001134626414511258}}, {{-0.0002, -0.006, 
        0}, {-0.0003732939703430103, -0.0008241120185168054, 
       0.001134626414511258}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 250], 0}, {-0.0009657400249999768, 
       0.012689836111142053`, 
       0.01001531226055051}}, {{-0.0002, -0.004, 0}, {-0.0009657400249999768, 
       0.012689836111142053`, 0.01001531226055051}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[-1, 500], 0}, {-0.0020596064626132653`, 
       0.01799930028122542, 
       0.037428930694457616`}}, {{-0.0002, -0.002, 
        0}, {-0.0020596064626132653`, 0.01799930028122542, 
       0.037428930694457616`}}]], 
    Arrow3DBox[{{-0.0002, 0, 
       0}, {-0.002048522654995085, -6.2035150841913186`*^-6, 
      0.05167899638366071}}], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[1, 500], 
        0}, {-0.0020596064626132653`, -0.01800553941300083, 
       0.037428930694457616`}}, {{-0.0002, 0.002, 
        0}, {-0.0020596064626132653`, -0.01800553941300083, 
       0.037428930694457616`}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[1, 250], 
        0}, {-0.0009657400249999768, -0.012683261127725092`, 
       0.01001531226055051}}, {{-0.0002, 0.004, 
        0}, {-0.0009657400249999768, -0.012683261127725092`, 
       0.01001531226055051}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[3, 500], 0}, {-0.0003732939703430103, 
       0.000827983856851333, 
       0.001134626414511258}}, {{-0.0002, 0.006, 0}, {-0.0003732939703430103, 
       0.000827983856851333, 0.001134626414511258}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[1, 125], 0}, {-0.0002305042370882111, 
       0.006988628506158519, 
       8.070010367038983*^-6}}, {{-0.0002, 0.008, 0}, {-0.0002305042370882111,
        0.006988628506158519, 8.070010367038983*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.0002, Rational[1, 100], 0}, {-0.00020584020148276287`, 
       0.00980555369675631, -0.0000293486655975446}}, {{-0.0002, 0.01, 
        0}, {-0.00020584020148276287`, 
       0.00980555369675631, -0.0000293486655975446}}]]}, {
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 100], 
        0}, {-0.00016467445588407457`, -0.009805563904932308, \
-0.000029409437298631245`}}, {{-0.00016, -0.01, 
        0}, {-0.00016467445588407457`, -0.009805563904932308, \
-0.000029409437298631245`}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 125], 
        0}, {-0.00018442395865310855`, -0.006988728999518273, 
       7.644287754009543*^-6}}, {{-0.00016, -0.008, 
        0}, {-0.00018442395865310855`, -0.006988728999518273, 
       7.644287754009543*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-3, 500], 
        0}, {-0.0002988274551990631, -0.0008293691263863163, 
       0.0011313255289937924`}}, {{-0.00016, -0.006, 
        0}, {-0.0002988274551990631, -0.0008293691263863163, 
       0.0011313255289937924`}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 250], 0}, {-0.000774078067982494, 
       0.012672076313713684`, 
       0.009994186759982626}}, {{-0.00016, -0.004, 0}, {-0.000774078067982494,
        0.012672076313713684`, 0.009994186759982626}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[-1, 500], 0}, {-0.0016534798564124403`, 
       0.017989564475501207`, 
       0.03734737559224618}}, {{-0.00016, -0.002, 
        0}, {-0.0016534798564124403`, 0.017989564475501207`, 
       0.03734737559224618}}]], 
    Arrow3DBox[{{-0.00016, 0, 
       0}, {-0.0016453703822023158`, -5.888486936902072*^-6, 
      0.05160425660105584}}], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[1, 500], 
        0}, {-0.0016534798564124403`, -0.01799576838241261, 
       0.03734737559224618}}, {{-0.00016, 0.002, 
        0}, {-0.0016534798564124403`, -0.01799576838241261, 
       0.03734737559224618}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[1, 250], 
        0}, {-0.000774078067982494, -0.012665511158253262`, 
       0.009994186759982626}}, {{-0.00016, 0.004, 
        0}, {-0.000774078067982494, -0.012665511158253262`, 
       0.009994186759982626}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[3, 500], 0}, {-0.0002988274551990631, 
       0.0008332369937350693, 
       0.0011313255289937924`}}, {{-0.00016, 0.006, 
        0}, {-0.0002988274551990631, 0.0008332369937350693, 
       0.0011313255289937924`}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[1, 125], 0}, {-0.00018442395865310855`, 
       0.0069895804914826155`, 
       7.644287754009543*^-6}}, {{-0.00016, 0.008, 
        0}, {-0.00018442395865310855`, 0.0069895804914826155`, 
       7.644287754009543*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00016, Rational[1, 100], 0}, {-0.00016467445588407457`, 
       0.009805718868780207, -0.000029409437298631245`}}, {{-0.00016, 0.01, 
        0}, {-0.00016467445588407457`, 
       0.009805718868780207, -0.000029409437298631245`}}]]}, {
    Arrow3DBox[
     NCache[{{-0.00012, Rational[-1, 100], 
        0}, {-0.00012350522209471972`, -0.009805692629903034, \
-0.000029456745033695782`}}, {{-0.00012, -0.01, 
        0}, {-0.00012350522209471972`, -0.009805692629903034, \
-0.000029456745033695782`}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[-1, 125], 
        0}, {-0.00013831970371400558`, -0.006989471237651423, 
       7.312754161778502*^-6}}, {{-0.00012, -0.008, 
        0}, {-0.00013831970371400558`, -0.006989471237651423, 
       7.312754161778502*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[-3, 500], 
        0}, {-0.00022417453958328446`, -0.0008334669853786248, 
       0.0011287531272545727`}}, {{-0.00012, -0.006, 
        0}, {-0.00022417453958328446`, -0.0008334669853786248, 
       0.0011287531272545727`}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[-1, 250], 0}, {-0.0005811660363902706, 
       0.012657507859120065`, 
       0.009977698692871519}}, {{-0.00012, -0.004, 
        0}, {-0.0005811660363902706, 0.012657507859120065`, 
       0.009977698692871519}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[-1, 500], 0}, {-0.0012428943082452867`, 
       0.01798190374379939, 
       0.0372835704571755}}, {{-0.00012, -0.002, 0}, {-0.0012428943082452867`,
        0.01798190374379939, 0.0372835704571755}}]], 
    Arrow3DBox[{{-0.00012, 0, 
       0}, {-0.0012372618788055701`, -5.9536401108011975`*^-6, 
      0.05154572856373495}}], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[1, 500], 
        0}, {-0.0012428943082452867`, -0.017988107115831542`, 
       0.0372835704571755}}, {{-0.00012, 0.002, 
        0}, {-0.0012428943082452867`, -0.017988107115831542`, 
       0.0372835704571755}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[1, 250], 
        0}, {-0.0005811660363902706, -0.012651651830531695`, 
       0.009977698692871519}}, {{-0.00012, 0.004, 
        0}, {-0.0005811660363902706, -0.012651651830531695`, 
       0.009977698692871519}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[3, 500], 0}, {-0.00022417453958328446`, 
       0.0008373317552640477, 
       0.0011287531272545727`}}, {{-0.00012, 0.006, 
        0}, {-0.00022417453958328446`, 0.0008373317552640477, 
       0.0011287531272545727`}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[1, 125], 0}, {-0.00013831970371400558`, 
       0.00699032206372595, 
       7.312754161778502*^-6}}, {{-0.00012, 0.008, 
        0}, {-0.00013831970371400558`, 0.00699032206372595, 
       7.312754161778502*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00012, Rational[1, 100], 0}, {-0.00012350522209471972`, 
       0.00980584748548523, -0.000029456745033695782`}}, {{-0.00012, 0.01, 
        0}, {-0.00012350522209471972`, 
       0.00980584748548523, -0.000029456745033695782`}}]]}, {
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[-1, 100], 
        0}, {-0.00008233337020020438, -0.009805784656932902, \
-0.000029490558189450046`}}, {{-0.00007999999999999999, -0.01, 
        0}, {-0.00008233337020020438, -0.009805784656932902, \
-0.000029490558189450046`}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[-1, 125], 
        0}, {-0.0000921959491805384, -0.006990000482391312, 
       7.0772603950940905`*^-6}}, {{-0.00007999999999999999, -0.008, 
        0}, {-0.0000921959491805384, -0.006990000482391312, 
       7.0772603950940905`*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[-3, 500], 
        0}, {-0.0001493837093619603, -0.0008364073338039549, 
       0.0011269075617753477`}}, {{-0.00007999999999999999, -0.006, 
        0}, {-0.0001493837093619603, -0.0008364073338039549, 
       0.0011269075617753477`}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[-1, 250], 
        0}, {-0.00038731579007643077`, 0.012648288648078872`, 
       0.009965888049972517}}, {{-0.00007999999999999999, -0.004, 
        0}, {-0.00038731579007643077`, 0.012648288648078872`, 
       0.009965888049972517}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[-1, 500], 
        0}, {-0.0008289092438398064, 0.017976411061203137`, 
       0.037237788900365165`}}, {{-0.00007999999999999999, -0.002, 
        0}, {-0.0008289092438398064, 0.017976411061203137`, 
       0.037237788900365165`}}]], 
    Arrow3DBox[{{-0.00007999999999999999, 0, 
       0}, {-0.0008253694327836746, -5.665311528829008*^-6, 
      0.051503683431621726`}}], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[1, 500], 
        0}, {-0.0008289092438398064, -0.017982603186626804`, 
       0.037237788900365165`}}, {{-0.00007999999999999999, 0.002, 
        0}, {-0.0008289092438398064, -0.017982603186626804`, 
       0.037237788900365165`}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[1, 250], 
        0}, {-0.00038731579007643077`, -0.012641733761145909`, 
       0.009965888049972517}}, {{-0.00007999999999999999, 0.004, 
        0}, {-0.00038731579007643077`, -0.012641733761145909`, 
       0.009965888049972517}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[3, 500], 
        0}, {-0.0001493837093619603, 0.0008402698701598871, 
       0.0011269075617753477`}}, {{-0.00007999999999999999, 0.006, 
        0}, {-0.0001493837093619603, 0.0008402698701598871, 
       0.0011269075617753477`}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[1, 125], 
        0}, {-0.0000921959491805384, 0.0069908523649963705`, 
       7.0772603950940905`*^-6}}, {{-0.00007999999999999999, 0.008, 
        0}, {-0.0000921959491805384, 0.0069908523649963705`, 
       7.0772603950940905`*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.00007999999999999999, Rational[1, 100], 
        0}, {-0.00008233337020020438, 
       0.009805939435104362, -0.000029490558189450046`}}, \
{{-0.00007999999999999999, 0.01, 0}, {-0.00008233337020020438, 
       0.009805939435104362, -0.000029490558189450046`}}]]}, {
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[-1, 100], 
        0}, {-0.00004115977515697345, -0.009805839904949995, \
-0.000029510854868039747`}}, {{-0.000039999999999999996`, -0.01, 
        0}, {-0.00004115977515697345, -0.009805839904949995, \
-0.000029510854868039747`}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[-1, 125], 
        0}, {-0.00004606332847912009, -0.006990320715872291, 
       6.933421643091234*^-6}}, {{-0.000039999999999999996`, -0.008, 
        0}, {-0.00004606332847912009, -0.006990320715872291, 
       6.933421643091234*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[-3, 500], 
        0}, {-0.00007449560263658383, -0.0008381592796917652, 
       0.0011258081703353884`}}, {{-0.000039999999999999996`, -0.006, 
        0}, {-0.00007449560263658383, -0.0008381592796917652, 
       0.0011258081703353884`}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[-1, 250], 
        0}, {-0.00019284865623470334`, 0.012642319987460845`, 
       0.009958797700480013}}, {{-0.000039999999999999996`, -0.004, 
        0}, {-0.00019284865623470334`, 0.012642319987460845`, 
       0.009958797700480013}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[-1, 500], 
        0}, {-0.0004126587546481249, 0.017973103067423744`, 
       0.03721017091827791}}, {{-0.000039999999999999996`, -0.002, 
        0}, {-0.0004126587546481249, 0.017973103067423744`, 
       0.03721017091827791}}]], 
    Arrow3DBox[{{-0.000039999999999999996`, 0, 
       0}, {-0.00041096106879556224`, -5.637149588943071*^-6, 
      0.051478364264262666`}}], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[1, 500], 
        0}, {-0.0004126587546481249, -0.017979288432609222`, 
       0.03721017091827791}}, {{-0.000039999999999999996`, 0.002, 
        0}, {-0.0004126587546481249, -0.017979288432609222`, 
       0.03721017091827791}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[1, 250], 
        0}, {-0.00019284865623470334`, -0.012635768010746201`, 
       0.009958797700480013}}, {{-0.000039999999999999996`, 0.004, 
        0}, {-0.00019284865623470334`, -0.012635768010746201`, 
       0.009958797700480013}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[3, 500], 
        0}, {-0.00007449560263658383, 0.0008420205002908155, 
       0.0011258081703353884`}}, {{-0.000039999999999999996`, 0.006, 
        0}, {-0.00007449560263658383, 0.0008420205002908155, 
       0.0011258081703353884`}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[1, 125], 
        0}, {-0.00004606332847912009, 0.006991170779665347, 
       6.933421643091234*^-6}}, {{-0.000039999999999999996`, 0.008, 
        0}, {-0.00004606332847912009, 0.006991170779665347, 
       6.933421643091234*^-6}}]], 
    Arrow3DBox[
     NCache[{{-0.000039999999999999996`, Rational[1, 100], 
        0}, {-0.00004115977515697345, 
       0.009805994636641247, -0.000029510854868039747`}}, \
{{-0.000039999999999999996`, 0.01, 0}, {-0.00004115977515697345, 
       0.009805994636641247, -0.000029510854868039747`}}]]}, {
    Arrow3DBox[
     NCache[{{0., Rational[-1, 100], 0}, {
       1.4682521650257189`*^-8, -0.009805858326354265, \
-0.000029517621895179622`}}, {{0., -0.01, 0}, {
       1.4682521650257189`*^-8, -0.009805858326354265, \
-0.000029517621895179622`}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[-1, 125], 0}, {
       7.676328234292664*^-8, -0.0069904269892738305`, 
       6.885969371206008*^-6}}, {{0., -0.008, 0}, {
       7.676328234292664*^-8, -0.0069904269892738305`, 
       6.885969371206008*^-6}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[-3, 500], 0}, {
       4.367476327075626*^-7, -0.0008387466103163205, 
       0.0011254396071702579`}}, {{0., -0.006, 0}, {
       4.367476327075626*^-7, -0.0008387466103163205, 
       0.0011254396071702579`}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[-1, 250], 0}, {1.935433635702359*^-6, 
       0.012640329033195098`, 0.009956430068709509}}, {{0., -0.004, 0}, {
       1.935433635702359*^-6, 0.012640329033195098`, 0.009956430068709509}}]],
     Arrow3DBox[
     NCache[{{0., Rational[-1, 500], 0}, {4.719509846737633*^-6, 
       0.017971996710577663`, 0.03720104074072116}}, {{0., -0.002, 0}, {
       4.719509846737633*^-6, 0.017971996710577663`, 0.03720104074072116}}]], 
    Arrow3DBox[{{0., 0, 0}, {4.698325105457059*^-6, -5.747776476174262*^-6, 
      0.05146990905458732}}], 
    Arrow3DBox[
     NCache[{{0., Rational[1, 500], 0}, {
       4.719509846737633*^-6, -0.017978179817151815`, 
       0.03720104074072116}}, {{0., 0.002, 0}, {
       4.719509846737633*^-6, -0.017978179817151815`, 0.03720104074072116}}]],
     Arrow3DBox[
     NCache[{{0., Rational[1, 250], 0}, {
       1.935433635702359*^-6, -0.01263377802341882, 0.009956430068709509}}, {{
       0., 0.004, 0}, {1.935433635702359*^-6, -0.01263377802341882, 
       0.009956430068709509}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[3, 500], 0}, {4.367476327075626*^-7, 
       0.0008426073865273427, 0.0011254396071702579`}}, {{0., 0.006, 0}, {
       4.367476327075626*^-7, 0.0008426073865273427, 
       0.0011254396071702579`}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[1, 125], 0}, {7.676328234292664*^-8, 
       0.00699127695769952, 6.885969371206008*^-6}}, {{0., 0.008, 0}, {
       7.676328234292664*^-8, 0.00699127695769952, 6.885969371206008*^-6}}]], 
    Arrow3DBox[
     NCache[{{0., Rational[1, 100], 0}, {1.4682521650257189`*^-8, 
       0.009806013042549392, -0.000029517621895179622`}}, {{0., 0.01, 0}, {
       1.4682521650257189`*^-8, 
       0.009806013042549392, -0.000029517621895179622`}}]]}, {
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[-1, 100], 0}, {
       0.00004118912923279629, -0.009805839904949995, \
-0.000029510854868039747`}}, {{0.000040000000000000024`, -0.01, 0}, {
       0.00004118912923279629, -0.009805839904949995, \
-0.000029510854868039747`}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[-1, 125], 0}, {
       0.00004621677978154523, -0.006990320715874509, 
       6.9334216408725635`*^-6}}, {{0.000040000000000000024`, -0.008, 0}, {
       0.00004621677978154523, -0.006990320715874509, 
       6.9334216408725635`*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[-3, 500], 0}, {
       0.0000753685110101931, -0.0008381592796917652, 
       0.0011258081703353884`}}, {{0.000040000000000000024`, -0.006, 0}, {
       0.0000753685110101931, -0.0008381592796917652, 
       0.0011258081703353884`}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[-1, 250], 0}, {
       0.0001967155793001896, 0.01264231998744507, 0.009958797700480013}}, {{
       0.000040000000000000024`, -0.004, 0}, {0.0001967155793001896, 
       0.01264231998744507, 0.009958797700480013}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[-1, 500], 0}, {
       0.0004220137204942855, 0.017973103067431634`, 0.03721017091830158}}, {{
       0.000040000000000000024`, -0.002, 0}, {0.0004220137204942855, 
       0.017973103067431634`, 0.03721017091830158}}]], 
    Arrow3DBox[{{0.000040000000000000024`, 0, 0}, {
      0.00042034184521601997`, -5.637149620497507*^-6, 
      0.051478364264231115`}}], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[1, 500], 0}, {
       0.0004220137204942855, -0.017979288432577664`, 0.0372101709182858}}, {{
       0.000040000000000000024`, 0.002, 0}, {
       0.0004220137204942855, -0.017979288432577664`, 0.0372101709182858}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[1, 250], 0}, {
       0.0001967155793001896, -0.012635768010746201`, 
       0.009958797700480013}}, {{0.000040000000000000024`, 0.004, 0}, {
       0.0001967155793001896, -0.012635768010746201`, 
       0.009958797700480013}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[3, 500], 0}, {
       0.0000753685110101931, 0.0008420205002908155, 
       0.0011258081703353884`}}, {{0.000040000000000000024`, 0.006, 0}, {
       0.0000753685110101931, 0.0008420205002908155, 
       0.0011258081703353884`}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[1, 125], 0}, {
       0.00004621677978154523, 0.006991170779661649, 
       6.9334216408725635`*^-6}}, {{0.000040000000000000024`, 0.008, 0}, {
       0.00004621677978154523, 0.006991170779661649, 
       6.9334216408725635`*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.000040000000000000024`, Rational[1, 100], 0}, {
       0.00004118912923279629, 
       0.009805994636641247, -0.000029510854868039747`}}, {{
       0.000040000000000000024`, 0.01, 0}, {0.00004118912923279629, 
       0.009805994636641247, -0.000029510854868039747`}}]]}, {
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[-1, 100], 0}, {
       0.00008236269139368542, -0.009805784656932902, \
-0.000029490558189450046`}}, {{0.00008000000000000002, -0.01, 0}, {
       0.00008236269139368542, -0.009805784656932902, \
-0.000029490558189450046`}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[-1, 125], 0}, {
       0.00009235070432163542, -0.006990000482391312, 
       7.0772603950940905`*^-6}}, {{0.00008000000000000002, -0.008, 0}, {
       0.00009235070432163542, -0.006990000482391312, 
       7.0772603950940905`*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[-3, 500], 0}, {
       0.0001502548761505858, -0.0008364073338049411, 
       0.0011269075617753477`}}, {{0.00008000000000000002, -0.006, 0}, {
       0.0001502548761505858, -0.0008364073338049411, 
       0.0011269075617753477`}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[-1, 250], 0}, {
       0.0003911709032157455, 0.012648288648078872`, 
       0.009965888049960684}}, {{0.00008000000000000002, -0.004, 0}, {
       0.0003911709032157455, 0.012648288648078872`, 0.009965888049960684}}]],
     Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[-1, 500], 0}, {
       0.0008382912221924051, 0.017976411061171586`, 
       0.037237788900333614`}}, {{0.00008000000000000002, -0.002, 0}, {
       0.0008382912221924051, 0.017976411061171586`, 
       0.037237788900333614`}}]], 
    Arrow3DBox[{{0.00008000000000000002, 0, 0}, {
      0.0008347026467291182, -5.665311528829008*^-6, 0.051503683431621726`}}],
     Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[1, 500], 0}, {
       0.0008382912221924051, -0.017982603186658362`, 
       0.037237788900333614`}}, {{0.00008000000000000002, 0.002, 0}, {
       0.0008382912221924051, -0.017982603186658362`, 
       0.037237788900333614`}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[1, 250], 0}, {
       0.0003911709032157455, -0.01264173376115774, 0.009965888049960684}}, {{
       0.00008000000000000002, 0.004, 0}, {
       0.0003911709032157455, -0.01264173376115774, 0.009965888049960684}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[3, 500], 0}, {
       0.0001502548761505858, 0.0008402698701598871, 
       0.0011269075617753477`}}, {{0.00008000000000000002, 0.006, 0}, {
       0.0001502548761505858, 0.0008402698701598871, 
       0.0011269075617753477`}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[1, 125], 0}, {
       0.00009235070432163542, 0.0069908523649963705`, 
       7.0772603950940905`*^-6}}, {{0.00008000000000000002, 0.008, 0}, {
       0.00009235070432163542, 0.0069908523649963705`, 
       7.0772603950940905`*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00008000000000000002, Rational[1, 100], 0}, {
       0.00008236269139368542, 
       0.00980593943510162, -0.000029490558189450046`}}, {{
       0.00008000000000000002, 0.01, 0}, {0.00008236269139368542, 
       0.00980593943510162, -0.000029490558189450046`}}]]}, {
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[-1, 100], 0}, {
       0.0001235344885172183, -0.009805692629903034, \
-0.000029456745033695782`}}, {{0.00012000000000000002`, -0.01, 0}, {
       0.0001235344885172183, -0.009805692629903034, \
-0.000029456745033695782`}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[-1, 125], 0}, {
       0.00013847281746284936`, -0.006989471237651671, 
       7.312754161531982*^-6}}, {{0.00012000000000000002`, -0.008, 0}, {
       0.00013847281746284936`, -0.006989471237651671, 
       7.312754161531982*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[-3, 500], 0}, {
       0.0002250427592230668, -0.0008334669853786248, 
       0.0011287531272545727`}}, {{0.00012000000000000002`, -0.006, 0}, {
       0.0002250427592230668, -0.0008334669853786248, 
       0.0011287531272545727`}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[-1, 250], 0}, {
       0.0005850015078988429, 0.012657507859120065`, 
       0.009977698692871519}}, {{0.00012000000000000002`, -0.004, 0}, {
       0.0005850015078988429, 0.012657507859120065`, 0.009977698692871519}}]],
     Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[-1, 500], 0}, {
       0.0012522052704992982`, 0.01798190374379939, 0.0372835704571755}}, {{
       0.00012000000000000002`, -0.002, 0}, {0.0012522052704992982`, 
       0.01798190374379939, 0.0372835704571755}}]], 
    Arrow3DBox[{{0.00012000000000000002`, 0, 0}, {
      0.0012465161097725951`, -5.9536401108011975`*^-6, 
      0.05154572856373495}}], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[1, 500], 0}, {
       0.0012522052704992982`, -0.017988107115831542`, 
       0.0372835704571755}}, {{0.00012000000000000002`, 0.002, 0}, {
       0.0012522052704992982`, -0.017988107115831542`, 0.0372835704571755}}]],
     Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[1, 250], 0}, {
       0.0005850015078988429, -0.012651651830531695`, 
       0.009977698692871519}}, {{0.00012000000000000002`, 0.004, 0}, {
       0.0005850015078988429, -0.012651651830531695`, 
       0.009977698692871519}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[3, 500], 0}, {
       0.0002250427592230668, 0.0008373317552640477, 
       0.0011287531272545727`}}, {{0.00012000000000000002`, 0.006, 0}, {
       0.0002250427592230668, 0.0008373317552640477, 
       0.0011287531272545727`}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[1, 125], 0}, {
       0.00013847281746284936`, 0.006990322063725704, 
       7.312754161531982*^-6}}, {{0.00012000000000000002`, 0.008, 0}, {
       0.00013847281746284936`, 0.006990322063725704, 
       7.312754161531982*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00012000000000000002`, Rational[1, 100], 0}, {
       0.0001235344885172183, 
       0.00980584748548523, -0.000029456745033695782`}}, {{
       0.00012000000000000002`, 0.01, 0}, {0.0001235344885172183, 
       0.00980584748548523, -0.000029456745033695782`}}]]}, {
    Arrow3DBox[
     NCache[{{0.00016, Rational[-1, 100], 0}, {
       0.0001647036456825413, -0.009805563904932308, \
-0.000029409437298631245`}}, {{0.00016, -0.01, 0}, {
       0.0001647036456825413, -0.009805563904932308, \
-0.000029409437298631245`}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[-1, 125], 0}, {
       0.0001845762827354229, -0.006988728999518273, 
       7.644287754009543*^-6}}, {{0.00016, -0.008, 0}, {
       0.0001845762827354229, -0.006988728999518273, 
       7.644287754009543*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[-3, 500], 0}, {
       0.00029969158148989816`, -0.0008293691263863163, 
       0.0011313255289947784`}}, {{0.00016, -0.006, 0}, {
       0.00029969158148989816`, -0.0008293691263863163, 
       0.0011313255289947784`}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[-1, 250], 0}, {0.0007778848887650749, 
       0.012672076313713684`, 0.009994186759982626}}, {{0.00016, -0.004, 0}, {
       0.0007778848887650749, 0.012672076313713684`, 0.009994186759982626}}]],
     Arrow3DBox[
     NCache[{{0.00016, Rational[-1, 500], 0}, {0.001662708245739826, 
       0.017989564475501207`, 0.03734737559224618}}, {{0.00016, -0.002, 0}, {
       0.001662708245739826, 0.017989564475501207`, 0.03734737559224618}}]], 
    Arrow3DBox[{{0.00016, 0, 0}, {
      0.0016588141866677826`, -5.888486936902072*^-6, 0.05160425660105584}}], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[1, 500], 0}, {
       0.001662708245739826, -0.01799576838241261, 0.03734737559224618}}, {{
       0.00016, 0.002, 0}, {0.001662708245739826, -0.01799576838241261, 
       0.03734737559224618}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[1, 250], 0}, {
       0.0007778848887650749, -0.012665511158253262`, 
       0.009994186759982626}}, {{0.00016, 0.004, 0}, {
       0.0007778848887650749, -0.012665511158253262`, 
       0.009994186759982626}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[3, 500], 0}, {0.00029969158148989816`, 
       0.0008332369937350693, 0.0011313255289947784`}}, {{
       0.00016, 0.006, 0}, {0.00029969158148989816`, 0.0008332369937350693, 
       0.0011313255289947784`}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[1, 125], 0}, {0.0001845762827354229, 
       0.0069895804914826155`, 7.644287754009543*^-6}}, {{
       0.00016, 0.008, 0}, {0.0001845762827354229, 0.0069895804914826155`, 
       7.644287754009543*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.00016, Rational[1, 100], 0}, {0.0001647036456825413, 
       0.009805718868780207, -0.000029409437298631245`}}, {{
       0.00016, 0.01, 0}, {0.0001647036456825413, 
       0.009805718868780207, -0.000029409437298631245`}}]]}, {
    Arrow3DBox[
     NCache[{{0.0002, Rational[-1, 100], 0}, {
       0.00020586929288549953`, -0.009805398593895003, \
-0.0000293486655975446}}, {{0.0002, -0.01, 0}, {
       0.00020586929288549953`, -0.009805398593895003, \
-0.0000293486655975446}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[-1, 125], 0}, {
       0.00023065588642303403`, -0.006987776159576785, 
       8.070010367038983*^-6}}, {{0.0002, -0.008, 0}, {
       0.00023065588642303403`, -0.006987776159576785, 
       8.070010367038983*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[-3, 500], 0}, {
       0.0003550976560198071, -0.0008241120185168054, 
       0.001134626414511258}}, {{0.0002, -0.006, 0}, {
       0.0003550976560198071, -0.0008241120185168054, 
       0.001134626414511258}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[-1, 250], 0}, {0.0009695130102051579, 
       0.012689836111142053`, 0.01001531226055051}}, {{0.0002, -0.004, 0}, {
       0.0009695130102051579, 0.012689836111142053`, 0.01001531226055051}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[-1, 500], 0}, {0.002068692261269398, 
       0.01799930028122542, 0.037428930694457616`}}, {{0.0002, -0.002, 0}, {
       0.002068692261269398, 0.01799930028122542, 0.037428930694457616`}}]], 
    Arrow3DBox[{{0.0002, 0, 0}, {
      0.0020576667939541274`, -6.2035150841913186`*^-6, 
      0.05167899638366071}}], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[1, 500], 0}, {
       0.002068692261269398, -0.01800553941300083, 0.037428930694457616`}}, {{
       0.0002, 0.002, 0}, {0.002068692261269398, -0.01800553941300083, 
       0.037428930694457616`}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[1, 250], 0}, {
       0.0009695130102091022, -0.012683261127725092`, 
       0.01001531226055051}}, {{0.0002, 0.004, 0}, {
       0.0009695130102091022, -0.012683261127725092`, 0.01001531226055051}}]],
     Arrow3DBox[
     NCache[{{0.0002, Rational[3, 500], 0}, {0.0003550976560198071, 
       0.000827983856851333, 0.001134626414511258}}, {{0.0002, 0.006, 0}, {
       0.0003550976560198071, 0.000827983856851333, 0.001134626414511258}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[1, 125], 0}, {0.00023065588642303403`, 
       0.006988628506157779, 8.070010367038983*^-6}}, {{0.0002, 0.008, 0}, {
       0.00023065588642303403`, 0.006988628506157779, 
       8.070010367038983*^-6}}]], 
    Arrow3DBox[
     NCache[{{0.0002, Rational[1, 100], 0}, {0.00020586929288549953`, 
       0.00980555369675631, -0.0000293486655975446}}, {{0.0002, 0.01, 0}, {
       0.00020586929288549953`, 
       0.00980555369675631, -0.0000293486655975446}}]]}},
  AutomaticImageSize->True,
  BoxRatios->{1, 1, 1},
  ImageSize->{398.3178605484813, 466.2551147889604},
  ViewPoint->{-2.407011299073156, -0.32134137488650744`, -2.3564881342625563`},
  ViewVertical->{-0.9299346665524357, -0.3370169746851363, 
   0.14710905722656523`}]], "Output",
 CellChangeTimes->{3.5044454986240435`*^9, 3.5044458908165636`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044460230057554`*^9, 3.5044460666781893`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8576667939541273`*^-13", ",", 
   RowBox[{"-", "6.203515084191319`*^-16"}], ",", 
   "5.1678996383660714`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044460812096252`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"0", ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446117944471*^9, 3.5044461352728176`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.706602212727872`*^-16", ",", 
   RowBox[{"-", "2.2377084788736653`*^-13"}], ",", 
   "5.133732888772609`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.504446139804126*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{"0.2", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.504446160148136*^9, 3.504446166616969*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.860817384471168`*^-13", ",", 
   RowBox[{"-", "2.2344295219755645`*^-13"}], ",", 
   "5.1547162346024545`*^-12"}], "}"}]], "Output",
 CellChangeTimes->{3.5044461719607873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{"0.2", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.5044462159769754`*^9, 3.5044462335553255`*^9}, {
  3.5044462804309254`*^9, 3.5044463740258737`*^9}}],

Cell[BoxData["0.008968509606979556`"], "Output",
 CellChangeTimes->{3.5044463284784155`*^9, 3.504446376166526*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcCos", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/", "2"}], 
   "/", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.504446402885618*^9, 3.5044464108857203`*^9}}],

Cell[BoxData["0.000022955493555877015`"], "Output",
 CellChangeTimes->{3.5044464254327817`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Dot"}]], "Input",
 CellChangeTimes->{{3.5044462365241137`*^9, 3.5044462371334963`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\".\\\", \
StyleBox[\\\"b\\\", \\\"TI\\\"], \\\".\\\", StyleBox[\\\"c\\\", \\\"TI\\\"]}]\
\\) or \\!\\(\\*RowBox[{\\\"Dot\\\", \\\"[\\\", RowBox[{StyleBox[\\\"a\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"b\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\
\\\"c\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives products of vectors, matrices \
and tensors. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Dot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.5044462379772573`*^9},
 CellTags->"Info3504449837-4660416"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5044462447742195`*^9, 3.5044462677901387`*^9}}],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.5044462682276444`*^9}]
}, Open  ]]
},
WindowSize->{615, 750},
WindowMargins->{{132, Automatic}, {Automatic, 20}},
ShowSelection->True,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3504449837-4660416"->{
  Cell[72010, 1768, 701, 14, 42, "Print",
   CellTags->"Info3504449837-4660416"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3504449837-4660416", 73437, 1811}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 18636, 467, 2184, "Input"],
Cell[CellGroupData[{
Cell[19206, 491, 1888, 53, 157, "Input"],
Cell[21097, 546, 1492, 28, 244, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22626, 579, 1711, 50, 157, "Input"],
Cell[24340, 631, 1496, 28, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25873, 664, 1824, 51, 137, "Input"],
Cell[27700, 717, 761, 15, 254, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28498, 737, 1628, 49, 137, "Input"],
Cell[30129, 788, 689, 15, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30855, 808, 1943, 56, 155, "Input"],
Cell[32801, 866, 288, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33126, 878, 145, 3, 31, "Input"],
Cell[33274, 883, 197, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33508, 894, 173, 4, 31, "Input"],
Cell[33684, 900, 138, 3, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33859, 908, 94, 1, 31, "Input"],
Cell[33956, 911, 118, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34111, 918, 2075, 59, 179, "Input"],
Cell[36189, 979, 32170, 654, 481, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68396, 1638, 323, 10, 33, "Input"],
Cell[68722, 1650, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68977, 1660, 321, 10, 33, "Input"],
Cell[69301, 1672, 215, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69553, 1682, 393, 13, 33, "Input"],
Cell[69949, 1697, 218, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70204, 1707, 821, 24, 55, "Input"],
Cell[71028, 1733, 114, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71179, 1739, 577, 17, 33, "Input"],
Cell[71759, 1758, 95, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71891, 1764, 116, 2, 31, "Input"],
Cell[72010, 1768, 701, 14, 42, "Print",
 CellTags->"Info3504449837-4660416"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72748, 1787, 267, 7, 31, "Input"],
Cell[73018, 1796, 72, 1, 30, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
